### **Performance Report to Congress**

# **Prescription Drug User Fee** **Act**

## **FY 2025**


---

#### **Executive Summary**

The Prescription Drug User Fee Act (PDUFA) was enacted in 1992 and authorized the
Food and Drug Administration (FDA or Agency) to collect user fees from pharmaceutical
and biotechnology companies for the review of certain human drug and biological
products. With respect to products covered by PDUFA, the FDA committed to certain
review performance goals, procedural and processing goals, and other commitments.

PDUFA has been reauthorized by Congress every 5 years. The sixth reauthorization
(known as PDUFA VII) occurred on September 30, 2022, when the President signed
into law the Continuing Appropriations and Ukraine Supplemental Appropriations Act,
2023, Public Law No. 117-180, of which Division F is titled the FDA User Fee
Reauthorization Act of 2022 (FUFRA). FUFRA amends the Federal Food, Drug, and
Cosmetic Act (FD&C Act) to reauthorize the PDUFA program for an additional 5 years
and is effective from fiscal year (FY) 2023 through FY 2027 _._

As directed by Congress, FDA developed proposed enhancements for PDUFA VII in
consultation with drug industry representatives, patient and consumer advocates, health
care professionals, and other public stakeholders. These discussions led to the current
set of performance goals for the FY 2023 to FY 2027 period, detailed in a document
commonly known as the PDUFA VII Commitment Letter. [1]

This report summarizes FDA’s performance results in meeting PDUFA goals and
commitments for FY 2024 and FY 2025. Specifically, this report updates performance
data for submissions received in FY 2024 (initially reported in the FY 2024 PDUFA
performance report) [2] and presents preliminary data on FDA’s progress in meeting FY
2025 goals. Updates on FDA’s accomplishments related to additional PDUFA VII
commitments for FY 2025 and historical review trend data are also included.
Appendices include details of review cycle data on all original new drug applications
(NDAs) and biologics license applications (BLAs) approved during FY 2025, the number
and characteristics of applications filed by review division, and definitions of key terms
used in this report. In addition, descriptions of the various submission types are
included on page 5 of this report.

The preliminary data show that the percentage of priority and standard applications filed
in FY 2024 and approved during the first review cycle were 76 percent and 68 percent,
respectively.


1 [https://www.fda.gov/media/151712/download.](https://www.fda.gov/media/151712/download)
2 [http://www.fda.gov/about-fda/user-fee-performance-reports/pdufa-performance-reports.](http://www.fda.gov/about-fda/user-fee-performance-reports/pdufa-performance-reports)


---

##### **A.  Achievements in FY 2025**

In FY 2025, FDA met or exceeded 8 of the 10 review performance goals. For example,
current performance is at 100 percent for Original Priority New Molecular Entities
(NMEs) and BLAs, Original Standard NMEs and BLAs, Original Standard Non-NME
NDAs, and Priority NDA and BLA Efficacy Supplements.

##### **B. Review Performance Results**


The FY 2024 cohort had a workload of 3,691 goal closing actions. FDA met or
exceeded the 90-percent performance level for 10 of the 10 review performance goals
for FY 2024.

For the FY 2025 cohort, FDA had completed 2,283 actions as of September 30, 2025.
FDA is currently meeting or exceeding 8 of the 10 review performance goals for FY
2025. With 1,672 submissions under review and still within the PDUFA goal date, FDA
has the potential to meet or exceed 8 of the 10 review performance goals for FY 2025.

##### **C.  Procedural and Processing Performance Results**


For the FY 2024 cohort, FDA’s workload for activities related to procedural and
processing goals and commitments (i.e., meeting management, procedural responses,
and procedural notifications) totaled 12,770 actions. FDA met or exceeded the
performance level for 25 of the 32 procedural and processing goals for FY 2024.

For the FY 2025 cohort, FDA is currently meeting or exceeding 24 of the 31 [3] procedural
and processing goals. There are 32 procedural and processing goals, but only 31 had
applicable submissions. With 1,526 submissions under review and still within the
PDUFA goal date, FDA has the potential to meet or exceed 26 of the 30 applicable
procedural and processing goal commitments for FY 2025. There are 32 procedural and
processing goals, but calculating the highest potential performance is not applicable for
the two Post Marketing Requirement (PMR)-related goals. The PMR-related goals
apply to submissions approved with PMRs, and it is not possible to accurately predict
the number of pending submissions that will be approved with PMRs.


3 Beginning in FY 2024, FDA began reporting on two new procedural and processing goals. FDA
committed to establish timelines for reviewing Use-Related Risk Analysis submissions and Risk
Evaluation Mitigation Strategy Assessment Methods and Protocols.


---

##### **D.  Additional PDUFA VII Commitments**

To highlight just a few achievements, there were several important PDUFA
commitments completed in FY 2025, including:

  - Five guidances,

  - Six public meetings or workshops, and

  - Five public reports or documents.


---

#### **Table of Contents**

**I.** **Introduction ........................................................................................................... 1**


A. Information Presented in This Report ............................................................. 1


**II.** **PDUFA Performance Goals and Commitments ................................................. 6**


**III.** **PDUFA Review Goals ......................................................................................... 10**


A. Review Workload: FY 2020 to FY 2025 ...................................................... 10

B. Final FY 2024 Review Goal Performance Results ....................................... 11

C. Final FY 2024 Review Goal Performance Details ........................................ 12

D. Preliminary FY 2025 Review Goal Performance Results ............................. 14

E. Preliminary FY 2025 Review Goal Performance Details .............................. 16


**IV.** **PDUFA Procedural and Processing Goals and Commitments ....................... 18**


A. Procedural and Processing Workload: FY 2020 to FY 2025 ....................... 18

B. Final FY 2024 Procedural and Processing Performance Results ................ 21

C. Final FY 2024 Procedural and Processing Performance Details ................. 23

D. Preliminary FY 2025 Procedural and Processing Performance Results ...... 28

E. Preliminary FY 2025 Procedural and Processing Performance Details ....... 32


**V.** **PDUFA Trend Graphs ......................................................................................... 39**


A. Total NDAs and BLAs Filed ......................................................................... 39

B. Median Total Times to Approval................................................................... 40

C. Percent of NDAs and BLAs Approved on the First Cycle ............................. 40


**VI.** **Additional PDUFA VII Commitments ................................................................. 42**


A. Section I.A – I.J: Human Drug Review Program and Meeting Management44

B. Section I.K: Enhancing Regulatory Science and Expediting Drug
Development ................................................................................................ 45

C. Section I.L: Enhancing Regulatory Decision Tools to Support Drug
Development and Review ............................................................................ 54


---

D. Section I.M: Enhancement and Modernization of FDA’s Drug Safety System
..................................................................................................................... 57

E. Section I.N: Enhancements Related to Product Quality Reviews, Chemistry,
Manufacturing, and Control Approaches, and Advancing the Utilization of
Innovative Manufacturing Technologies ....................................................... 59

F. Section I.O: Enhancing CBER’s Capacity to Support Development, Review,
and Approval of Cell and Gene Therapy Products ....................................... 61

G. Section I.P: Supporting Review of New Allergenic Extract Products ........... 63

H. Section II: Enhancing the Management of User Fee Resources ................. 63

I. Section III: Improving FDA’s Hiring and Retention of Review Staff ............. 64

J. Section IV: Information Technology and Bioinformatics Goals .................... 65

K. Additional PDUFA VII Review Program Reporting ....................................... 67

_1._ _Hiring and Placement of New PDUFA VII Staff at FDA ....................... 67_


**VII.** **Rationale for PDUFA Program Changes ........................................................... 68**


A. Changes in the Number of Individuals Hired as Agreed in the PDUFA VII
Commitment Letter, the Number of Remaining Vacancies, the Number of
Full-Time Equivalents (FTEs) Funded by Fees Collected Pursuant to Section
736, and the Number of FTEs Funded by Budget Authority by Division Within
CDER, CBER, OII, and OC .......................................................................... 69

_1._ _Changes in the Number of Individuals Hired as Agreed Upon in the_
_PDUFA VII Commitment Letter and Remaining Vacancies ................. 69_

_2._ _Change in the Number of FTEs Funded by Budget Authority and_
_Number of FTEs Funded by Fees by Division Within CDER, CBER, OII,_
_and OC ................................................................................................ 69_

B. Changes in the Average Total Cost Per FTE in the Prescription Drug Review
Program ....................................................................................................... 74

C. Number of Employees for Whom Time Reporting Is Required .................... 76

D. Changes in the Average FTE Hours Required to Complete the Review of
Each Type of Human Drug Application ........................................................ 77


**Appendix A: List of Approved Applications .......................................................... A-1**


**Appendix B: Filed Application Numbers by Review Division .............................. B-1**


**Appendix C: Analysis of Use of Funds .................................................................. C-1**


A. Original Application Approval Cycle Summary ........................................... C-1


---

B. Performance Enhancement Goals ............................................................. C-2

C. Common Causes and Trends Impacting Ability to Meet Goals .................. C-9


**Appendix D: FY 2025 Corrective Action Report .................................................... D-1**


A. Executive Summary ................................................................................... D-1

B. PDUFA Performance Goals ....................................................................... D-4

_1._ _FY 2024 Updated Review and Procedural and Processing Goal_
_Performance Results ......................................................................... D-5_

_2._ _FY 2025 Review and Procedural and Processing Performance Results_
_D-5_

C. PDUFA Performance Enhancement Goals ................................................ D-7


**Appendix E: Definitions of Key Terms .................................................................... E-1**


---

#### **List of Tables and Figures**

Table 1. PDUFA VII Performance Review Goals for FY 2023 to 2027. .......................... 6
Table 2. PDUFA VII Performance Procedural and Processing Goals for FY 2023 to
2027. ............................................................................................................................... 7
Table 3. Workload for Applications and Submissions................................................... 10
Table 4. FY 2024 Final Review Goal Performance Results. ........................................ 11
Table 5. FY 2024 Original Applications. ....................................................................... 13
Table 6. FY 2024 Resubmitted Original Applications. .................................................. 13
Table 7. FY 2024 Efficacy Supplements. ..................................................................... 13
Table 8. FY 2024 Resubmitted Efficacy Supplements. ................................................ 14
Table 9. FY 2024 Manufacturing Supplements. ........................................................... 14
Table 10. FY 2025 Preliminary Review Goal Performance Results. ............................ 15
Table 11. FY 2025 Original Applications. ..................................................................... 16
Table 12. FY 2025 Resubmitted Original Applications. ................................................ 16
Table 13. FY 2025 Efficacy Supplements. ................................................................... 17
Table 14. FY 2025 Resubmitted Efficacy Supplements. .............................................. 17
Table 15. FY 2025 Manufacturing Supplements. ......................................................... 17
Table 16. Meeting Management, Procedural Responses, and Procedural Notifications
Workload. ...................................................................................................................... 18
Table 17. FY 2024 Final Procedural and Processing Performance Results. ................ 21
Table 18. FY 2024 Meeting Management. ................................................................... 24
Table 19. FY 2024 Responses to Clinical Holds. ......................................................... 25
Table 20. FY 2024 Major Dispute Resolutions. ............................................................ 25
Table 21. FY 2024 Special Protocol Assessments. ...................................................... 26
Table 22. FY 2024 Special Protocol Assessments Resubmissions. ............................ 26
Table 23. FY 2024 Drug/Biological Product Proprietary Names. .................................. 26
Table 24. FY 2024 Human Factors Validation Protocol Submissions. ......................... 26
Table 25. FY 2024 Use-Related Risk Analysis Submissions. ...................................... 27
Table 26. FY 2024 REMS Assessment Methods and Protocols. ................................. 27
Table 27. FY 2024 Communication of Anticipated Postmarketing Requirements
(PMRs). ......................................................................................................................... 27
Table 28. FY 2025 Preliminary Procedural and Processing Performance Results. ...... 29
Table 29. FY 2025 Meeting Management. ................................................................... 32
Table 30. FY 2025 Responses to Clinical Holds. ......................................................... 35
Table 31. FY 2025 Major Dispute Resolutions. ............................................................ 35
Table 32. FY 2025 Special Protocol Assessments. ...................................................... 35
Table 33. FY 2025 Special Protocol Assessments Resubmissions. ............................ 36
Table 34. FY 2025 Drug/Biological Product Proprietary Names. .................................. 36
Table 35. FY 2025 Human Factors Validation Protocol Submissions. ......................... 36
Table 36. FY 2025 Use-Related Risk Analysis Submissions. ...................................... 37


---

Table 37. FY 2025 REMS Assessment Methods and Protocols. ................................. 37
Table 38. FY 2025 Communication of Anticipated Postmarketing Requirements
(PMRs). ......................................................................................................................... 37
Figure 1. Total NDAs and BLAs Filed. .......................................................................... 39
Figure 2. Median Time to Application Approval for First Approval NDAs and BLAs
(Months). [†] ...................................................................................................................... 40
Figure 3. Percent of NDAs and BLAs Approved on the First Cycle. [†] ............................ 41
Table 39. Section I.A - I.J’s FY 2025 Commitments and Accomplishments. ................ 44
Table 40. Section I.K’s FY 2025 Commitments and Accomplishments. ....................... 45
Table 41. Section I.L’s FY 2025 Commitments and Accomplishments. ....................... 54
Table 42. Section I.M’s FY 2025 Commitments and Accomplishments. ...................... 57
Table 43. Section I.N’s FY 2025 Commitments and Accomplishments. ....................... 59
Table 44. Section I.O’s FY 2025 Commitments and Accomplishments........................ 61
Table 45. Section I.P’s FY 2025 Commitments and Accomplishments. ....................... 63
Table 46. Section II’s FY 2025 Commitments and Accomplishments. ......................... 63
Table 47. Section III’s FY 2025 Commitments and Accomplishments. ........................ 64
Table 48. Section IV’s FY 2025 Commitments and Accomplishments. ........................ 65
Table 49. Number of Individuals Hired as Agreed Upon in the PDUFA VII Commitment
Letter and Remaining Vacancies. ................................................................................. 69
Table 50. Number of FTEs Funded by Budget Authority and Number of FTEs funded by
Fees by Division Within CDER, CBER, OII, and OC. .................................................... 70
Table 51. Changes in the Average Total Cost Per FTE in the Prescription Drug Review
Program. ....................................................................................................................... 76
Table 52. Time Reporting Requirement for FY 2025. ................................................... 76
Table 53. Changes in the Average FTE Hours Required to Complete the Review of
Each Type of Human Drug Applications. ....................................................................... 77
Table A-1. FY 2025 Priority NDA and BLA Approvals (by Fiscal Year of Receipt). ........ 2
Table A-2. FY 2025 Standard NDA and BLA Approvals (by Fiscal Year of Receipt). ..... 6
Table B-1. Original Applications Filed in FY 2025 by Review Division/Office. ................ 1
Table B-2. Efficacy Supplements Filed in FY 2025 by Review Division/Office. .............. 4
Table B-3. Submissions with Special Designations Filed in FY 2025 by Review
Division/Office. ................................................................................................................ 6
Table C-1. FY 2025 Original Application Approval Cycle Summary. .............................. 2
Table C-2. FY 2024 Performance Enhancement Goals (Updated). ............................... 3
Table C-3. FY 2025 Performance Enhancement Goals. ................................................ 3
Table C-4. FY 2025 Performance Results. ..................................................................... 9
Table D-1. FY 2024 Review and Procedural and Processing Goal Performance Results
(Updated). ....................................................................................................................... 1
Table D-2. FY 2025 Review and Procedural and Processing Goal Performance
Results. ........................................................................................................................... 2


---

#### **Acronym List**

**ARC Program** Accelerating Rare Disease Cures Program

**BLA** Biologics License Application

**BT** Breakthrough Therapy

**CBER** Center for Biologics Evaluation and Research

**CDER** Center for Drug Evaluation and Research

**CDRH** Center for Devices and Radiological Health

**CPA** Capacity Planning Adjustment

**DHT** Digital Health Technology

**DRDMG** Division of Rare Diseases and Medical Genetics

**EOP** End of Phase

**ETASU** Elements to Assure Safe Use

**ESG** Electronic Submissions Gateway

**FDA** Food and Drug Administration

**FD&C Act** Federal Food, Drug, and Cosmetic Act

**FDARA** FDA Reauthorization Act of 2017

**FTE** Full-Time Equivalent

**FUFRA** FDA User Fee Reauthorization Act of 2022

**FY** Fiscal Year (October 1 to September 30)

**IND** Investigational New Drug

**IT** Information Technology

**MAPP** Manual of Policies and Procedures

**NDA** New Drug Application

**NME** New Molecular Entity

**OC** Office of the Commissioner

**OII** Office of Inspections and Investigations


---

**PFDD** Patient Focused Drug Development

**PMR** Postmarketing Requirement

**RDT** Rare Diseases Team

**REMS** Risk Evaluation and Mitigation Strategy

**RFI** Request for Information

**URRA** Use-Related Risk Analysis

**WCF** Working Capital Fund


---

#### **I. Introduction**

On September 30, 2022, the President signed the FDA User Fee Reauthorization Act
of 2022 (FUFRA) into law, which included the sixth reauthorization of the Prescription
Drug User Fee Act (PDUFA) for fiscal year (FY) 2023 through FY 2027, known as
PDUFA VII. PDUFA VII continues to provide the Food and Drug Administration (FDA
or Agency) with a consistent source of funding to help maintain a predictable and
efficient review process for human drugs and biological products. In commitments tied
to this funding, FDA agreed to certain review performance goals, such as reviewing
and acting on new drug application (NDA) and biologics license application (BLA)
submissions within predictable time frames.


Since the enactment of PDUFA I in 1992, FDA has used PDUFA resources to
significantly reduce the time needed to evaluate new drugs and biological products
without compromising its rigorous standards for a demonstration of safety, efficacy,
and quality of these products before approval. The efficiency gains under PDUFA
have revolutionized the drug review process in the United States and enabled FDA to
ensure more timely access to innovative and important new therapies for patients.


More information on the history of PDUFA is available on FDA’s website. [1]

##### **A. Information Presented in This Report**


This report presents PDUFA performance and workload information for two different
types of goals: (1) the review of applications and other submissions pertaining to
human drugs and biological products and (2) meeting management and other
procedural goals related to responses and notifications in the human drug review
process. PDUFA workload information for these goals is included in the tables that
follow. Significant components of the PDUFA workload (such as reviews of
investigational new drug (IND) applications, labeling supplements, and annual reports,
as well as the ongoing monitoring of drug safety in the postmarket setting) are not
captured by PDUFA goals and are therefore not presented in this report.


PDUFA performance information related to achieving these two types of goals includes
reviews of submissions pending from the previous fiscal year as well as reviews of
submissions received during the current fiscal year. This report presents the final


[1 A history of PDUFA and past performance reports are available at http://www.fda.gov/about-fda/user-](http://www.fda.gov/about-fda/user-fee-performance-reports/pdufa-performance-reports)
[fee-performance-reports/pdufa-performance-reports.](http://www.fda.gov/about-fda/user-fee-performance-reports/pdufa-performance-reports)


_Prescription Drug User Fee Act: FY 2025_ _Page 1_


---

performance results for the FY 2024 cohort of submissions based on actions
completed in FY 2024 and FY 2025. In addition, this report includes the preliminary
performance results for the FY 2025 cohort of submissions that had actions completed
or due for completion in FY 2025. Final performance for the FY 2025 cohort will be
presented in the FY 2026 PDUFA performance report and will include actions for
submissions still pending within the PDUFA goal date as of September 30, 2025.


The following information refers to FDA’s performance presented in this report.


  - The following terminology is used throughout this document:

     - _Application_ means a new, original application.

     - _Supplement_ means a request to approve a change in an application that has
been approved.

     - _Resubmission_ means a resubmitted application or supplement in response
to a complete response, approvable, not approvable, or tentative approval
letter.

     - _New molecular entities_ _(NMEs)_ refer only to NMEs that are submitted for
approval under NDAs (not BLAs).

     - _Submission_ applies to all the above.

     - _Action_ refers to an FDA decision (e.g., an approval, a tentative approval, a
complete response) or withdrawal of the submission by the sponsor for any
of the above.


  - Under PDUFA VII, the preliminary counts of NMEs in workload tables for the
current fiscal year may not reflect the final determination of NME status for that
fiscal year. FDA often receives multiple submissions for the same NME (e.g.,
different dosage forms). All such submissions are initially designated as NMEs,
and once FDA approves the first of the multiple submissions, the other
submissions will be designated as Non-NMEs, and workload numbers will be
appropriately updated in later years.

  - The data presented in this report do not include biosimilar INDs or biosimilar
BLAs. These data are presented in the annual Biosimilar User Fee Act (BsUFA)
Performance Reports located on FDA’s website. [2]

  - FDA files only applications that are sufficiently complete to permit a substantive
review. The Agency makes a filing decision within 60 days of an original
application’s receipt by FDA. FDA’s review of an application begins once the


[2] [See the BsUFA performance reports at http://www.fda.gov/about-fda/user-fee-performance-](http://www.fda.gov/about-fda/user-fee-performance-reports/bsufa-performance-reports)
[reports/bsufa-performance-reports.](http://www.fda.gov/about-fda/user-fee-performance-reports/bsufa-performance-reports)


_Prescription Drug User Fee Act: FY 2025_ _Page 2_


---

application is received. For NME NDAs and original BLAs reviewed under the
program (see the PDUFA VII Commitment Letter [3] for more information), the
PDUFA clock begins after the conclusion of the 60-day filing period. For all
other submissions, the PDUFA clock begins upon FDA’s receipt of the
application.


  - FDA annually reports PDUFA performance data for each fiscal year receipt
cohort (defined as submissions filed from October 1 to September 30 of the
following year). In each fiscal year, FDA receives submissions that will have
associated goals due in the following fiscal year. For these submissions, FDA’s
performance data will be reported in subsequent fiscal years, either after the
Agency takes an action or when the goal becomes overdue, whichever comes
first.


  - Submission types (e.g., responses to clinical holds) with shorter (e.g., 30-day)
review time goals tend to have a larger percentage of reviews completed by the
end of the fiscal year, and these submission types’ preliminary performance
data are a more reliable indicator of their final performance results. However,
submission types (e.g., standard NME NDA/BLA) with longer (e.g., within 10
months of the 60-day filing date) review time goals tend to have a smaller
percentage of reviews completed within the reporting period, and these
submission types’ preliminary performance data are a less reliable indicator of
their final performance results.


  - Final performance results for FY 2024 submissions are shown as the
percentage of submissions that were reviewed within the specified goal timeline.
Submission types with 90 percent or more submissions reviewed by the goal
date are shown as having met the goal.


  - Preliminary performance results for FY 2025 submissions are shown as the
percentage of submissions reviewed on time as of September 30, 2025,
excluding actions pending within the PDUFA goal date. Submission types with
a current performance result of 90 percent or more reviewed by the goal date
are shown as currently meeting the goal. [4] The highest possible percent of
reviews that may be completed on time (i.e., the highest possible performance
results) if all non-overdue pending reviews are completed within the goal is also


[3 See the PDUFA VII Commitment Letter at https://www.fda.gov/media/151712/download.](https://www.fda.gov/media/151712/download)
4 There are six processing and procedural performance goals with performance thresholds at 70 percent,
and two goals at 80 percent. Therefore, a current performance result at these rates or higher will be
shown as currently meeting the goal.


_Prescription Drug User Fee Act: FY 2025_ _Page 3_


---

shown.


  - Filed applications and supplements include submissions that have been filed or
are in pending filing status. Data do not include submissions that are
unacceptable for filing because of nonpayment of user fees, have been
withdrawn within 60 days of receipt, or have been refused to file. Data include
applications or supplements that were administratively split to allow the Agency
to take different actions with respect to different aspects of the submission.


  - FY 2025 workload and performance figures include applications that are
identified as _undesignated_, which means they are still within the 60-day filing
date and have not yet had a review designation, standard or priority, made.


  - For resubmitted applications, the applicable performance goal is determined by
the fiscal year in which the resubmission is received, rather than the year in
which the original application was submitted.


  - Unless otherwise noted, all performance data are as of September 30, 2025.


  - Definitions of key terms used throughout this report can be found in Appendix E.


_Prescription Drug User Fee Act: FY 2025_ _Page 4_


---

_Prescription Drug User Fee Act: FY 2025_ _Page 5_


---

#### **II. PDUFA Performance Goals and Commitments**

Tables 1 and 2 present the goal timelines and the percentage of submissions that FDA
committed to review within those goal timelines for FY 2023 through FY 2027.


**Table 1. PDUFA VII Review Goals for FY 2023 to 2027.**


|PDUFA Submission Type|Goal: Act on<br>Within|FY 23|FY 24|FY 25|FY 26|FY 27|
|---|---|---|---|---|---|---|
|**Applications and Submissions**|**Applications and Submissions**|**Applications and Submissions**|**Applications and Submissions**|**Applications and Submissions**|**Applications and Submissions**|**Applications and Submissions**|
|<br>Original Priority NME and BLA<br>Submissions|6 months from<br>filing date|90%|90%|90%|90%|90%|
|Original Standard NME and BLA<br>Submissions<br>|10 months from<br>filing date|90%|90%|90%|90%|90%|
|Original Priority Non-NME NDA<br>Submissions<br>|6 months|90%|90%|90%|90%|90%|
|<br>Original Standard Non-NME NDA<br>Submissions<br>|10 months|90%|90%|90%|90%|90%|
|<br>Class 1 Resubmitted NDAs and<br>BLAs<br>|2 months|90%<br>|90%<br>|90%<br>|90%<br>|90%<br>|
|<br>Class 2 Resubmitted NDAs and<br>BLAs<br>|6 months|6 months|6 months|6 months|6 months|6 months|
|<br>Priority NDA and BLA Efficacy<br>Supplements<br>|6 months|90%|90%|90%|90%|90%|
|<br>Standard NDA and BLA Efficacy<br>Supplements<br>|10 months|90%|90%|90%|90%|90%|
|<br>Class 1 Resubmitted NDA and BLA<br>Efficacy Supplements<br>|2 months|90%|90%|90%|90%|90%|
|<br>Class 2 Resubmitted NDA and BLA<br>Efficacy Supplements<br>|6 months|6 months|6 months|6 months|6 months|6 months|
|<br>NDA and BLA Manufacturing<br>Supplements Requiring Prior<br>Approval<br>|4 months|90%|90%|90%|90%|90%|
|<br>NDA and BLA Manufacturing<br>Supplements not Requiring Prior<br>Approval|6 months|90%|90%|90%|90%|90%|


_Prescription Drug User Fee Act: FY 2025_ _Page 6_


---

**Table 2. PDUFA VII Procedural and Processing Goals for FY 2023 to 2027.**


|PDUFA Procedural/<br>Processing Type|Goal|FY 23|FY 24|FY 25|FY 26|FY 27|
|---|---|---|---|---|---|---|
|**Procedural Notifications/Responses**|**Procedural Notifications/Responses**|**Procedural Notifications/Responses**|**Procedural Notifications/Responses**|**Procedural Notifications/Responses**|**Procedural Notifications/Responses**|**Procedural Notifications/Responses**|
|<br>Responses to Clinical Holds|<br>Respond within<br>30 days|90%|90%|90%|90%|90%|
|Major Dispute Resolutions|Respond within<br>30 days<br>|90%|90%|90%|90%|90%|
|Special Protocol Assessments|Complete and<br>return within 45<br>days<br>|90%|90%|90%|90%|90%|
|Review of Proprietary Names<br>Submitted During IND Phase|<br>Review and<br>notify of<br>tentative<br>acceptance or<br>non-acceptance<br>within 180 days<br>|90%|90%|90%|90%|90%|
|Review of Proprietary Names<br>Submitted During NDA/BLA Phase|<br>Review and<br>notify of<br>tentative<br>acceptance or<br>non-acceptance<br>within 90 days<br>|90%|90%|90%|90%|90%|
|Human Factors Validation Protocol<br>Submissions to INDs|<br>Review and<br>provide<br>comments<br>within 60 days<br>|90%|90%|90%|90%|90%|
|Use-Related Risk Analysis<br>Submissions|<br>Review and<br>respond within<br>60 days<br>|--|50%|70%|90%|90%|
|REMS Assessment Methods and<br>Protocols|<br>Review and<br>respond within<br>90 days<br>|--|50%|70%|90%|90%|
|Priority NME NDAs and Original<br>BLAs Approved with PMRs|<br>Communicate<br>anticipated<br>PMRs 6 weeks<br>prior to action<br>goal date<br>|60%|70%|80%|80%|80%|
|Standard NME NDAs and Original<br>BLAs Approved with PMRs|<br>Communicate<br>anticipated<br>PMRs 8 weeks<br>prior to action<br>goal date|60%|70%|80%|80%|80%|


_Prescription Drug User Fee Act: FY 2025_ _Page 7_


---

|PDUFA Procedural/<br>Processing Type|Goal|FY 23|FY 24|FY 25|FY 26|FY 27|
|---|---|---|---|---|---|---|
|**Meeting Management**|**Meeting Management**|**Meeting Management**|**Meeting Management**|**Meeting Management**|**Meeting Management**|**Meeting Management**|
|<br>Type A Meeting Requests|Respond within<br>14 days|90%|90%|90%|90%|90%|
|Type B Meeting Requests|Respond within<br>21 days|90%|90%|90%|90%|90%|
|Type B(EOP) Meeting Requests|Respond within<br>14 days|90%|90%|90%|90%|90%|
|Type C Meeting Requests|Respond within<br>21 days|90%|90%|90%|90%|90%|
|Type D Meeting Requests|Respond within<br>14 days|90%|90%|90%|90%|90%|
|Type INTERACT Meeting Requests|Respond within<br>21 days|90%|90%|90%|90%|90%|
|Type A Meetings Scheduled|Schedule within<br>30 days|90%|90%|90%|90%|90%|
|Type B Meetings Scheduled|Schedule within<br>60 days|90%|90%|90%|90%|90%|
|Type B(EOP) Meetings Scheduled|Schedule within<br>70 days|90%|90%|90%|90%|90%|
|Type C Meetings Scheduled|Schedule within<br>75 days|90%|90%|90%|90%|90%|
|Type D Meetings Scheduled|Schedule within<br>50 days|50%|60%|70%|80%|90%|
|Type INTERACT Meetings<br>Scheduled|<br>Schedule within<br>75 days|50%|60%|70%|80%|90%|
|Type A Written Response|Send within 30<br>days|90%|90%|90%|90%|90%|
|Type B Meeting Written Response|Send within 60<br>days|90%|90%|90%|90%|90%|
|Type B(EOP) Written Response|Send within 70<br>days|90%|90%|90%|90%|90%|
|Type C Written Response|Send within 75<br>days|90%|90%|90%|90%|90%|
|Type D Written Response|<br>Send within 50<br>days|50%|60%|70%|80%|90%|
|Type INTERACT Written Response|Send within 75<br>days|50%|60%|70%|80%|90%|


_Prescription Drug User Fee Act: FY 2025_ _Page 8_


---

|PDUFA Procedural/<br>Processing Type|Goal|FY 23|FY 24|FY 25|FY 26|FY 27|
|---|---|---|---|---|---|---|
|Preliminary Response for Type<br>B(EOP) Meetings|Issue no later<br>than 5 days<br>prior to meeting<br>date<br>|90%|90%|90%|90%|90%|
|Preliminary Response for Type D<br>Meetings|<br>Issue no later<br>than 5 days<br>prior to meeting<br>date<br>|90%|90%|90%|90%|90%|
|Preliminary Response for Type<br>INTERACT Meetings|<br>Issue no later<br>than 5 days<br>prior to meeting<br>date<br>|90%|90%|90%|90%|90%|
|Meeting Minutes for All Meeting<br>Types<br>|<br>Issue within 30<br>Days After<br>Meeting Date|90%|90%|90%|90%|90%|


_Prescription Drug User Fee Act: FY 2025_ _Page 9_


---

#### **III. PDUFA Review Goals**

##### **A. Review Workload: FY 2020 to FY 2025**

In the table below, preliminary workload numbers from FY 2025 are compared to the
previous 5-year averages for original NDAs and BLAs, resubmissions, and
supplements, and the workload numbers for the previous 5 years are presented.

Definitions of Class 1 and Class 2 resubmissions and other terms are found in Appendix
E. The data presented in this section represent receipts by FDA of the submission
types listed in Table 3.


**Table 3. Workload for Applications and Submissions.**


|Submission Type|FY 20|FY 21|FY 22|FY 23|FY 24*|FY 25|FY 20 to<br>FY 24<br>5-Year<br>Average|FY 25<br>Compared<br>to 5-Year<br>Average|
|---|---|---|---|---|---|---|---|---|
|Original Priority<br>NMEs and BLAs<br>|54|52|43|38|40|45†|<br>45|<br>0%‡|
|<br>Original Standard<br>NMEs and BLAs<br>|29|29|33|27|33|30|30|0%|
|<br>Original Priority Non-<br>NME NDAs<br>|14|22|11|18|9|21†|15|40%‡|
|<br>Original Standard<br>Non-NME NDAs<br>|59|72|44|72|47|61|59|3%|
|<br>Class 1 Resubmitted<br>NDAs and BLAs<br>|5|5|8|10|6|6|7|-14%|
|<br>Class 2 Resubmitted<br>NDAs and BLAs<br>|57|51|59|66|47|50|56|-11%|
|<br>Priority NDA and BLA<br>Efficacy Supplements<br>|112|100|77|67|90|95†|89|7%‡|
|<br>Standard NDA and<br>BLA Efficacy<br>Supplements<br>|195|173|171|178|207|185|185|0%|
|<br>Class 1 Resubmitted<br>NDA and BLA Efficacy<br>Supplements<br>|3|3|1|2|2|3|2|50%|
|<br>Class 2 Resubmitted<br>NDA and BLA Efficacy<br>Supplements|20|10|11|4|7|5|10|-50%|


_Prescription Drug User Fee Act: FY 2025_ _Page 10_


---

|Submission Type|FY 20|FY 21|FY 22|FY 23|FY 24*|FY 25|FY 20 to<br>FY 24<br>5-Year<br>Average|FY 25<br>Compared<br>to 5-Year<br>Average|
|---|---|---|---|---|---|---|---|---|
|NDA and BLA<br>Manufacturing<br>Supplements<br>Requiring Prior<br>Approval<br>|1,168|1,243|1,155|1,275|1,411|1,667|<br>1,250|<br>33%|
|<br>NDA and BLA<br>Manufacturing<br>Supplements Not<br>Requiring Prior<br>Approval<br>|1,717<br>|1,779<br>|1,518<br>|1,738<br>|1,796<br>|1,787<br>|1,710<br>|5%<br>|


report.

- Some applications have not yet received a review priority designation. There were six undesignated NMEs and
BLAs counted as Priority NMEs and BLAs, 13 undesignated Non-NME NDAs counted as Priority Non-NME NDAs,
and nine undesignated efficacy supplements counted as Priority NDA and BLA Efficacy Supplements in the table
above. Performance results in all categories may change once designations are made for these applications, and
the table will then be updated accordingly, as appropriate, in the FY 2026 PDUFA performance report.

- The percentage difference may be inflated due to the inclusion of undesignated submissions.


##### **B. Final FY 2024 Review Goal Performance Results**

The final FY 2024 review goal performance results are presented in Table 4. The final
performance results for submission types that met or exceeded the goal (i.e., 90
percent or more actions were completed by the goal date) are shown in bold text. FDA
met or exceeded the 90-percent performance level for 10 of 10 review performance
goals in FY 2024.


**Table 4. FY 2024 Final Review Goal Performance Results.**


|Submission Type|Goal: Act<br>on 90<br>Percent<br>Within|Total|FY 2024<br>Performance|
|---|---|---|---|
|Original Priority NMEs and BLAs|<br>6 months <br>of filing date<br>|38 of 40 on<br>time<br>|**95%**|
|Original Standard NMEs and BLAs|<br>10 months<br>of filing date|<br>27 of 29<br>on time<br>|**93%**|
|Original Priority Non-NME NDAs|<br>6 months|<br>9 of 9<br>on time<br>|**100%**|
|Original Standard Non-NME NDAs|10 months|<br>46 of 47<br>on time|**98%**|


_Prescription Drug User Fee Act: FY 2025_ _Page 11_


---

|Submission Type|Goal: Act<br>on 90<br>Percent<br>Within|Total|FY 2024<br>Performance|
|---|---|---|---|
|Class 1 Resubmitted NDAs and BLAs|<br>2 months|5 of 6<br>on time<br>|**96%**|
|Class 2 Resubmitted NDAs and BLAs<br>|6 months|<br>46 of 47<br>on time<br>|<br>46 of 47<br>on time<br>|
|Priority NDA and BLA Efficacy<br>Supplements<br>|6 months|<br>86 of 90<br>on time<br>|**96%**|
|<br>Standard NDA and BLA Efficacy<br>Supplements<br>|10 months|<br>197 of 207<br>on time<br>|**95%**|
|<br>Class 1 Resubmitted NDA and BLA<br>Efficacy Supplements<br>|2 months|<br>2 of 2<br>complete<br>|**100%**|
|<br>Class 2 Resubmitted NDA and BLA<br>Efficacy Supplements<br>|6 months|<br>7 of 7<br>complete<br>|<br>7 of 7<br>complete<br>|
|<br>NDA and BLA Manufacturing<br>Supplements Requiring Prior Approval<br>|4 months|<br>1,363 of 1,411<br>complete|**97%**|
|<br>NDA and BLA Manufacturing<br>Supplements Not Requiring Prior<br>Approval<br>|6 months|<br>1,759 of 1,796<br>complete|**98%**|


##### **C. Final FY 2024 Review Goal Performance Details**

Tables 5 to 9 detail the final performance data for the FY 2024 cohort of submissions.
These data include the number of submissions reviewed _On Time_ (i.e., acted on by the
PDUFA goal date) or _Overdue_ (i.e., acted on past the goal date or pending past the
goal date) and the final _Percent on Time_ (i.e., final performance with no actions
pending within the PDUFA goal date). The performance data presented here have
been updated from the preliminary performance information reported in the FY 2024
PDUFA performance report.


_Prescription Drug User Fee Act: FY 2025_ _Page 12_


---

**Table 5. FY 2024 Original Applications.**


|Original Application<br>Type|Goal: Act<br>on 90<br>Percent<br>Within|Filed|On<br>Time|Overdue|Percent<br>on Time|
|---|---|---|---|---|---|
|Priority NMEs &<br>BLAs|<br>6 months<br>of filing<br>date<br>|40|38|2|95%|
|Standard NMEs &<br>BLAs<br>|<br>10 months<br>of filing<br>date|33|27|2|93%*****|
|Priority Non-NME<br>NDAs<br>|<br>6 months|9|9|0|100%|
|<br>Standard Non-NME<br>NDAs<br>|10 months<br>|47<br>|46<br>|1 <br>|98%<br>|


**Table 6. FY 2024 Resubmitted Original Applications.**


|Resubmitted<br>Application Type|Goal: Act on<br>90 Percent<br>Within|Received|On<br>Time|Overdue|Percent<br>on Time|
|---|---|---|---|---|---|
|Class 1|<br>2 months|6|5|1|96%|
|Class 2|6 months|47|46|1|1|


**Table 7. FY 2024 Efficacy Supplements.**


|Efficacy<br>Supplement Type|Goal: Act on<br>90 Percent<br>Within|Filed|On<br>Time|Overdue|Percent<br>on Time|
|---|---|---|---|---|---|
|Priority|<br>6 months|90|86|4|96%|
|Standard<br>|10 months|207|197|10|95%|


_Prescription Drug User Fee Act: FY 2025_ _Page 13_


---

**Table 8. FY 2024 Resubmitted Efficacy Supplements.**


|Resubmitted<br>Efficacy<br>Supplement Type|Goal: Act on<br>90 Percent<br>Within|Received|On<br>Time|Overdue|Percent<br>on Time|
|---|---|---|---|---|---|
|<br>Class 1|<br>2 months|2|2|0|100%|
|Class 2|6 months|7|7|0|0|


**Table 9. FY 2024 Manufacturing Supplements.**


|Manufacturing<br>Supplement Type|Goal: Act on<br>90 Percent<br>Within|Filed|On Time|Overdue|Percent<br>on<br>Time|
|---|---|---|---|---|---|
|Prior Approval<br>Required<br>|<br>4 months|1,411|1,363|48|<br>97%|
|<br>Prior Approval<br>Not Required|6 months|1,796|1,759|37|98%|


##### **D. Preliminary FY 2025 Review Goal Performance Results**

The preliminary FY 2025 review goal performance results are presented in Table 10.


  - The _Progress_ (i.e., the number of reviews completed) and the total number of
submissions received for each submission type are shown in the second
column. _FY 2025_ _Current Performance_ includes submissions reviewed _On Time_
(i.e., acted on by the PDUFA goal date) or _Overdue_ (i.e., acted on past the goal
date or pending past the goal date). The current performance results for
submission types with a greater proportion of reviews completed will be more
representative of the final performance results. The _Highest Possible Final_
_Performance_ is the best potential final performance result, which accounts for
actions pending within the PDUFA goal date.

  - The current performance results for submission types that are meeting the
performance goal (i.e., 90 percent or more reviews were completed by the goal
date) as of September 30, 2025, are shown in bold text. FDA is currently
meeting or exceeding the 90-percent performance level for 8 of the 10
performance goals.

  - If all non-overdue pending submissions are reviewed on time, FDA will achieve


_Prescription Drug User Fee Act: FY 2025_ _Page 14_


---

the performance results presented in the Highest Possible Final Performance
column. FDA has the potential to meet or exceed the 90-percent performance
level for 8 of the 10 review performance goals.


**Table 10. FY 2025 Preliminary Review Goal Performance Results.**


|Submission Type|Progress*|Goal: Act on<br>90 Percent<br>Within|FY 2025<br>Current<br>Performance|Highest<br>Possible<br>Final<br>Performance|
|---|---|---|---|---|
|Original Priority NMEs and<br>BLAs<br>|18 of 39<br>complete<br>|6 months of<br>filing date<br>|**100%**|<br>100%|
|<br>Original Standard NMEs<br>and BLAs<br>|<br>4 of 30<br>complete<br>|<br>10 months of<br>filing date|**100%**|100%|
|<br>Original Priority Non-NME<br>NDAs<br>|<br>7 of 8<br>complete<br>|<br>6 months|86%|88%|
|<br>Original Standard Non-NME<br>NDAs<br>|<br>11 of 61<br>complete<br>|10 months|**100%**|100%|
|<br>Class 1 Resubmitted NDAs<br>and BLAs<br>|<br>5 of 6<br>complete<br>|2 months|**94%**|96%|
|<br>Class 2 Resubmitted NDAs<br>and BLAs<br>|<br>30 of 50<br>complete<br>|6 months|6 months|6 months|
|<br>Priority NDA and BLA<br>Efficacy Supplements<br>|<br>39 of 86<br>complete<br>|6 months|**100%**|100%|
|<br>Standard NDA and BLA<br>Efficacy Supplements<br>|<br>53 of 185<br>complete|10 months|**96%**|99%|
|<br>Class 1 Resubmitted NDA<br>and BLA Efficacy<br>Supplements<br>|<br>3 of 3<br>complete|2 months|83%|88%|
|<br>Class 2 Resubmitted NDA<br>and BLA Efficacy<br>Supplements<br>|3 of 5<br>complete<br>|6 months|6 months|6 months|
|<br>NDA and BLA Manufacturing<br>Supplements Requiring Prior<br>Approval<br>|1,045 of<br>1,667<br>complete<br>|4 months|**96%**|97%|
|<br>NDA and BLA Manufacturing<br>Supplements Not Requiring<br>Prior Approval<br>|<br>1,065 of<br>1,787<br>complete<br>|6 months<br>|**98%**<br>|99%<br>|


status.


_Prescription Drug User Fee Act: FY 2025_ _Page 15_


---

##### **E. Preliminary FY 2025 Review Goal Performance Details**

The following detailed performance information for the FY 2025 cohort submissions
includes the number of submissions _Filed_ or _Received_, reviewed _On Time_ (i.e., acted
on by the PDUFA goal date), and _Overdue_ (i.e., acted on past the goal date or pending
past the goal date). The number of submissions not yet acted on but still pending
within the PDUFA goal date ( _Pending within Goal_ ) is also provided, along with the
highest possible percent of reviews that may be completed on time ( _Highest Possible_
_Percent on Time_ ).


**Table 11. FY 2025 Original Applications.**


|Original Application<br>Type|Goal: Act<br>on 90<br>Percent<br>Within|Filed|On<br>Time|Overdue|Col6|Pending<br>Within<br>Goal|Current<br>Percent<br>on Time|Highest<br>Possible<br>Percent<br>on Time|
|---|---|---|---|---|---|---|---|---|
|Priority NMEs & BLAs<br>|6 months of<br>filing date<br>|39|18|0|0|21|100%|100%|
|Standard NMEs &<br>BLAs<br>|<br>10 months<br>of filing date|30|4|0|0|26|100%|100%|
|<br>Priority Non-NME<br>NDAs<br>|<br>6 months|8|6|1|1|1|86%|88%|
|<br>Standard Non-NME<br>NDAs<br>|10 months|61|11|0|0|50|100%|100%|
|<br>Review Priority<br>Undesignated*|N/A|19|--|--|--|--|--|--|
|<br>Total<br>|N/A<br>|157<br>|39<br>|1 <br>|1 <br>|98|--†|--†|
|* These applications have not yet received a review priority designation<br>|* These applications have not yet received a review priority designation<br>|* These applications have not yet received a review priority designation<br>|* These applications have not yet received a review priority designation<br>|* These applications have not yet received a review priority designation<br>|||||


**Table 12. FY 2025 Resubmitted Original Applications.**


|Resubmitted<br>Application Type|Goal: Act<br>on 90<br>Percent<br>Within|Received|On<br>Time|Overdue|Pending<br>Within<br>Goal|Current<br>Percent<br>on Time|Highest<br>Possible<br>Percent<br>on Time|
|---|---|---|---|---|---|---|---|
|Class 1|2 months|6|5|0|1|94%|96%|
|Class 2|6 months|50|28|2|20|20|20|


_Prescription Drug User Fee Act: FY 2025_ _Page 16_


---

**Table 13. FY 2025 Efficacy Supplements.**


|Efficacy<br>Supplement Type|Goal: Act<br>on 90<br>Percent<br>Within|Filed|On<br>Time|Overdue|Pending<br>Within<br>Goal|Current<br>Percent<br>on Time|Highest<br>Possible<br>Percent<br>on Time|
|---|---|---|---|---|---|---|---|
|Priority|6 months|86|39|0|47|100%|100%|
|Standard|10 months|185|51|2|132|96%|99%|
|Review Priority<br>Undesignated*<br>|N/A<br>|9 <br>|--<br>|--<br>|--|--|--|


**Table 14. FY 2025 Resubmitted Efficacy Supplements.**


|Resubmitted Efficacy<br>Supplement Type|Goal: Act<br>on 90<br>Percent<br>Within|Received|On<br>Time|Overdue|Pending<br>Within<br>Goal|Current<br>Percent<br>on Time|Highest<br>Possible<br>Percent<br>on Time|
|---|---|---|---|---|---|---|---|
|Class 1|2 months|3|3|0|0|83%|88%|
|Class 2|6 months|5|2|1|2|2|2|


**Table 15. FY 2025 Manufacturing Supplements.**


|Manufacturing<br>Supplement Type|Goal: Act on 90<br>Percent Within|Received|On<br>Time|Overdue|Pending<br>Within<br>Goal|Current<br>Percent<br>on Time|Highest<br>Possible<br>Percent<br>on Time|
|---|---|---|---|---|---|---|---|
|Prior Approval<br>Required<br>|4 months|1,667|1,003|42|622|96%|97%|
|Prior Approval<br>Not Required|6 months|1,787|1,049|16|722|98%|99%|
|Review Priority<br>Undesignated*<br>|N/A<br>|0 <br>|--<br>|--<br>|--|--|--|


_Prescription Drug User Fee Act: FY 2025_ _Page 17_


---

#### **IV. PDUFA Procedural and Processing Goals and** **Commitments**

##### **A. Procedural and Processing Workload: FY 2020 to FY 2025**

The FY 2025 procedural and processing workload, which includes activities related to
meeting management, procedural responses, and procedural notifications, is
compared to the previous 5-year averages in Table 16.


New meeting types, specifically Type D meeting and Type INTERACT meeting, were
created under PDUFA VII. These new categories included new meeting metrics for
Type D and Type INTERACT meetings: Requests, Scheduled, Written Response, and
Preliminary Response. Meeting type definitions and other terms can be found in
Appendix E. Additionally, FDA committed to establish timelines for reviewing UseRelated Risk Analysis submissions and Risk Evaluation and Mitigation Strategy
(REMS) Assessment Methods and Protocols beginning in FY 2024. The table shows
updated final FY 2024 performance and presents new reporting required under PDUFA
VII.

The agency notes that undesignated meeting requests have not been assigned a
meeting type prior to the fiscal year closing. Any meeting that was not assigned at the
fiscal year close is considered Type A in Table 16. In subsequent performance
reports, these meetings will be categorized in Table 16 by their assigned meeting type.


**Table 16. Meeting Management, Procedural Responses, and Procedural**
**Notifications Workload.**


|Submission/<br>Request Type|FY<br>2020|FY<br>2021|FY<br>2022|FY<br>2023|FY<br>2024*|FY<br>2025|FY 2020<br>to<br>FY 2024<br>5-Year<br>Average|FY 2025<br>Compared<br>to 5-Year<br>Average|
|---|---|---|---|---|---|---|---|---|
|<br>**Meeting Management**<br>|<br>**Meeting Management**<br>|<br>**Meeting Management**<br>|<br>**Meeting Management**<br>|<br>**Meeting Management**<br>|<br>**Meeting Management**<br>|<br>**Meeting Management**<br>|<br>**Meeting Management**<br>|<br>**Meeting Management**<br>|
|Type A Meeting<br>Requests‡ <br>|182|178|211|176|178|238†|185|29%§|
|<br>Type B Meeting<br>Requests‡ <br>|2,438|2,332|2,174|1,940|1,954|2,016|2,168|-7%|
|<br>Type B(EOP)<br>Meeting Requests‡|350|347|304|301|325|309|325|-5%|


_Prescription Drug User Fee Act: FY 2025_ _Page 18_


---

|Submission/<br>Request Type|FY<br>2020|FY<br>2021|FY<br>2022|FY<br>2023|FY<br>2024*|FY<br>2025|FY 2020<br>to<br>FY 2024<br>5-Year<br>Average|FY 2025<br>Compared<br>to 5-Year<br>Average|
|---|---|---|---|---|---|---|---|---|
|Type C Meeting<br>Requests‡ <br>|1,716|1,706|1,699|1,510|1,534|1,534|<br>1,633|-6%|
|<br>Type D Meeting<br>Requests‡ <br>|--|--|--|390|764|873|--|--|
|<br>Type INTERACT<br>Requests‡ <br>|--|--|--|115|181|217|--|--|
|<br>Type A Meetings<br>Scheduled<br>|147|143|157|140|144|217†|146|49%§|
|<br>Type B Meetings<br>Scheduled<br>|869|741|714|626|829|905|756|20%|
|<br>Type B(EOP)<br>Meetings<br>Scheduled<br>|322|282|259|260|297|277|284|-2%|
|<br>Type C Meetings<br>Scheduled<br>|699|648|619|575|690|700|646|8%|
|<br>Type D Meetings<br>Scheduled¶ <br>|--|--|--|90|192|249|--|--|
|<br>Type INTERACT<br>Meetings<br>Scheduled¶ <br>|--|--|--|28|63|82|--|--|
|<br>Type A Written<br>Response<br>|13|11|19|12|10|10|13|-23%|
|<br>Type B Written<br>Response<br>|1,430|1,451|1,341|1,214|1,044|998|1,296|-23%|
|<br>Type B(EOP)<br>Written Response<br>|23|49|38|30|24|26|33|-21%|
|<br>Type C Written<br>Response<br>|905|918|974|839|786|739|884|-16%|
|<br>Type D Written<br>Response¶ <br>|--|--|--|276|512|559|--|--|
|<br>Type INTERACT<br>Written Response¶ <br>|--|--|--|31|65|81|--|--|
|<br>Preliminary<br>Response for Type<br>B(EOP) Meetings<br>|309|271|246|254|290|258|274|-6%|
|<br>Preliminary<br>Response for Type<br>D Meetings¶ <br>|--|--|--|90|191|240|--|--|
|<br>Preliminary<br>Response for Type<br>INTERACT<br>Meetings¶|--|--|--|28|63|66|--|--|


_Prescription Drug User Fee Act: FY 2025_ _Page 19_


---

|Submission/<br>Request Type|FY<br>2020|FY<br>2021|FY<br>2022|FY<br>2023|FY<br>2024*|FY<br>2025|FY 2020<br>to<br>FY 2024<br>5-Year<br>Average|FY 2025<br>Compared<br>to 5-Year<br>Average|
|---|---|---|---|---|---|---|---|---|
|Meeting Minutes|1,515|1,363|1,281|1,251|1,556|1,587|<br>1,393|14%|
|**Procedural Notifications and Responses** <br>|**Procedural Notifications and Responses** <br>|**Procedural Notifications and Responses** <br>|**Procedural Notifications and Responses** <br>|**Procedural Notifications and Responses** <br>|**Procedural Notifications and Responses** <br>|**Procedural Notifications and Responses** <br>|**Procedural Notifications and Responses** <br>|**Procedural Notifications and Responses** <br>|
|Responses to<br>Clinical Holds<br>|261|275|344|282|288|239|290|-18%|
|<br>Major Dispute<br>Resolutions<br>|35|14|12|19|16|7|19|-63%|
|<br>Special Protocol<br>Assessments<br>|148|150|167|139|107|133|142|-6%|
|<br>Review of<br>Proprietary Names<br>Submitted During<br>IND Phase<br>|224|211|188|154|176|202|191|6%|
|<br>Review of<br>Proprietary Names<br>Submitted During<br>NDA/BLA Phase<br>|255|223|206|239|238|241|232|4%|
|<br>Human Factors<br>Validation Protocol<br>Submissions to<br>NDAs, BLAs, or<br>INDs# <br>|79|79|59|--|--|--|--|--|
|<br>Human Factors<br>Validation Protocol<br>Submissions to<br>INDs¶# <br>|--|--|--|64|61|44|--|--|
|<br>Use-Related Risk<br>Analysis<br>Submissions¶ <br>|--|--|--|--|23|29|--|--|
|<br>REMS Assessment<br>Methods and<br>Protocols¶ <br>|--<br>|--<br>|--<br>|--<br>|129<br>|259<br>|--<br>|--<br>|


report.

- Some meeting requests and the subsequent scheduling of meetings are for requests for which the type cannot
be initially determined. There were 111 undesignated meetings counted as Type A meeting requests and
scheduled in the table above. Performance in all categories will change once designations are made for these
requests and scheduling and will be updated in the FY 2026 PDUFA performance report.

- Excludes meetings withdrawn prior to the meeting granted/denied response goal date.
§ The percentage difference may be inflated due to the inclusion of undesignated meetings.

- Because of changing reporting requirements, no past average is presented for this area.

# Under PDUFA VII, the Performance Goal related to Human Factors Validation Protocol Submissions was
updated to apply only to INDs.


_Prescription Drug User Fee Act: FY 2025_ _Page 20_


---

##### **B. Final FY 2024 Procedural and Processing Performance** **Results**

Table 17 presents the final performance results for FY 2024 submissions in meeting
goals related to meeting management, procedural responses, and procedural
notifications. The final performance results for submission types that met or exceeded
the goal (e.g., 90 percent or more reviews were completed by the goal date) are shown
in bold text. FDA exceeded the performance level for 25 of the 32 procedural and
processing goals in FY 2024.


**Table 17. FY 2024 Final Procedural and Processing Performance Results.**


|Submission/Request Type|Goal: 90<br>Percent|Total|FY 2024<br>Performance|
|---|---|---|---|
|Type A Meeting Requests*|Respond within<br>14 days<br>|165 of 178<br>on time<br>|**93%**|
|Type B Meeting Requests*|<br>Respond within<br>21 days<br>|<br>1,876 of 1,954<br>on time<br>|**96%**|
|Type B(EOP) Meeting Requests*|<br>Respond within<br>14 days<br>|<br>298 of 325<br>on time<br>|**92%**|
|Type C Meeting Requests*|<br>Respond within<br>21 days<br>|<br>1,457 of 1,534<br>on time<br>|**95%**|
|Type D Meeting Requests*|<br>Respond within<br>14 days<br>|<br>706 of 764<br>on time<br>|**92%**|
|Type INTERACT Meeting Requests*|<br>Respond within<br>21 days<br>|<br>163 of 181<br>on time<br>|**90%**|
|Type A Meetings Scheduled|<br>Schedule within<br>30 days<br>|<br>114 of 144<br>on time<br>|79%|
|Type B Meetings Scheduled|<br>Schedule within<br>60 days<br>|<br>664 of 829<br>on time<br>|80%|
|Type B(EOP) Meetings Scheduled|<br>Schedule within<br>70 days<br>|<br>246 of 297<br>on time<br>|83%|
|Type C Meetings Scheduled|<br>Schedule within<br>75 days<br>|<br>601 of 690<br>on time<br>|87%|
|Type A Written Response|<br>Send within 30<br>days<br>|<br>6 of 10<br>on time<br>|60%|
|Type B Written Response|<br>Send within 60<br>days<br>|<br>924 of 1,044<br>on time<br>|89%|
|Type B(EOP) Written Response|<br>Send within 70<br>days<br>|<br>24 of 24<br>on time<br>|**100%**|
|Type C Written Response|<br>Send within 75<br>days|<br>706 of 786<br>on time|**90%**|


_Prescription Drug User Fee Act: FY 2025_ _Page 21_


---

|Submission/Request Type|Goal: 90<br>Percent|Total|FY 2024<br>Performance|
|---|---|---|---|
|Preliminary Response for Type B(EOP)<br>Meetings|Issue no later<br>than 5 days prior<br>to meeting date<br>|267 of 290<br>on time|**92%**|
|Preliminary Response for Type D Meetings|<br>Issue no later<br>than 5 days prior<br>to meeting date<br>|180 of 191<br>on time|**94%**|
|Preliminary Response for Type INTERACT<br>Meetings|<br>Issue no later<br>than 5 days prior<br>to meeting date<br>|59 of 63<br>on time|**94%**|
|Meeting Minutes|<br>Issue within 30<br>days after<br>meeting date<br>|1,464 of 1,556<br>on time<br>|**94%**|
|Responses to Clinical Holds|<br>Respond within<br>30 days<br>|263 of 288<br>on time<br>|**91%**|
|Major Dispute Resolutions|<br>Respond within<br>30 days<br>|<br>15 of 16<br>on time|**94%**|
|Special Protocol Assessments|<br>Complete and<br>return within 45<br>days<br>|<br>102 of 107<br>on time|**95%**|
|Proprietary Name Submitted During IND Phase|<br>Review and<br>notify of tentative<br>acceptance or<br>non-acceptance<br>within 180 days<br>|169 of 176<br>on time|**96%**|
|Proprietary Name Submitted During NDA/BLA<br>Phase|<br>Review and<br>notify of tentative<br>acceptance or<br>non-acceptance<br>within 90 days<br>|230 of 238<br>on time|**97%**|
|Human Factors Validation Protocol<br>Submissions to INDs<br>|<br>Review and<br>provide<br>comments within<br>60 days<br>|44 of 61<br>on time<br>|72%|


|Submission/Request Type|Goal: 60<br>Percent|Total|FY 2024<br>Performance|
|---|---|---|---|
|Type D Meetings Scheduled|Schedule within<br>50 days<br>|169 of 192<br>on time<br>|**88%**|
|Type INTERACT Scheduled|<br>Schedule within<br>75 days<br>|<br>61 of 63<br>on time<br>|**97%**|
|Type D Written Response|<br>Send within 50<br>days|<br>461 of 512<br>on time|**90%**|


_Prescription Drug User Fee Act: FY 2025_ _Page 22_


---

|Submission/Request Type|Goal: 60<br>Percent|Total|FY 2024<br>Performance|
|---|---|---|---|
|Type INTERACT Written Response<br>|Send within 75<br>days|63 of 65<br>on time|**97%**|


|Submission/Request Type|Goal: 50<br>Percent|Total|FY 2024<br>Performance|
|---|---|---|---|
|Use-Related Risk Analysis Submissions|Review and<br>respond within<br>60 days<br>|20 of 23<br>on time|**87%**|
|REMS Assessment Methods and Protocols<br>|<br>Review and<br>respond within<br>90 days|86 of 129<br>on time|**67%**|


|Application Type|Goal: 70<br>Percent|Total|FY 2024<br>Performance|
|---|---|---|---|
|Priority NME NDAs and Original BLAs<br>Approved with PMRs*|Communicate<br>anticipated<br>PMRs 6 weeks<br>prior to action<br>goal date<br>|20 of 26<br>on time|**77%**|
|Standard NME NDAs and Original BLAs<br>Approved with PMRs*<br>|<br>Communicate<br>anticipated<br>PMRs 8 weeks<br>prior to action<br>goal date<br>|13 of 14 on<br>time<br>|**93%**<br>|


2024 and approved with PMRs, regardless of approval date.


##### **C. Final FY 2024 Procedural and Processing Performance** **Details**

Tables 18 to 27 detail the final performance data for the FY 2024 cohort of
submissions. These data include the number of submissions reviewed _On Time_ (i.e.,
acted on by the PDUFA goal date) or _Overdue_ (i.e., acted on past the goal date or
pending past the goal date) and the final _Percent On Time_ (i.e., final performance with
no actions pending within the PDUFA goal date). The performance data presented
here have been updated from the preliminary performance information reported in the
FY 2024 PDUFA performance report.


_Prescription Drug User Fee Act: FY 2025_ _Page 23_


---

**Table 18. FY 2024 Meeting Management.**


|Type|Goal: 90<br>Percent|Received*|On Time|Overdue|Percent<br>on Time|
|---|---|---|---|---|---|
|Type A Meeting Requests†|Respond<br>within 14 days|178|165|13|93%|
|Type B Meeting Requests†|Respond<br>within 21 days|1,954|1,876|78|96%|
|Type B(EOP) Meeting<br>Requests†|Respond<br>within 14 days|325|298|27|92%|
|Type C Meeting Requests†|Respond<br>within 21 days|1,534|1,457|77|95%|
|Type D Meeting Requests†|Respond<br>within 14 days|764|706|58|92%|
|Type INTERACT Meeting<br>Requests†|Respond<br>within 21 days|181|163|18|90%|
|Type A Meetings<br>Scheduled|Schedule<br>within 30 days|144|114|30|79%|
|Type B Meetings<br>Scheduled|Schedule<br>within 60 days|829|664|165|80%|
|Type B(EOP) Meetings<br>Scheduled|Schedule<br>within 70 days|297|246|51|83%|
|Type C Meetings<br>Scheduled|Schedule<br>within 75 days|690|601|89|87%|
|Type A Written Response|Send within<br>30 days|10|6|4|60%|
|Type B Written Response|Send within<br>60 days|1,044|924|120|89%|
|Type B(EOP) Written<br>Response|Send within<br>70 days|24|24|0|100%|
|Type C Written Response|Send within<br>75 days<br>|786|706|80|90%|
|Preliminary Response for<br>Type B(EOP) Meetings|Issue no later<br>than 5 days<br>prior to<br>meeting date|290|267|23|92%|
|Preliminary Response for<br>Type D Meetings|<br>Issue no later<br>than 5 days<br>prior to<br>meeting date|191|180|11|94%|


_Prescription Drug User Fee Act: FY 2025_ _Page 24_


---

|Type|Goal: 90<br>Percent|Received*|On Time|Overdue|Percent<br>on Time|
|---|---|---|---|---|---|
|Preliminary Response for<br>Type INTERACT Meetings|Issue no later<br>than 5 days<br>prior to<br>meeting date<br>|63|59|4|94%|
|Meeting Minutes<br>|<br>Issue within<br>30 days after<br>meeting date<br>|1,556<br>|1,464<br>|92<br>|94%<br>|


number of meeting requests received. Not all scheduled meetings are held; therefore, the number of
meeting minutes may differ from the number of meetings scheduled.

- Excludes meetings withdrawn prior to the meeting granted/denied response goal date.


|Type|Goal: 60<br>Percent|Received*|On Time|Overdue|Percent<br>on Time|
|---|---|---|---|---|---|
|Type D Meetings<br>Scheduled|Schedule<br>within 50 days|192|169|23|88%|
|Type INTERACT<br>Scheduled|Schedule<br>within 75 days|63|61|2|97%|
|Type D Written Response|Send within<br>50 days|512|461|51|90%|
|Type INTERACT Written<br>Response<br>|Send within<br>75 days<br>|65<br>|63<br>|2 <br>|97%<br>|


of meeting requests received. Not all scheduled meetings are held; therefore, the number of meeting minutes
may differ from the number of meetings scheduled.


**Table 19. FY 2024 Responses to Clinical Holds.**

|Goal<br>Respond to 90 percent within<br>30 days|Received|On Time|Overdue|Percent on<br>Time|
|---|---|---|---|---|
|**Goal**<br>Respond to 90 percent within<br>30 days|288|263|25|<br>91%|


**Table 20. FY 2024 Major Dispute Resolutions.**


|Goal|Responses*|On Time|Overdue|Percent on<br>Time|
|---|---|---|---|---|
|Respond to 90 percent within<br>30 days <br>|16<br>|15<br>|1 <br>|<br>94%<br>|


received. This figure is not representative of the number of unique appeals received that have been reviewed
as there may be more than one response to an original appeal.


_Prescription Drug User Fee Act: FY 2025_ _Page 25_


---

**Table 21. FY 2024 Special Protocol Assessments.**

|Goal|Received|On Time|Overdue|Percent on<br>Time|
|---|---|---|---|---|
|Complete and return 90<br>percent within 45 days|107|102|5|<br>95%|


**Table 22. FY 2024 Special Protocol Assessments Resubmissions.**


|SPAs with<br>Resubmissions|Applications<br>with 1<br>Resubmission|Applications<br>with 2<br>Resubmissions|Applications<br>with 3<br>Resubmissions|Applications<br>with 4<br>Resubmissions|Total<br>Resubmissions|
|---|---|---|---|---|---|
|19|<br>16|<br>3|<br>0|<br>0|22|


**Table 23. FY 2024 Drug/Biological Product Proprietary Names.**


|Submission Type|Goal: 90<br>Percent|Received|On Time|Overdue|Percent<br>on Time|
|---|---|---|---|---|---|
|Proprietary Name<br>Submitted During IND<br>Phase|<br>Review and<br>notify of<br>tentative<br>acceptance or<br>non-acceptance<br>within 180 days<br>|176|169|7|<br>96%|
|Proprietary Name<br>Submitted During NDA/BLA<br>Phase|<br>Review and<br>notify of<br>tentative<br>acceptance or<br>non-acceptance<br>within 90 days|238|230|8|97%|


**Table 24. FY 2024 Human Factors Validation Protocol Submissions.**


|Submission Type|Goal: 90<br>Percent|Received|On Time|Overdue|Percent<br>on Time|
|---|---|---|---|---|---|
|Human Factors Validation<br>Protocol Submissions to<br>INDs|<br>Review and<br>provide<br>comments<br>within 60 days|61|44|17|<br>72%|


_Prescription Drug User Fee Act: FY 2025_ _Page 26_


---

**Table 25. FY 2024 Use-Related Risk Analysis Submissions.**


|Submission Type|Goal: 50<br>Percent|Received|On Time|Overdue|Percent<br>on Time|
|---|---|---|---|---|---|
|Use-Related Risk<br>Analysis<br>Submissions<br>|Review<br>and<br>respond<br>within 60<br>days|23|20|3|87%|


**Table 26. FY 2024 REMS Assessment Methods and Protocols.**


|Submission Type|Goal: 50<br>Percent|Received|On Time|Overdue|Percent<br>on Time|
|---|---|---|---|---|---|
|REMS Assessment<br>Methods and<br>Protocols|Review<br>and<br>respond<br>within 90<br>days|129<br>|86|43|67%|


**Table 27. FY 2024 Communication of Anticipated Postmarketing Requirements**
**(PMRs).**


|Application Type|Goal: 70<br>Percent|Approved<br>Applications<br>with PMRs|On Time*|Overdue†|Percent<br>on Time|
|---|---|---|---|---|---|
|Priority NME NDAs and<br>Original BLAs Approved with<br>PMRs‡|<br>Communicate<br>anticipated<br>PMRs 6 weeks<br>prior to action<br>goal date<br>|<br>26|20|6|77%|
|Standard NME NDAs and<br>Original BLAs Approved with<br>PMRs‡ <br>|<br> <br>Communicate<br>anticipated<br>PMRs 8 weeks<br>prior to action<br>goal date<br>|14<br>|13<br>|1 <br>|93%<br>|


communicated by the 6- or 8-week goal date.


_Prescription Drug User Fee Act: FY 2025_ _Page 27_


---

- _Overdue_ refers to the number of approved applications with PMRs where the PMRs required at approval were not
communicated by the 6- or 8-week goal date.

- Data reflect the communication of anticipated PMRs for NME NDAs and Original BLAs that were received in FY
2024 and approved with PMRs, regardless of approval date.

##### **D. Preliminary FY 2025 Procedural and Processing Performance** **Results**


Table 28 presents preliminary performance results for FY 2025 submissions in
achieving goals related to meeting management, procedural responses, and
procedural notifications as outlined under PDUFA VII.


  - The _progress_ (i.e., the number of review activities completed or pending
overdue) and the total number of submissions received for each submission
type are shown in the second column. _Current performance_ includes the
number of submissions reviewed _on time_ (i.e., acted on by the PDUFA goal
date) or _overdue_ (i.e., acted on past the goal date or pending past the goal
date). _Highest possible final performance_ is the best potential final performance
result, which accounts for actions pending within the PDUFA goal date.

  - The current performance results for submission types that are meeting the
performance goal as of September 30, 2025, are shown in bold text. FDA is
currently meeting or exceeding the performance level for 24 of the 31 applicable
procedural and processing goals (e.g., 90 percent or more reviews were
completed by the goal date). There are 32 procedural and processing goals, but
only 31 had applicable submissions. If all pending submissions are reviewed on
time, FDA has the potential to meet 26 of the 30 applicable goals, as seen in the
Highest Possible Final Performance column. [5]


5 The highest potential performance is not calculated for the two PMR goals as it is not possible to
accurately predict the number of pending submissions that will be approved with PMRs.


_Prescription Drug User Fee Act: FY 2025_ _Page 28_


---

**Table 28. FY 2025 Preliminary Procedural and Processing Performance Results.**


|Submission/Request Type|Progress|Goal: 90<br>Percent|FY 2025<br>Current<br>Performance|Highest<br>Possible<br>Final<br>Performance|
|---|---|---|---|---|
|Type A Meeting Requests*†|129 of 238<br>complete<br>|Respond<br>within 14<br>days<br>|**94%**|97%|
|Type B Meeting Requests*|1,976 of<br>2,016<br>complete|<br>Respond<br>within 21<br>days<br>|**98%**|98%|
|Type B(EOP) Meeting<br>Requests*|<br>302 of 309<br>complete<br>|<br>Respond<br>within 14<br>days<br>|**93%**|93%|
|Type C Meeting Requests*|1,512 of<br>1,534<br>complete|<br>Respond<br>within 21<br>days<br>|**97%**|97%|
|Type D Meeting Requests*|<br>866 of 873<br>complete|<br>Respond<br>within 14<br>days<br>|**92%**|92%|
|Type INTERACT Requests*|211 of 217<br>complete|<br>Respond<br>within 21<br>days<br>|**95%**|95%|
|Type A Meetings Scheduled†|106 of 217<br>complete|<br>Schedule<br>within 30<br>days<br>|79%|90%|
|Type B Meetings Scheduled|838 of 905<br>complete|<br>Schedule<br>within 60<br>days<br>|83%|85%|
|Type B(EOP) Meetings<br>Scheduled|265 of 277<br>complete|<br>Schedule<br>within 70<br>days<br>|**91%**|91%|
|Type C Meetings Scheduled|662 of 700<br>complete<br>|<br>Schedule<br>within 75<br>days<br>|87%|88%|
|Type A Written Response|10 of 10<br>complete<br>|<br>Send within<br>30 days<br>|**90%**|90%|
|Type B Written Response<br>|<br>844 of 998<br>complete<br>|<br>Send within<br>60 days<br>|85%|87%|
|Type B(EOP) Written<br>Response|<br>22 of 26<br>complete<br>|<br>Send within<br>70 days<br>|**91%**|92%|
|<br>Type C Written Response|<br>597 of 739<br>complete|<br>Send within<br>75 days|88%|90%|


_Prescription Drug User Fee Act: FY 2025_ _Page 29_


---

|Submission/Request Type|Progress|Goal: 90<br>Percent|FY 2025<br>Current<br>Performance|Highest<br>Possible<br>Final<br>Performance|
|---|---|---|---|---|
|Preliminary Response for<br>Type B(EOP) Meetings|209 of 258<br>complete|Issue no later<br>than 5 days<br>prior to<br>meeting date<br>|**97%**|97%|
|Preliminary Response for<br>Type D Meetings|216 of 240<br>complete|<br>Issue no later<br>than 5 days<br>prior to<br>meeting date<br>|**97%**|98%|
|Preliminary Response for<br>Type INTERACT Meetings|63 of 66<br>complete|<br>Issue no later<br>than 5 days<br>prior to<br>meeting date|**98%**|98%|
|Meeting Minutes|1,197 of<br>1,587<br>complete|<br>Issue within<br>30 days after<br>meeting date<br>|**96%**|97%|
|Responses to Clinical Holds|222 of 239<br>complete|Respond<br>within 30<br>days<br>|89%|90%|
|Major Dispute Resolutions|6 of 7<br>complete|<br>Respond<br>within 30<br>days<br>|**100%**|100%|
|Special Protocol<br>Assessments|121 of 133<br>complete|<br>Complete<br>and return<br>within 45<br>days<br>|**97%**|97%|
|Proprietary Name Submitted<br>During IND Phase|99 of 202<br>complete|<br>Review and<br>notify of<br>tentative<br>acceptance<br>or non-<br>acceptance<br>within 180<br>days<br>|**97%**|99%|
|Proprietary Name Submitted<br>During NDA/BLA Phase|198 of 241<br>complete|<br>Review and<br>notify of<br>tentative<br>acceptance<br>or non-<br>acceptance<br>within 90<br>days|**94%**|95%|


_Prescription Drug User Fee Act: FY 2025_ _Page 30_


---

|Submission/Request Type|Progress|Goal: 90<br>Percent|FY 2025<br>Current<br>Performance|Highest<br>Possible<br>Final<br>Performance|
|---|---|---|---|---|
|Human Factors Validation<br>Protocol Submissions to<br>INDs<br>|36 of 44<br>complete<br>|Review and<br>provide<br>comments<br>within 60<br>days<br>|86%<br>|89%|


- Some meeting requests and subsequent scheduling of meetings are for requests for which the type cannot be
initially determined. There were 111 undesignated meetings counted as Type A meeting requests and
scheduled in the table above. Performance in all categories will change once designations are made for these
requests and scheduling and will be updated in the FY 2025 PDUFA performance report.


|Submission/Request Type|Progress|Goal: 70<br>Percent|FY 2025<br>Current<br>Performance|Highest<br>Possible<br>Final<br>Performance|
|---|---|---|---|---|
|Type D Meetings Scheduled|239 of 249<br>complete|Schedule<br>within 50<br>days<br>|**93%**|<br>93%|
|Type INTERACT Scheduled|63 of 82<br>complete<br>|<br>Schedule<br>within 75<br>days<br>|**84%**|88%|
|Type D Written Response<br>|494 of 559<br>complete<br>|<br>Send within<br>50 days<br>|**91%**|92%|
|Type INTERACT Written<br>Response|<br>65 of 81<br>complete|<br>Send within<br>75 days<br>|**91%**|93%|
|<br>Use-Related Risk Analysis<br>Submissions|<br>21 of 29<br>complete|<br>Review and<br>respond<br>within 60<br>days<br>|**81%**|86%|
|REMS Assessment Methods<br>and Protocols<br>|220 of 259<br>complete|<br>Review and<br>respond<br>within 90<br>days|**85%**|87%|


_Prescription Drug User Fee Act: FY 2025_ _Page 31_


---

|Application Type|Progress|Goal: 80<br>Percent|FY 2025<br>Current<br>Performance|Highest<br>Possible<br>Final<br>Performance|
|---|---|---|---|---|
|Priority NME NDAs and<br>Original BLAs Approved with<br>PMRs*|10 of 10<br>complete|Communicate<br>anticipated<br>PMRs 6<br>weeks prior<br>to action goal<br>date<br>|**80%**|<br>N/A†|
|Standard NME NDAs and<br>Original BLAs Approved with<br>PMRs*<br>|0 of 0<br>complete<br>|<br>Communicate<br>anticipated<br>PMRs 8<br>weeks prior<br>to action goal<br>date<br>|N/A‡ <br>|N/A† <br>|


2025 and approved with PMRs, regardless of approval date.

- The highest possible final performance is not calculated for the two PMR goals as it is not possible to accurately
predict the number of pending submissions that will be approved with PMRs.

- Performance goal does not apply because no submissions were received.


##### **E. Preliminary FY 2025 Procedural and Processing** **Performance Details**

The following detailed performance information for FY 2025 cohort submissions
includes the number of submissions _received_, reviewed _on time_ (i.e., acted on by the
PDUFA goal date), and _overdue_ (i.e., acted on past the goal date or pending past the
goal date). The number of submissions not yet acted on but still pending within the
PDUFA goal date ( _Pending Within Goal_ ) is also provided, along with the highest
possible percent of reviews that may be completed on time ( _Highest Possible Percent_
_on Time_ ).


**Table 29. FY 2025 Meeting Management.**


|Type|Goal: 90<br>Percent|Received*|On<br>Time|Overdue|Pending<br>Within<br>Goal|Current<br>Percent<br>on Time|Highest<br>Possible<br>Percent<br>on Time|
|---|---|---|---|---|---|---|---|
|Type A Meeting<br>Requests†‡|Respond<br>within 14<br>days|238|121|8|109|94%|97%|


_Prescription Drug User Fee Act: FY 2025_ _Page 32_


---

|Type|Goal: 90<br>Percent|Received*|On<br>Time|Overdue|Pending<br>Within<br>Goal|Current<br>Percent<br>on Time|Highest<br>Possible<br>Percent<br>on Time|
|---|---|---|---|---|---|---|---|
|Type B Meeting<br>Requests‡ <br>|Respond<br>within 21<br>days<br>|2,016|1,927|49|40|98%|98%|
|Type B(EOP)<br>Meeting<br>Requests‡|<br>Respond<br>within 14<br>days<br>|309|281|21|7|93%|93%|
|<br>Type C Meeting<br>Requests‡|<br>Respond<br>within 21<br>days<br>|1,534|1,465|47|22|97%|97%|
|Type D Meeting<br>Requests‡ <br>|<br>Respond<br>within 14<br>days<br>|873|795|71|7|92%|92%|
|Type INTERACT<br>Meeting<br>Requests‡|<br>Respond<br>within 21<br>days<br>|217|201|10|6|95%|95%|
|<br>Type A Meetings<br>Scheduled†|<br>Schedule<br>within 30<br>days<br>|217|84|22|111|79%|90%|
|Type B Meetings<br>Scheduled<br>|<br>Schedule<br>within 60<br>days<br>|905|699|139|67|83%|85%|
|Type B(EOP)<br>Meetings<br>Scheduled|<br>Schedule<br>within 70<br>days<br>|277|240|25|12|91%|91%|
|<br>Type C Meetings<br>Scheduled|<br>Schedule<br>within 75<br>days<br>|700|577|85|38|87%|88%|
|Type A Written<br>Response|<br>Send<br>within 30<br>days<br>|10|9|1|0|90%|90%|
|Type B Written<br>Response|<br>Send<br>within 60<br>days<br>|998|718|126|154|85%|87%|
|Type B(EOP)<br>Written Response|<br>Send<br>within 70<br>days<br>|26|20|2|4|91%|92%|
|Type C Written<br>Response|<br>Send<br>within 75<br>days|739|523|74|142|88%|90%|


_Prescription Drug User Fee Act: FY 2025_ _Page 33_


---

|Type|Goal: 90<br>Percent|Received*|On<br>Time|Overdue|Pending<br>Within<br>Goal|Current<br>Percent<br>on Time|Highest<br>Possible<br>Percent<br>on Time|
|---|---|---|---|---|---|---|---|
|Preliminary<br>Response for<br>Type B(EOP)<br>Meetings|Issue no<br>later than 5<br>days prior<br>to meeting<br>date<br>|258|202|7|49|97%|97%|
|Preliminary<br>Response for<br>Type D Meetings|<br>Issue no<br>later than 5<br>days prior<br>to meeting<br>date|240|210|6|24|97%|98%|
|Preliminary<br>Response for<br>Type INTERACT<br>Meetings|<br>Issue no<br>later than 5<br>days prior<br>to meeting<br>date<br>|66|62|1|3|98%|98%|
|Meeting Minutes<br>|Issue<br>within 30<br>days after<br>meeting<br>date<br>|1,587<br>|1,147<br>|50<br>|390<br>|96%<br>|97%<br>|


meeting requests received. Not all scheduled meetings are held; therefore, the number of meeting minutes may
differ from the number of meetings scheduled.

- Some meeting requests and subsequent scheduling of meetings are for requests for which the type cannot be initially
determined. There were 111 undesignated meetings counted as Type A meeting requests and scheduled in the table
above. Performance in all categories will change once designations are made for these requests and scheduling and
will be updated in the FY 2026 PDUFA performance report.

- Excludes meetings withdrawn prior to the meeting granted/denied response goal date.


|Type|Goal: 70<br>Percent|Received*|On<br>Time|Overdue|Pending<br>Within<br>Goal|Current<br>Percent<br>on Time|Highest<br>Possible<br>Percent<br>on Time|
|---|---|---|---|---|---|---|---|
|Type D Meetings<br>Scheduled|Schedule<br>within 50<br>days<br>|249|222|17|10|93%|93%|
|Type INTERACT<br>Scheduled<br>|<br>Schedule<br>within 75<br>days<br>|82|53|10|19|84%|88%|
|Type D Written<br>Response<br>|<br>Send within<br>50 days<br>|559|449|45|65|91%|92%|
|<br>Type INTERACT<br>Written Response|<br>Send within<br>75 days|81|59|6|16|91%|93%|


_Prescription Drug User Fee Act: FY 2025_ _Page 34_


---

- Not all meeting requests are granted; therefore, the number of meetings scheduled may differ from the number of
meeting requests received. Not all scheduled meetings are held; therefore, the number of meeting minutes may differ
from the number of meetings scheduled.


**Table 30. FY 2025 Responses to Clinical Holds.**


|Submission<br>Type|Goal|Received|On Time|Overdue|Pending<br>Within<br>Goal|Current<br>Percent<br>on Time|Highest<br>Possible<br>Percent<br>on Time|
|---|---|---|---|---|---|---|---|
|Responses<br>to Clinical<br>Holds|Respond to 90<br>percent within 30<br>days|239|197|25|17|89%|90%|


**Table 31. FY 2025 Major Dispute Resolutions.**


|Submission<br>Type|Goal|Responses*|On Time|Overdue|Pending<br>Within<br>Goal|Current<br>Percent<br>on Time|Highest<br>Possible<br>Percent<br>on Time|
|---|---|---|---|---|---|---|---|
|Major<br>Dispute<br>Resolutions<br>|Respond to 90<br>percent within 30<br>days<br>|7 <br>|6 <br>|0 <br>|1 <br>|100%<br>|100%<br>|


representative of the number of unique appeals received that have been reviewed as there may be more than one response to an
original appeal.


**Table 32. FY 2025 Special Protocol Assessments.**


|Submission<br>Type|Goal|Received|On Time|Overdue|Pending<br>Within<br>Goal|Current<br>Percent<br>on Time|Highest<br>Possible<br>Percent<br>on Time|
|---|---|---|---|---|---|---|---|
|Special<br>Protocol<br>Assessments|Complete and<br>return 90 percent<br>within 45 days|133|117|4|12|97%|97%|


_Prescription Drug User Fee Act: FY 2025_ _Page 35_


---

**Table 33. FY 2025 Special Protocol Assessments Resubmissions.**


|SPAs with<br>Resubmissions|Applications<br>with 1<br>Resubmission|Applications<br>with 2<br>Resubmissions|Applications<br>with 3<br>Resubmissions|Applications<br>with 4<br>Resubmissions|Total<br>Resubmissions|
|---|---|---|---|---|---|
|16|12|4|0|0|20|


**Table 34. FY 2025 Drug/Biological Product Proprietary Names.**


|Submission Type|Goal: 90<br>Percent|Received|On Time|Overdue|Pending<br>Within<br>Goal|Current<br>Percent<br>on Time|Highest<br>Possible<br>Percent<br>on Time|
|---|---|---|---|---|---|---|---|
|Proprietary Name<br>Submitted During<br>IND Phase|Review and notify<br>of tentative<br>acceptance or<br>non-acceptance<br>within 180 days|202|96|3|103|97%|99%|
|Proprietary Name<br>Submitted During<br>NDA/BLA Phase|Review and notify<br>of tentative<br>acceptance or<br>non-acceptance<br>within 90 days|241|187|11|43|94%|95%|


**Table 35. FY 2025 Human Factors Validation Protocol Submissions.**


|Submission Type|Goal: 90<br>Percent|Received|On Time|Overdue|Pending<br>Within<br>Goal|Current<br>Percent<br>on Time|Highest<br>Possible<br>Percent<br>on Time|
|---|---|---|---|---|---|---|---|
|Human Factors<br>Validation Protocol<br>Submissions to<br>INDs|Review<br>and<br>provide<br>comments<br>within 60<br>days|44|31|5|8|86%|89%|


_Prescription Drug User Fee Act: FY 2025_ _Page 36_


---

**Table 36. FY 2025 Use-Related Risk Analysis Submissions.**


|Submission Type|Goal: 70<br>Percent|Received|On Time|Overdue|Pending<br>Within<br>Goal|Current<br>Percent<br>on Time|Highest<br>Possible<br>Percent<br>on Time|
|---|---|---|---|---|---|---|---|
|Use-Related Risk<br>Analysis<br>Submissions|Review<br>and<br>respond<br>within 60<br>days|29|17<br>|4|8|81%|86%|


**Table 37. FY 2025 REMS Assessment Methods and Protocols.**


|Submission Type|Goal: 70<br>Percent|Received|On Time|Overdue|Pending<br>Within<br>Goal|Current<br>Percent<br>on Time|Highest<br>Possible<br>Percent<br>on Time|
|---|---|---|---|---|---|---|---|
|REMS Assessment<br>Methods and<br>Protocols<br>|Review<br>and<br>respond<br>within 90<br>days|259|187|33|39|85%|87%|


**Table 38. FY 2025 Communication of Anticipated Postmarketing Requirements**
**(PMRs).**


|Application Type|Goal: 80<br>Percent|Approved<br>Applications<br>with PMRs|On Time*|Overdue†|Current<br>Percent<br>on Time|
|---|---|---|---|---|---|
|Priority NME NDAs and<br>Original BLAs Approved with<br>PMRs‡|Communicate<br>anticipated<br>PMRs 6 weeks<br>prior to action<br>goal date<br>|<br>10|8|2|<br>80%|
|Standard NME NDAs and<br>Original BLAs Approved with<br>PMRs‡ <br>|<br>Communicate<br>anticipated<br>PMRs 8 weeks<br>prior to action<br>goal date<br>|0 <br>|0 <br>|0 <br>|N/A**<br>|


communicated by the 6- or 8-week goal date.


_Prescription Drug User Fee Act: FY 2025_ _Page 37_


---

- _Overdue_ refers to the number of approved applications with PMRs where the PMRs required at approval were not
communicated by the 6- or 8-week goal date.

- Data reflect the communication of anticipated PMRs for NME NDAs and Original BLAs that were received in FY
2025 and approved with PMRs, regardless of approval date.
** Performance goal does not apply because no submissions were received.


_Prescription Drug User Fee Act: FY 2025_ _Page 38_


---

#### **V. PDUFA Trend Graphs**

##### **A. Total NDAs and BLAs Filed**

The number of NDAs and BLAs filed from FY 2016 to FY 2025 is presented in Figure
1. The total number of all original applications (NDAs and BLAs) filed in FY 2025
increased from the number filed in FY 2024.


**Figure 1. Total NDAs and BLAs Filed.**


Standard


220

200

180

160

140

120

100

80

60

40

20

0


FY
2016


FY
2017


FY
2018


FY
2019


FY
2020


FY
2021


FY
2022


FY
2023


FY
2024*


FY
2025†


**Fiscal Year of Receipt**


       - FY 2024 numbers were changed to reflect updates to the data presented in the FY
2024 PDUFA performance report.

       - Some applications filed in FY 2025 have not yet received a review priority

designation. The undesignated NDAs and BLAs are counted as Priority NDAs and
BLAs. Designation may change and the table will then be updated accordingly, as
appropriate, in the FY 2026 PDUFA performance report.


_Prescription Drug User Fee Act: FY 2025_ _Page 39_


---

##### **B. Median Total Times to Approval**

The median total times to approval for priority and standard applications received from
FY 2016 through FY 2025 are presented in the graph below. [6] The data represented in
Figure 2 are updated based on the approvals reported in Appendix A. The increase in
median time to approval for standard applications in FY2023 was due, in part, to a
higher proportion of the applications in that year having NME goals, many of which also
had 3-month extensions, leading to a median time that was much higher compared to
other years.


**Figure 2. Median Time to Application Approval for First Approval NDAs and**
**BLAs (Months).** **[†]**


16.0


14.0


12.0


10.0


8.0


6.0


4.0


2.0


0.0


FY 2016 FY 2017 FY 2018 FY 2019 FY 2020 FY 2021 FY 2022 FY 2023* FY 2024* FY 2025*

**Fiscal Year of Application Approval**


  - The median approval times for the 3 most recent years are estimated.

  - The data represented in this figure are based on the approvals reported in Appendix A.

##### **C. Percent of NDAs and BLAs Approved on the First Cycle**


Figure 3 depicts the percentages of priority and standard NDAs and BLAs approved in
the first review cycle for the receipt cohorts from FY 2015 to FY 2024. These


6 The _median time to application approval_ is calculated from the date of receipt to the date of first approval. For
applications with both tentative and full approvals, the first tentative approval date is used to calculate the median
response time. Applications approved in the first cycle include only FDA review time, while those approved after
multiple cycles include both FDA and sponsor response times.


_Prescription Drug User Fee Act: FY 2025_ _Page 40_


---

percentages are based on the approvals reported in Appendix A. The percentage of
standard applications in first-cycle approvals increased in FY 2024. For the FY 2024
cohort, which is still preliminary, 68 percent of standard applications were approved on
the first cycle. First-cycle approvals for approved priority applications decreased in FY
2024, with 76 percent of approved priority applications being approved on the first
cycle. The FY 2025 data are too preliminary to estimate the percent of first-cycle
approvals.


**Figure 3. Percent of NDAs and BLAs Approved on the First Cycle.** **[†]**


100%

90%

80%

70%

60%

50%

40%

30%

20%

10%

0%


FY 2015 FY 2016 FY 2017 FY 2018 FY 2019 FY 2020 FY 2021 FY 2022 FY 2023 FY 2024*

**Fiscal Year of Application Receipt** **[‡]**


   - First-cycle approvals are still possible for FY 2024 standard applications, so the data are preliminary.

   - The data were changed to reflect updates to the data presented in the FY 2024 PDUFA performance report.

   - The data represented in this graph are based on the approvals reported in Appendix A.


_Prescription Drug User Fee Act: FY 2025_ _Page 41_


---

#### **VI. Additional PDUFA VII Commitments**

Under Section VI (“Progress reporting for PDUFA VII and Continuing PDUFA VI
initiatives”) of the PDUFA VII Commitment Letter, FDA committed to report its progress
on the specific commitments identified in the following sections of the Commitment
Letter: [7]

  - Section I.A: Review Performance Goals

  - Section I.B: Program for Review Transparency and Communication for NME
NDAs and Original BLAs

  - Section I.C: New Molecular Entity (NME) Milestones and Postmarketing
Requirements (PMRs)

  - Section I.D: Split Real Time Application Review (STAR) Pilot Program

  - Section I.E: Expedited Reviews

  - Section I.F: Review of Proprietary Names to Reduce Medication Errors

  - Section I.G: Major Dispute Resolutions

  - Section I.H: Clinical Holds

  - Section I.I: Special Protocol Assessment and Agreement

  - Section I.J: Meeting Management Goals

  - Section I.K: Enhancing Regulatory Science and Expediting Drug Development

  - Section I.L: Enhancing Regulatory Decision Tools to Support Drug
Development and Review

  - Section I.M: Enhancement and Modernization of the FDA Drug Safety System


[7 See the PDUFA VII Commitment Letter at https://www.fda.gov/media/151712/download.](https://www.fda.gov/media/151712/download)


_Prescription Drug User Fee Act: FY 2025_ _Page 42_


---

  - Section I.N: Enhancing Related to Product Quality Reviews, Chemistry,
Manufacturing, and Control Approaches, and Advancing the Utilization of
Innovative Manufacturing Technologies

  - Section I.O: Enhancing CBER’s Capacity to Support Development, Review, and
Approval of Cell and Gene Therapy Products

  - Section I.P: Supporting Review of New Allergenic Extract Products

  - Section II: Continued Enhancement of User Fee Resource Management

  - Section III: Improving FDA Hiring and Retention of Review Staff

  - Section IV: Information Technology and Bioinformatics Goals

Further, section 736B(a) of the FD&C Act, as amended by section 103 of the FDA
Reauthorization Act of 2017 (FDARA), requires FDA to report on the Agency’s
performance under PDUFA VII.

FDA and industry designed these enhancements to improve the efficiency of drug
development and the human drug review process. The progress reports in this section
detail the work FDA performed in FY 2025 with updates on commitments in respective
sections of the Commitment Letter cited above in the list. Each accomplishment
includes a reference to a specific section of the Commitment Letter. External
references are also provided to published guidances, meeting summaries, and other
pertinent public information.

FDA is dedicated to the goals outlined in these sections of the Commitment Letter.
When applicable, for each section, additional information is included on other activities
FDA has conducted that are not specifically committed but further the goals outlined in
the Commitment Letter.


_Prescription Drug User Fee Act: FY 2025_ _Page 43_


---

##### **A. Section I.A – I.J: Human Drug Review Program and** **Meeting Management**

**Table 39. Section I.A - I.J’s FY 2025 Commitments and Accomplishments.**


|Commitment Title|FY 2025 Accomplishments|
|---|---|
|I.A Review Performance<br>Goals|• <br>There were no commitments due|
|I.B Program for Enhanced<br>Review Transparency and<br>Communication for NME<br>NDAs and Original BLAs|• <br>There were no commitments due|
|I.C New Molecular Entity<br>(NME) Milestones and<br>Postmarketing Requirements<br>(PMRs)|• <br>There were no commitments due|
|I.D Split Real Time<br>Application Review (STAR)<br>Pilot Program|• <br>Conduct STAR Interim Assessment:<br>FDA assessed the requests received for the STAR pilot<br>program. FDA plans to provide a summary of the<br>findings in the next fiscal year.|
|I.E Expedited Reviews|• <br>There were no commitments due|
|I.F Review of Proprietary<br>Names to Reduce Medication<br>Errors|• <br>There were no commitments due|
|I.G Major Dispute Resolution|• <br>There were no commitments due|
|I.H Clinical Holds|• <br>There were no commitments due|
|I.I Special Protocol<br>Assessment and Agreement|• <br>There were no commitments due|


_Prescription Drug User Fee Act: FY 2025_ _Page 44_


---

##### **B. Section I.K: Enhancing Regulatory Science and Expediting** **Drug Development**

**Table 40. Section I.K’s FY 2025 Commitments and Accomplishments.**


|Commitment Title|FY 2025 Accomplishments|
|---|---|
|I.K.1 Promoting Innovation<br>Through Enhanced<br>Communication Between<br>FDA and Sponsors During<br>Drug Development|• <br>There were no commitments due|
|I.K.2 Ensuring Sustained<br>Success of Breakthrough<br>Therapy Program|• <br>There were no commitments due|
|I.K.3 Early Consultation on<br>the Use of New Surrogate<br>Endpoints|• <br>There were no commitments due|
|I.K.4 Advancing Drug<br>Development of Drugs for<br>Rare Diseases|**OVERALL**<br>  <br>• <br>Advancing drug development for rare diseases is an<br>intra-Agency collaborative effort. In FY 2025, CDER’s<br>Rare Diseases Team (RDT), CBER’s Rare Disease<br>Program and others engaged in critical rare disease<br>drug development enhancement activities. <br>  <br>• <br>In FY 2025, the CDER Accelerating Rare disease<br>Cures Program (https://www.fda.gov/about-<br>fda/center-drug-evaluation-and-research-<br>cder/accelerating-rare-disease-cures-arc-<br>program)(CDER ARC Program), managed by|


_Prescription Drug User Fee Act: FY 2025_ _Page 45_


---

8 [https://www.fda.gov/about-fda/center-drug-evaluation-and-research-cder/accelerating-rare-disease-](https://www.fda.gov/about-fda/center-drug-evaluation-and-research-cder/accelerating-rare-disease-cures-arc-program)
[cures-arc-program](https://www.fda.gov/about-fda/center-drug-evaluation-and-research-cder/accelerating-rare-disease-cures-arc-program)
9 [https://www.fda.gov/industry/medical-products-rare-diseases-and-conditions/fda-rare-disease-](https://www.fda.gov/industry/medical-products-rare-diseases-and-conditions/fda-rare-disease-innovation-hub)
[innovation-hub](https://www.fda.gov/industry/medical-products-rare-diseases-and-conditions/fda-rare-disease-innovation-hub)
10 [https://healthpolicy.duke.edu/events/rise-controls-rare-disease-clinical-trials-small-and-diminishing-](https://healthpolicy.duke.edu/events/rise-controls-rare-disease-clinical-trials-small-and-diminishing-populations)
[populations](https://healthpolicy.duke.edu/events/rise-controls-rare-disease-clinical-trials-small-and-diminishing-populations)


_Prescription Drug User Fee Act: FY 2025_ _Page 46_


---

_Prescription Drug User Fee Act: FY 2025_ _Page 47_


---

_Prescription Drug User Fee Act: FY 2025_ _Page 48_


---

11 [https://www.fda.gov/about-fda/center-drug-evaluation-and-research-cder/accelerating-rare-disease-](https://www.fda.gov/about-fda/center-drug-evaluation-and-research-cder/accelerating-rare-disease-cures-arc-program)
[cures-arc-program](https://www.fda.gov/about-fda/center-drug-evaluation-and-research-cder/accelerating-rare-disease-cures-arc-program)
12 [https://www.fda.gov/about-fda/accelerating-rare-disease-cures-arc-program/learning-and-education-](https://www.fda.gov/about-fda/accelerating-rare-disease-cures-arc-program/learning-and-education-advance-and-empower-rare-disease-drug-developers-leader-3d)
[advance-and-empower-rare-disease-drug-developers-leader-3d](https://www.fda.gov/about-fda/accelerating-rare-disease-cures-arc-program/learning-and-education-advance-and-empower-rare-disease-drug-developers-leader-3d)


_Prescription Drug User Fee Act: FY 2025_ _Page 49_


---

_Prescription Drug User Fee Act: FY 2025_ _Page 50_


---

13 [https://www.fda.gov/regulatory-information/search-fda-guidance-documents/nonclinical-safety-](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/nonclinical-safety-assessment-oligonucleotide-based-therapeutics)
[assessment-oligonucleotide-based-therapeutics](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/nonclinical-safety-assessment-oligonucleotide-based-therapeutics)
14 [https://www.fda.gov/regulatory-information/search-fda-guidance-documents/accelerated-approval-](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/accelerated-approval-expedited-program-serious-conditions)
[expedited-program-serious-conditions](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/accelerated-approval-expedited-program-serious-conditions)
15 [https://www.fda.gov/regulatory-information/search-fda-guidance-documents/myelodysplastic-](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/myelodysplastic-syndromes-developing-drug-and-biological-products-treatment)
[syndromes-developing-drug-and-biological-products-treatment](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/myelodysplastic-syndromes-developing-drug-and-biological-products-treatment)
16 [https://www.fda.gov/regulatory-information/search-fda-guidance-documents/frequently-asked-](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/frequently-asked-questions-developing-potential-cellular-and-gene-therapy-products)
[questions-developing-potential-cellular-and-gene-therapy-products](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/frequently-asked-questions-developing-potential-cellular-and-gene-therapy-products)
17 [https://www.fda.gov/regulatory-information/search-fda-guidance-documents/innovative-designs-](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/innovative-designs-clinical-trials-cellular-and-gene-therapy-products-small-populations?utm_medium=email&utm_source=govdelivery)
[clinical-trials-cellular-and-gene-therapy-products-small-](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/innovative-designs-clinical-trials-cellular-and-gene-therapy-products-small-populations?utm_medium=email&utm_source=govdelivery)
[populations?utm_medium=email&utm_source=govdelivery](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/innovative-designs-clinical-trials-cellular-and-gene-therapy-products-small-populations?utm_medium=email&utm_source=govdelivery)
18 [https://www.fda.gov/regulatory-information/search-fda-guidance-documents/postapproval-methods-](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/postapproval-methods-capture-safety-and-efficacy-data-cell-and-gene-therapy-products)
[capture-safety-and-efficacy-data-cell-and-gene-therapy-products](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/postapproval-methods-capture-safety-and-efficacy-data-cell-and-gene-therapy-products)


_Prescription Drug User Fee Act: FY 2025_ _Page 51_


---

19 [https://www.fda.gov/regulatory-information/search-fda-guidance-documents/expedited-programs-](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/expedited-programs-regenerative-medicine-therapies-serious-conditions-0)
[regenerative-medicine-therapies-serious-conditions-0](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/expedited-programs-regenerative-medicine-therapies-serious-conditions-0)
20 [https://www.fda.gov/about-fda/fda-track-agency-wide-program-performance/fda-track-center-drug-](https://www.fda.gov/about-fda/fda-track-agency-wide-program-performance/fda-track-center-drug-evaluation-and-research-pre-approval-safety-review-drugs-and-biologics)
[evaluation-and-research-pre-approval-safety-review-drugs-and-biologics](https://www.fda.gov/about-fda/fda-track-agency-wide-program-performance/fda-track-center-drug-evaluation-and-research-pre-approval-safety-review-drugs-and-biologics)
21 [https://www.fda.gov/industry/prescription-drug-user-fee-amendments/externally-led-patient-focused-](https://www.fda.gov/industry/prescription-drug-user-fee-amendments/externally-led-patient-focused-drug-development-meetings)
[drug-development-meetings](https://www.fda.gov/industry/prescription-drug-user-fee-amendments/externally-led-patient-focused-drug-development-meetings)
22 [https://www.fda.gov/patients/learn-about-fda-patient-engagement/fda-patient-listening-sessions](https://www.fda.gov/patients/learn-about-fda-patient-engagement/fda-patient-listening-sessions)


_Prescription Drug User Fee Act: FY 2025_ _Page 52_


---

23 [https://www.fda.gov/drugs/news-events-human-drugs/assessing-novel-efficacy-endpoints-](https://www.fda.gov/drugs/news-events-human-drugs/assessing-novel-efficacy-endpoints-ophthalmologic-rare-disease-drug-and-biologics-development)
[ophthalmologic-rare-disease-drug-and-biologics-development](https://www.fda.gov/drugs/news-events-human-drugs/assessing-novel-efficacy-endpoints-ophthalmologic-rare-disease-drug-and-biologics-development)
24 [https://www.fda.gov/news-events/otp-events-meetings-and-workshops/fda-cber-otp-public-listening-](https://www.fda.gov/news-events/otp-events-meetings-and-workshops/fda-cber-otp-public-listening-meeting-leveraging-knowledge-facilitating-development-and-review-cell)
[meeting-leveraging-knowledge-facilitating-development-and-review-cell](https://www.fda.gov/news-events/otp-events-meetings-and-workshops/fda-cber-otp-public-listening-meeting-leveraging-knowledge-facilitating-development-and-review-cell)
25 [https://www.fda.gov/news-events/meeting-2-patient-and-care-partner-perspectives-early-enrollment-](https://www.fda.gov/news-events/meeting-2-patient-and-care-partner-perspectives-early-enrollment-gene-therapy-clinical-trials-rare)
[gene-therapy-clinical-trials-rare](https://www.fda.gov/news-events/meeting-2-patient-and-care-partner-perspectives-early-enrollment-gene-therapy-clinical-trials-rare)
26 [https://www.fda.gov/news-events/otp-events-meetings-and-workshops/finding-your-support-team-](https://www.fda.gov/news-events/otp-events-meetings-and-workshops/finding-your-support-team-while-participating-clinical-trial-10302024)
[while-participating-clinical-trial-10302024](https://www.fda.gov/news-events/otp-events-meetings-and-workshops/finding-your-support-team-while-participating-clinical-trial-10302024)
27 [https://www.fda.gov/news-events/otp-events-meetings-and-workshops/workshop-integration-site-](https://www.fda.gov/news-events/otp-events-meetings-and-workshops/workshop-integration-site-analysis-during-long-term-follow-gene-therapies-integrating-viral-vectors)
[analysis-during-long-term-follow-gene-therapies-integrating-viral-vectors](https://www.fda.gov/news-events/otp-events-meetings-and-workshops/workshop-integration-site-analysis-during-long-term-follow-gene-therapies-integrating-viral-vectors)


_Prescription Drug User Fee Act: FY 2025_ _Page 53_


---

|Col1|o Live Biotherapeutic Products to Prevent<br>Necrotizing Enterocolitis in Very Low Birth<br>Weight Infants, October 25, 2024.28<br>• The CBER Rare Disease Program 29 web page<br>continues to be updated with timely and relevant<br>information about CBER’s rare disease-focused<br>activities, such as collaborative efforts with partners at<br>FDA and beyond, annual listings of CBER's recent<br>orphan approvals starting from 2022 and currently to<br>the end of FY 2025, and a section with Frequently<br>Asked Questions | FDA.30|
|---|---|
|Would I.K.5 Advancing<br>Development of Drug-Device<br>and Biologic-Device<br>Combination Products<br>Regulated by CBER and<br>CDER|• <br>There were no commitments due|
|I.K.6 Enhancing Use of Real-<br>World Evidence for Use in<br>Regulatory Decision-Making|• <br>FDA completed a total of six submission cycles of the<br>Advancing RWE Program.<br> <br>• <br>FDA published the FY24 report on RWE Submissions to<br>CDER and CBER.31 <br> <br>• <br>FDA conducted the RWE Program Public Workshop on<br>September 23, 2025.32 <br>|


##### **C.  Section I.L: Enhancing Regulatory Decision Tools to** **Support Drug Development and Review**

**Table 41. Section I.L’s FY 2025 Commitments and Accomplishments.**


28 [https://www.fda.gov/news-events/live-biotherapeutic-products-prevent-necrotizing-enterocolitis-very-](https://www.fda.gov/news-events/live-biotherapeutic-products-prevent-necrotizing-enterocolitis-very-low-birth-weight-infants)
[low-birth-weight-infants](https://www.fda.gov/news-events/live-biotherapeutic-products-prevent-necrotizing-enterocolitis-very-low-birth-weight-infants)
29 [https://www.fda.gov/vaccines-blood-biologics/cber-rare-disease-program](https://www.fda.gov/vaccines-blood-biologics/cber-rare-disease-program)
30 [https://www.fda.gov/vaccines-blood-biologics/cber-rare-disease-program-frequently-asked-questions](https://www.fda.gov/vaccines-blood-biologics/cber-rare-disease-program-frequently-asked-questions)
31 [https://www.fda.gov/science-research/real-world-evidence/real-world-evidence-submissions-center-](https://www.fda.gov/science-research/real-world-evidence/real-world-evidence-submissions-center-drug-evaluation-and-research)
[drug-evaluation-and-research](https://www.fda.gov/science-research/real-world-evidence/real-world-evidence-submissions-center-drug-evaluation-and-research)
32 [https://healthpolicy.duke.edu/events/regulatory-submissions-real-world-evidence-successes-](https://healthpolicy.duke.edu/events/regulatory-submissions-real-world-evidence-successes-challenges-and-lessons-learned)
[challenges-and-lessons-learned](https://healthpolicy.duke.edu/events/regulatory-submissions-real-world-evidence-successes-challenges-and-lessons-learned)


_Prescription Drug User Fee Act: FY 2025_ _Page 54_


---

33 [https://www.fda.gov/drugs/development-approval-process-drugs/fda-patient-focused-drug-](https://www.fda.gov/drugs/development-approval-process-drugs/fda-patient-focused-drug-development-guidance-series-enhancing-incorporation-patients-voice-medical)
[development-guidance-series-enhancing-incorporation-patients-voice-medical.](https://www.fda.gov/drugs/development-approval-process-drugs/fda-patient-focused-drug-development-guidance-series-enhancing-incorporation-patients-voice-medical)


_Prescription Drug User Fee Act: FY 2025_ _Page 55_


---

|Col1|Discuss Methodologic and Other Challenges<br>Related to Patient Experience Data.34<br>o In September 2025, as a follow-up to the<br>December 2024 workshop, FDA held a second<br>public workshop, Patient-Focused Drug<br>Development: Workshop #2 to Discuss<br>Methodologic and Other Challenges Related to<br>Patient Experience Data.35<br>o FDA continued the Standard Core Clinical Endpoints and<br>Grant Program that (1) funds the development of core<br>outcome sets in a variety of clinical divisions and (2)<br>increases the familiarity and understanding of the<br>development of Clinical Outcome Assessments within<br>review divisions and other areas. Multiple scientific<br>presentations and publicly available publications have<br>resulted from these programs.<br>o FDA staff members continued to interact with<br>stakeholders to systematically obtain the patient<br>perspective on specific diseases and their treatments.<br>These interactions included participating in 9 Patient<br>Listening Sessions and 12 externally-led PFDD meetings.<br>FDA staff across review divisions were also active<br>participants at many patient-led meetings such as the<br>National Organization for Rare Disorders (NORD) Annual<br>Summit, Patients as Partners, the Alzheimer’s<br>Association, the Lupus Alliance ABC Patient Reported<br>Outcomes meeting, the Global Liver Alliance A3 meeting,<br>the Association for Frontotemporal Degeneration (AFTD)<br>2025 Research Roundtable, the Combined Brain Summit,<br>and many others.|
|---|---|
|I.L.2 Enhancing the Benefit-<br>Risk Assessment in<br>Regulatory Decision-Making|• <br>There were no commitments due|
|I.L.3 Advancing Model-<br>Informed Drug Development|• <br>Under PDUFA VII, FDA has granted 26 meeting requests<br>as part of the MIDD Paired Meeting Program as of<br>September 30, 2025.|


34 [https://www.fda.gov/drugs/news-events-human-drugs/patient-focused-drug-development-workshop-](https://www.fda.gov/drugs/news-events-human-drugs/patient-focused-drug-development-workshop-discuss-methodologic-and-other-challenges-related-patient)
[discuss-methodologic-and-other-challenges-related-patient](https://www.fda.gov/drugs/news-events-human-drugs/patient-focused-drug-development-workshop-discuss-methodologic-and-other-challenges-related-patient)
35 [https://www.fda.gov/drugs/news-events-human-drugs/patient-focused-drug-development-workshop-2-](https://www.fda.gov/drugs/news-events-human-drugs/patient-focused-drug-development-workshop-2-discuss-methodologic-and-other-challenges-related)
[discuss-methodologic-and-other-challenges-related](https://www.fda.gov/drugs/news-events-human-drugs/patient-focused-drug-development-workshop-2-discuss-methodologic-and-other-challenges-related)


_Prescription Drug User Fee Act: FY 2025_ _Page 56_


---

|I.L.4 Enhancing Capacity to<br>Review Complex Innovative<br>Designs|• Publish Draft Guidance on Complex Innovative Trial<br>Designs (CID): As of September 30, 2025, a guidance on<br>the use of Bayesian methodology in clinical trials of drugs<br>and biologics is in development. The FDA anticipates this<br>guidance will be published in FY26.<br>• In FY 2025, FDA held one meeting as part of the<br>Complex Innovative Trial Design (CID) Paired Meeting<br>Program.<br>• In FY 2025, to promote innovation in this area, a new CID<br>Meeting Program case study was published on the<br>program's external website, for a total of six case studies.<br>• FDA continued to develop CDER and CBER staff by a<br>hosting a CID Seminar Training and engaged with an<br>external expert through Intergovernmental Personnel Act<br>assignment to support the review of complex innovative<br>designs.|
|---|---|
|I.L.5 Enhancing Capacity to<br>Support Analysis Data<br>Standards for Product<br>Development and Review|• <br>There were no commitments due|
|I.L.6 Enhancing Drug<br>Development Tools<br>Qualification Pathway for<br>Biomarkers|• <br>There were no commitments due|


##### **D.  Section I.M: Enhancement and Modernization of FDA’s** **Drug Safety System**

**Table 42. Section I.M’s FY 2025 Commitments and Accomplishments.**


|Commitment Title|FY 2025 Accomplishments|
|---|---|
|I.M.1 Modernization and<br>Improvement of REMS<br>Assessments|• There were no commitments due|
|I.M.2 Optimization of the<br>Sentinel Initiative|• <br>Contribute Information on Sentinel to PDUFA Financial<br>Report FY24: CDER reported in the FY 2024 PDUFA<br>Financial Report a total of $7.5M for the Sentinel System<br>for data, analytical capabilities, safety issue analyses,<br>dissemination of relevant product and safety information,<br>and Sentinel system operations / maintenance and|


_Prescription Drug User Fee Act: FY 2025_ _Page 57_


---

36 [https://www.fda.gov/industry/prescription-drug-user-fee-amendments/pdufa-vii-commitment-](https://www.fda.gov/industry/prescription-drug-user-fee-amendments/pdufa-vii-commitment-assessment-sentinel-system-2022-2024)
[assessment-sentinel-system-2022-2024](https://www.fda.gov/industry/prescription-drug-user-fee-amendments/pdufa-vii-commitment-assessment-sentinel-system-2022-2024)
37 [https://bestinitiative.org/vaccines-and-allergenics](https://bestinitiative.org/vaccines-and-allergenics)
38 [https://www.fda.gov/industry/prescription-drug-user-fee-amendments/completed-pdufa-vii-deliverables](https://www.fda.gov/industry/prescription-drug-user-fee-amendments/completed-pdufa-vii-deliverables)
39 [https://bestinitiative.org/best/data-and-surveillance-activities/distributed-network-and-common-data-](https://bestinitiative.org/best/data-and-surveillance-activities/distributed-network-and-common-data-model)
[model](https://bestinitiative.org/best/data-and-surveillance-activities/distributed-network-and-common-data-model)


_Prescription Drug User Fee Act: FY 2025_ _Page 58_


---

##### **E. Section I.N: Enhancements Related to Product Quality** **Reviews, Chemistry, Manufacturing, and Control** **Approaches, and Advancing the Utilization of Innovative** **Manufacturing Technologies**

**Table 43. Section I.N’s FY 2025 Commitments and Accomplishments.**


|Commitment Title|FY 2025 Accomplishments|
|---|---|
|I. N.1 Enhancing<br>Communication Between<br>FDA and Sponsors During<br>Application Review|• Conduct Assessment of Chemistry, Manufacturing, and<br>Controls (CMC) Information Requests (IRs): FDA partnered<br>with Eastern Research Group (ERG) to assess the<br>practices of CDER, CBER, and sponsors in communicating<br>through product quality information requests (IRs) during<br>application review. ERG specifically assessed the<br>implementation and effectiveness of Four-Part Harmony, in<br>which reviewers are expected to communicate (1) what<br>was provided, (2) what is the issue or deficiency, (3) what is<br>needed, and (4) why it is needed.<br>• Publish CMC IR Assessment Report: FDA published a<br>report of the above assessment on its public webpage:<br>“PDUFA VII: Assessment of FDA and Sponsor<br>Communications Through Product Quality Information<br>Requests.”40 The report describes assessment methods,<br>findings, and recommendations. FDA posted the report in<br>the Federal Register for public comment and is currently<br>considering the comments received.41|
|I. N.2 Enhancing Inspection<br>Communication for<br>Applications, not Including<br>Supplements|• <br>There were no commitments due|
|I.N.3 Alternative Tools to<br>Assess Manufacturing<br>Facilities Named in Pending<br>Applications|• <br>On September 11, 2025, the FDA published a final<br>guidance on Alternative Tools to Assess Manufacturing<br>Facilities.42|


40 [https://www.fda.gov/industry/prescription-drug-user-fee-amendments/pdufa-vii-assessment-fda-and-](https://www.fda.gov/industry/prescription-drug-user-fee-amendments/pdufa-vii-assessment-fda-and-sponsor-communications-through-product-quality-information-requests)
[sponsor-communications-through-product-quality-information-requests](https://www.fda.gov/industry/prescription-drug-user-fee-amendments/pdufa-vii-assessment-fda-and-sponsor-communications-through-product-quality-information-requests)
41 [Prescription Drug User Fee Act VII; Independent Assessment of Communication Through Product](https://www.federalregister.gov/documents/2025/05/09/2025-08208/prescription-drug-user-fee-act-vii-independent-assessment-of-communication-through-product-quality)
[Quality Information Requests During Application Review; Final Report; Availability; Request for](https://www.federalregister.gov/documents/2025/05/09/2025-08208/prescription-drug-user-fee-act-vii-independent-assessment-of-communication-through-product-quality)
[Comments](https://www.federalregister.gov/documents/2025/05/09/2025-08208/prescription-drug-user-fee-act-vii-independent-assessment-of-communication-through-product-quality)
42 [https://www.fda.gov/regulatory-information/search-fda-guidance-documents/alternative-tools-](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/alternative-tools-assessing-drug-manufacturing-facilities-identified-pending-applications)
[assessing-drug-manufacturing-facilities-identified-pending-applications](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/alternative-tools-assessing-drug-manufacturing-facilities-identified-pending-applications)


_Prescription Drug User Fee Act: FY 2025_ _Page 59_


---

|Col1|o Requesting records and other information,<br>pursuant to section 704(a)(4) of the FD&C Act<br>(21 U.S.C. 374(a)(4)), directly from facilities<br>and other entities subject to inspection<br>o Performing remote interactive evaluations<br>(RIEs) (e.g., remote livestreaming video of<br>operations, teleconferences, screen sharing)<br>• Requesting existing inspection reports and other<br>information from trusted foreign regulatory partners<br>through mutual recognition agreements and other<br>agreement|
|---|---|
|I.N.4 Facilitating Chemistry,<br>Manufacturing, and Controls<br>Readiness for Products with<br>Accelerated Clinical<br>Development|• Conducted the Public Workshop on CMC Development and<br>Readiness Pilot on September 10, 2025.43 <br>• Published the Federal Register Notice (FRN) announcing<br>the Chemistry, Manufacturing, and Controls (CMC)<br>Development and Readiness Pilot (CDRP) Public<br>Workshop on August 18, 2025.44 <br>• Published the Year 4 FRN for CMC Development and<br>Readiness Pilot on August 28, 2025.45 <br>• Updated the website: Chemistry, Manufacturing, and<br>Controls Development and Readiness Pilot (CDRP)<br>Program | FDA46 <br>• Accepted two new INDs into the CDRP program for FY25,<br>totaling six for the program.|
|I.N.5 Advancing Utilization<br>and Implementation of<br>Innovative Manufacturing|• <br>Finalized Innovative Manufacturing Strategy Document:<br>• <br>On June 8, 2023, FDA participated in a public<br>workshop on the use of innovative manufacturing<br>technologies for products regulated by the Center for<br>Drug Evaluation and Research (CDER) and the Center<br>for Biologics Evaluation and Research (CBER),<br>including barriers to their adoption. FDA also<br>committed to issuing the draft Strategy Document for<br>public comment.<br>• <br>On September 12, 2024, FDA announced the<br>publication of a draft Strategy Document for public<br>comment outlining specific actions FDA will take|


43 [https://healthpolicy.duke.edu/events/lessons-learned-chemistry-manufacturing-and-controls-cmc-](https://healthpolicy.duke.edu/events/lessons-learned-chemistry-manufacturing-and-controls-cmc-development-and-readiness-pilot-0)
[development-and-readiness-pilot-0](https://healthpolicy.duke.edu/events/lessons-learned-chemistry-manufacturing-and-controls-cmc-development-and-readiness-pilot-0)
44 [https://www.federalregister.gov/documents/2025/08/19/2025-15799/lessons-learned-from-the-](https://www.federalregister.gov/documents/2025/08/19/2025-15799/lessons-learned-from-the-chemistry-manufacturing-and-controls-development-and-readiness-pilot)
[chemistry-manufacturing-and-controls-development-and-readiness-pilot](https://www.federalregister.gov/documents/2025/08/19/2025-15799/lessons-learned-from-the-chemistry-manufacturing-and-controls-development-and-readiness-pilot)
45 [https://www.federalregister.gov/documents/2025/08/28/2025-16513/chemistry-manufacturing-and-](https://www.federalregister.gov/documents/2025/08/28/2025-16513/chemistry-manufacturing-and-controls-development-and-readiness-pilot-program-program-announcement)
[controls-development-and-readiness-pilot-program-program-announcement](https://www.federalregister.gov/documents/2025/08/28/2025-16513/chemistry-manufacturing-and-controls-development-and-readiness-pilot-program-program-announcement)
46 [https://www.fda.gov/drugs/pharmaceutical-quality-resources/chemistry-manufacturing-and-controls-](https://www.fda.gov/drugs/pharmaceutical-quality-resources/chemistry-manufacturing-and-controls-development-and-readiness-pilot-cdrp-program)
[development-and-readiness-pilot-cdrp-program](https://www.fda.gov/drugs/pharmaceutical-quality-resources/chemistry-manufacturing-and-controls-development-and-readiness-pilot-cdrp-program)


_Prescription Drug User Fee Act: FY 2025_ _Page 60_


---

##### **F. Section I.O: Enhancing CBER’s Capacity to Support** **Development, Review, and Approval of Cell and Gene** **Therapy Products**

**Table 44. Section I.O’s FY 2025 Commitments and Accomplishments.**


|Commitment Title|FY 2025 Accomplishments|
|---|---|
|I.O.1 Patient-Focused Drug<br>Development|• <br>No commitments due|
|I.O.2 Novel Approaches to<br>Development of Cell and<br>Gene Therapy|• On November 19, 2024, FDA published Federal Register<br>Notice (FRN)47 of Draft Guidance for Industry (GFI): Q&A<br>CGT. FDA published the announcement of the Draft GFI:<br>Frequently Asked Questions — Developing Potential<br>Cellular and Gene Therapy Products | FDA.48 <br>• On September 25, 2025, FDA published FRN and Draft<br>GFI: Innovative Designs for Clinical Trials of Cellular and<br>Gene Therapy Products in Small Populations49.50 FDA<br>published the announcement of the Draft GFI, Innovative<br>Designs for Clinical Trials of Cellular and Gene Therapy<br>Products in Small Populations | FDA.51 <br>• On September 25, 2025, FDA published FRN and Draft GFI<br>on Post-Approval Cell and Gene Therapy: Postapproval<br>Methods to Capture Safety and Efficacy Data for Cell and|


47 [https://www.federalregister.gov/documents/2024/11/19/2024-26918/frequently-asked-questions-](https://www.federalregister.gov/documents/2024/11/19/2024-26918/frequently-asked-questions-developing-potential-cellular-and-gene-therapy-products-draft-guidance)
[developing-potential-cellular-and-gene-therapy-products-draft-guidance](https://www.federalregister.gov/documents/2024/11/19/2024-26918/frequently-asked-questions-developing-potential-cellular-and-gene-therapy-products-draft-guidance)
48 [https://www.fda.gov/regulatory-information/search-fda-guidance-documents/frequently-asked-](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/frequently-asked-questions-developing-potential-cellular-and-gene-therapy-products)
[questions-developing-potential-cellular-and-gene-therapy-products](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/frequently-asked-questions-developing-potential-cellular-and-gene-therapy-products)
49 [https://www.fda.gov/media/188892/download](https://www.fda.gov/media/188892/download)
50 [https://www.federalregister.gov/documents/2025/09/25/2025-18651/innovative-designs-for-clinical-](https://www.federalregister.gov/documents/2025/09/25/2025-18651/innovative-designs-for-clinical-trials-of-cellular-and-gene-therapy-products-in-small-populations)
[trials-of-cellular-and-gene-therapy-products-in-small-populations](https://www.federalregister.gov/documents/2025/09/25/2025-18651/innovative-designs-for-clinical-trials-of-cellular-and-gene-therapy-products-in-small-populations)
51 [https://www.fda.gov/regulatory-information/search-fda-guidance-documents/innovative-designs-](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/innovative-designs-clinical-trials-cellular-and-gene-therapy-products-small-populations)
[clinical-trials-cellular-and-gene-therapy-products-small-populations](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/innovative-designs-clinical-trials-cellular-and-gene-therapy-products-small-populations)


_Prescription Drug User Fee Act: FY 2025_ _Page 61_


---

|Col1|Gene Therapy Products52.53 FDA published the<br>announcement of the Draft GFI: Postapproval Methods to<br>Capture Safety and Efficacy Data for Cell and Gene<br>Therapy Products | FDA.54|
|---|---|
|I.O.3 Expedited Programs for<br>the Development of<br>Regenerative Medicine<br>Therapies|• <br>On September 25, 2025, FDA published FRN and Draft<br>GFI on Regenerative Medicine Therapies: Expedited<br>Programs for Regenerative Medicine Therapies for<br>Serious Conditions.55,56 On September 25, 2025, FDA<br>published FRN and Draft GFI on Regenerative Medicine<br>Therapies: Expedited Programs for Regenerative Medicine<br>Therapies for Serious Conditions.57,58 FDA published the<br>announcement of the Draft GFI, Expedited Programs for<br>Regenerative Medicine Therapies for Serious Conditions |<br>FDA.59|
|I. O.4 Leveraging Knowledge|• Conducted Public Meeting CGT Manufacturers: The FDA<br>CBER OTP Public Listening Meeting: Leveraging<br>Knowledge for Facilitating the Development and Review of<br>Cell and Gene Therapies, was held virtually on September<br>18, 2025, from 10 a.m. – 4 p.m., EST.60 A livestream of the<br>event can be reached via FDA’s YouTube channel.61|


52 [https://www.fda.gov/media/188891/download](https://www.fda.gov/media/188891/download)
53 [https://www.federalregister.gov/documents/2025/09/25/2025-18650/postapproval-methods-to-capture-](https://www.federalregister.gov/documents/2025/09/25/2025-18650/postapproval-methods-to-capture-safety-and-efficacy-data-for-cell-and-gene-therapy-products-draft)
[safety-and-efficacy-data-for-cell-and-gene-therapy-products-draft](https://www.federalregister.gov/documents/2025/09/25/2025-18650/postapproval-methods-to-capture-safety-and-efficacy-data-for-cell-and-gene-therapy-products-draft)
54 [https://www.fda.gov/regulatory-information/search-fda-guidance-documents/postapproval-methods-](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/postapproval-methods-capture-safety-and-efficacy-data-cell-and-gene-therapy-products)
[capture-safety-and-efficacy-data-cell-and-gene-therapy-products](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/postapproval-methods-capture-safety-and-efficacy-data-cell-and-gene-therapy-products)
55 [https://www.fda.gov/media/188874/download](https://www.fda.gov/media/188874/download)
56 [https://www.federalregister.gov/documents/2025/09/25/2025-18653/expedited-programs-for-](https://www.federalregister.gov/documents/2025/09/25/2025-18653/expedited-programs-for-regenerative-medicine-therapies-for-serious-conditions-draft-guidance-for)
[regenerative-medicine-therapies-for-serious-conditions-draft-guidance-for](https://www.federalregister.gov/documents/2025/09/25/2025-18653/expedited-programs-for-regenerative-medicine-therapies-for-serious-conditions-draft-guidance-for)
57 [https://www.fda.gov/media/188874/download](https://www.fda.gov/media/188874/download)
58 [https://www.federalregister.gov/documents/2025/09/25/2025-18653/expedited-programs-for-](https://www.federalregister.gov/documents/2025/09/25/2025-18653/expedited-programs-for-regenerative-medicine-therapies-for-serious-conditions-draft-guidance-for)
[regenerative-medicine-therapies-for-serious-conditions-draft-guidance-for](https://www.federalregister.gov/documents/2025/09/25/2025-18653/expedited-programs-for-regenerative-medicine-therapies-for-serious-conditions-draft-guidance-for)
59 [https://www.fda.gov/regulatory-information/search-fda-guidance-documents/expedited-programs-](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/expedited-programs-regenerative-medicine-therapies-serious-conditions-0)
[regenerative-medicine-therapies-serious-conditions-0](https://www.fda.gov/regulatory-information/search-fda-guidance-documents/expedited-programs-regenerative-medicine-therapies-serious-conditions-0)
60 [https://www.fda.gov/news-events/otp-events-meetings-and-workshops/fda-cber-otp-public-listening-](https://www.fda.gov/news-events/otp-events-meetings-and-workshops/fda-cber-otp-public-listening-meeting-leveraging-knowledge-facilitating-development-and-review-cell)
[meeting-leveraging-knowledge-facilitating-development-and-review-cell](https://www.fda.gov/news-events/otp-events-meetings-and-workshops/fda-cber-otp-public-listening-meeting-leveraging-knowledge-facilitating-development-and-review-cell)
61 [https://www.youtube.com/live/yNafnXPaOHY](https://www.youtube.com/live/yNafnXPaOHY)


_Prescription Drug User Fee Act: FY 2025_ _Page 62_


---

##### **G. Section I.P: Supporting Review of New Allergenic Extract** **Products**

**Table 45. Section I.P’s FY 2025 Commitments and Accomplishments.**


|Commitment Title|FY 2025 Accomplishments|
|---|---|
|I.P.1 Allergenic Extract<br>Products Licensed After<br>October 1, 2022|• There were no commitments due.|
|I.P.2 Allergenic Extract<br>Products Licensed Before<br>October 1, 2022<br>|• There were no commitments due.|


##### **H. Section II: Enhancing the Management of User Fee** **Resources**

**Table 46. Section II’s FY 2025 Commitments and Accomplishments.**


|Commitment Title|FY 2025 Accomplishments|
|---|---|
|II.A Resource Capacity<br>Planning and Modernized<br>Time Reporting|• <br>Information on the use of the capacity planning<br>adjustment (CPA) revenue to was published in the FY24<br>PDUFA Annual Financial Report.62 <br>• <br>The annual update to the Resource Capacity Planning<br>(RCP) Implementation Plan was published on 3/31/2025.<br>63 <br>• <br>The independent assessment of Resource Capacity<br>Planning was published on 9/26/2025.64|
|II.B Financial Transparency<br>and Efficiency|• <br>Publish Financial Plan Updates FY25: PDUFA VII Five-<br>Year Financial Plan - 2025 update was published on July<br>30, 2025.65|


62 [https://www.fda.gov/media/185331/download?attachment](https://www.fda.gov/media/185331/download?attachment)
63 [https://www.fda.gov/media/186035/download?attachment](https://www.fda.gov/media/186035/download?attachment)
64 [https://www.fda.gov/industry/fda-user-fee-programs/resource-capacity-planning-and-modernized-time-](https://www.fda.gov/industry/fda-user-fee-programs/resource-capacity-planning-and-modernized-time-reporting)
[reporting](https://www.fda.gov/industry/fda-user-fee-programs/resource-capacity-planning-and-modernized-time-reporting)
65 [https://www.fda.gov/media/187933/download?attachment](https://www.fda.gov/media/187933/download?attachment)


_Prescription Drug User Fee Act: FY 2025_ _Page 63_


---

##### **I. Section III: Improving FDA’s Hiring and Retention of** **Review Staff**

**Table 47. Section III’s FY 2025 Commitments and Accomplishments.**


|Commitment Title|FY 2025 Accomplishments|
|---|---|
|III.A Set Clear Goals for<br>Human Drug Review Program<br>Hiring|• <br>CBER was allocated 29 PDUFA VII positions for<br>FY2025. As of September 30, 2025, 8 were on board.<br>• <br>CDER was allocated 15 PDUFA VII positions for<br>FY2025. As of September 30, 2025, 9 were on board.<br>• <br>Quarterly hiring data for PDUFA VII is posted on the<br>public website (PDUFA and BsUFA Quarterly Hiring<br>Updates | FDA).68|


66 [https://www.fda.gov/media/185331/download?attachment](https://www.fda.gov/media/185331/download?attachment)
67 [https://www.fda.gov/drugs/news-events-human-drugs/financial-transparency-and-efficiency-](https://www.fda.gov/drugs/news-events-human-drugs/financial-transparency-and-efficiency-prescription-drug-user-fee-act-biosimilar-user-fee-act-and)
[prescription-drug-user-fee-act-biosimilar-user-fee-act-and](https://www.fda.gov/drugs/news-events-human-drugs/financial-transparency-and-efficiency-prescription-drug-user-fee-act-biosimilar-user-fee-act-and)
68 [https://www.fda.gov/industry/prescription-drug-user-fee-amendments/pdufa-and-bsufa-quarterly-hiring-](https://www.fda.gov/industry/prescription-drug-user-fee-amendments/pdufa-and-bsufa-quarterly-hiring-updates)
[updates](https://www.fda.gov/industry/prescription-drug-user-fee-amendments/pdufa-and-bsufa-quarterly-hiring-updates)


_Prescription Drug User Fee Act: FY 2025_ _Page 64_


---

##### **J. Section IV: Information Technology and Bioinformatics** **Goals**

**Table 48. Section IV’s FY 2025 Commitments and Accomplishments.**


|Goal|FY 2025 Accomplishments|
|---|---|
|IV.A Enhancing Transparency<br>and Leveraging Modern<br>Technology|• <br>Publish Data Standards Action Plan Q4 FY24: The<br>CBER-CDER FY24 Q4 Data Standards Action Plan<br>was approved by the Data Standards Operations<br>Subcommittee on November 13, 2024, and<br>published on November 20, 2024.<br>• <br>Publish Data Standards Action Plan Q1 FY25: The<br>CBER-CDER FY25 Q1 Data Standards Action Plan<br>was approved by the Data Standards Operations<br>Subcommittee on February 19, 2025, and published<br>on March 27, 2025.<br>• <br>Publish Data Standards Action Plan Q2 FY25: The<br>CBER-CDER FY25 Q2 Data Standards Action Plan<br>was approved by the Data Standards Operations<br>Subcommittee on July 25, 2025, and was published<br>on August 5, 2025.<br>• <br>Publish Data Standards Action Plan Q3 FY25: The<br>CBER-CDER FY25 Q3 Data Standards Action Plan<br>was approved by the Data Standards Operations<br>Subcommittee on September 17, 2025, and was<br>published on September 26, 2025.|


69 [https://www.fda.gov/media/188083/download?attachment](https://www.fda.gov/media/188083/download?attachment)
70 [https://www.fda.gov/drugs/news-events-human-drugs/prescription-drug-user-fee-act-and-biosimilar-](https://www.fda.gov/drugs/news-events-human-drugs/prescription-drug-user-fee-act-and-biosimilar-user-fee-amendments-hiring-and-retention-assessment)
[user-fee-amendments-hiring-and-retention-assessment](https://www.fda.gov/drugs/news-events-human-drugs/prescription-drug-user-fee-act-and-biosimilar-user-fee-amendments-hiring-and-retention-assessment)


_Prescription Drug User Fee Act: FY 2025_ _Page 65_


---

71 [https://www.fda.gov/industry/resources/submission-times](https://www.fda.gov/industry/resources/submission-times)
72 [https://www.fda.gov/industry/resources/submission-statistics](https://www.fda.gov/industry/resources/submission-statistics)


_Prescription Drug User Fee Act: FY 2025_ _Page 66_


---

|Col1|• Assess and Share Bioinformatics Capabilities FY25:<br>CBER plans to share the Center’s bioinformatics<br>capabilities at the next regularly scheduled FDA-<br>Industry meeting.<br>• Develop and Update Data and Tech Modernization<br>Strategy FY25: Due to the highly fluid nature of<br>current IT initiatives, FDA is no longer updating and<br>publishing a “Data and Tech Modernization” strategy<br>as such a document would quickly become obsolete.<br>Rather, FDA is providing frequent updates to various<br>stakeholders on the current direction and status of IT<br>initiatives.|
|---|---|
|IV.B Expanding and Enhancing<br>Bioinformatics Support|• <br>There were no commitments due.|
|IV.C Enhancing Use of Digital<br>Health Technologies to Support<br>Drug Development and Review|• <br>In FY2025, CDER’s Office of Biostatistics held a year-<br>long training program and created a training material<br>repository on the statistical analysis of DHT data for<br>statistical reviewers and analysts to aid their<br>regulatory review efforts. The program focused on<br>statistical considerations of the use of endpoints<br>derived from DHT data with instruction by an external<br>expert in academia.|


##### **K. Additional PDUFA VII Review Program Reporting** _1. Hiring and Placement of New PDUFA VII Staff at FDA_

The hiring and placement of new staff at FDA under PDUFA VII are reported on a
quarterly basis and posted on the FDARA hiring performance web page. [73] FDA
reports its progress in hiring new staff to support new initiatives in the annual PDUFA
financial report, as per the PDUFA VII Commitment Letter.


73 [https://www.fda.gov/industry/prescription-drug-user-fee-amendments/pdufa-and-bsufa-quarterly-hiring-](https://www.fda.gov/industry/prescription-drug-user-fee-amendments/pdufa-and-bsufa-quarterly-hiring-updates)
[updates.](https://www.fda.gov/industry/prescription-drug-user-fee-amendments/pdufa-and-bsufa-quarterly-hiring-updates)


_Prescription Drug User Fee Act: FY 2025_ _Page 67_


---

#### **VII. Rationale for PDUFA Program Changes**

Section 736B(a)(4) of the FD&C Act requires the annual PDUFA performance reporting
requirements to include the following:

(A) data, analysis, and discussion of the changes in the number of individuals
hired as agreed upon in the letters described in section 1001(b) of the
Prescription Drug User Fee Amendments of 2022 and the number of
remaining vacancies, the number of full-time equivalents funded by fees
collected pursuant to section 736, and the number of full time equivalents
funded by budget authority at the Food and Drug Administration by each
division within the Center for Drug Evaluation and Research, the Center for
Biologics Evaluation and Research, the Office of Inspections and
Investigations, and the Office of the Commissioner;

(B) data, analysis, and discussion of the changes in the fee revenue amounts and
costs for human prescription drug activities, including identifying –


(i) drivers of such changes; and
(ii) changes in the total average cost per full-time equivalent in the
prescription drug review program

(C) for each of the Center for Drug Evaluation and Research, the Center for
Biologics Evaluation and Research, the Office of Inspections and Investigation,
and the Office of the Commissioner, the number of employees for whom time
reporting is required and the number of employees for whom time reporting is
not required; and

(D) data, analysis, and discussion of the changes in the average full-time
equivalent hours required to complete review of each type of human drug
applications.

The information below fulfills these reporting requirements.


_Prescription Drug User Fee Act: FY 2025_ _Page 68_


---

##### **A. Changes in the Number of Individuals Hired as Agreed in** **the PDUFA VII Commitment Letter, the Number of** **Remaining Vacancies, the Number of Full-Time** **Equivalents (FTEs) Funded by Fees Collected Pursuant to** **Section 736, and the Number of FTEs Funded by Budget** **Authority by Division Within CDER, CBER, OII, and OC** _1. Changes in the Number of Individuals Hired as Agreed_ _Upon in the PDUFA VII Commitment Letter and_ _Remaining Vacancies_

FDA is committed to hiring 352 FTEs from FY 2023 to FY 2027 as agreed upon in the
PDUFA VII Commitment Letter. FDA had successfully hired 275 FTEs of the 352 FTEs
(78 percent) as of September 30, 2025. The data in the following table show the total
number of FTEs hired towards the FY 2024 and FY 2025 hiring targets as agreed upon
in the PDUFA VII Commitment Letter and the change in the number of FTE hires from
FY 2024 to FY 2025.


**Table 49. Number of Individuals Hired as Agreed Upon in the PDUFA VII**
**Commitment Letter and Remaining Vacancies.**


|Center|Number<br>Hired in FY<br>2024|Number<br>Hired in FY<br>2025|Change in<br>Number<br>Hired|Remaining<br>Vacancies<br>in FY 2024|Remaining<br>Vacancies<br>in FY 2025|Change in<br>Number of<br>Remaining<br>Vacancies|
|---|---|---|---|---|---|---|
|CDER|49|9|-40|18|24|<br>6|
|CBER|51|15|-36|20|34|14|
|OC|N/A|N/A|N/A|0|N/A|N/A|
|OII|0|0|0|0|0|0|
|**Total**<br>|**100**<br>|**24**<br>|**-76**<br>|**38**<br>|**58**<br>|**20**<br>|


the noted Center. Although some hires are recruited from outside the Center/FDA, a hire can also be a current
Center/FDA employee who is changing positions within the Agency.

##### _2. Change in the Number of FTEs Funded by Budget_ _Authority and Number of FTEs Funded by Fees by_ _Division Within CDER, CBER, OII, and OC_


_Prescription Drug User Fee Act: FY 2025_ _Page 69_


---

The data in the table below show the number of User Fee and Budget Authority
funded FTEs at FDA by each division within CDER, CBER, OII and OC. This table
reflects the number of FTEs funded by User Fee and Budget Authority for the PDUFA
VII program. For this table, “budget authority” refers to FDA's non-user fee annual
appropriations. To address the requirement that information on the number of FTEs
funded by budget authority be presented “by each division,” the information in this
table is broken down to the office level for the Centers, OII, and OC. FDA uses a
2080-hour workload to equate to one FTE, and this calculation is reflected in the table
below. Data for FY 2025 represent the number of FTEs committed to PDUFA work.
The number of FTEs funded by User Fee and budget authority for FY 2025 are those
FTEs as of September 30, 2025.


**Table 50. Number of FTEs Funded by Budget Authority and Number of FTEs**
**funded by Fees by Division Within CDER, CBER, OII, and OC.**


|Center and Office|Number<br>of FTEs<br>Funded<br>by<br>Budget<br>Authority<br>in FY<br>2024|Number<br>of FTEs<br>Funded<br>by<br>Budget<br>Authority<br>in FY<br>2025|Change<br>in the<br>Number<br>of FTEs<br>Funded<br>by<br>Budget<br>Authority|Number<br>of FTEs<br>Funded<br>by Fees<br>in FY<br>2024|Number<br>of FTEs<br>Funded<br>by Fees<br>in FY<br>2025|Change<br>in the<br>Number<br>of FTEs<br>Funded<br>by Fees|
|---|---|---|---|---|---|---|
|<br> <br> <br>**CDER**<br>|<br> <br> <br>**CDER**<br>|<br> <br> <br>**CDER**<br>|<br> <br> <br>**CDER**<br>|<br> <br> <br>**CDER**<br>|<br> <br> <br>**CDER**<br>|<br> <br> <br>**CDER**<br>|
|Office of<br>Communications<br>|10.05|9.08|-0.97|44.21|40.81|-3.40|
|<br>Office of<br>Compliance<br>|15.16|15.66|0.50|81.43|78.93|-2.50|
|<br>Office of the<br>Center Director<br>|4.67|1.07|-3.60|33.23|36.42|3.19|
|<br>Office of Executive<br>Programs<br>|3.36|4.12|0.76|61.95|47.50|-14.45|
|<br>Office of Generic<br>Drugs<br>|3.66|2.31|-1.35|3.61|4.83|1.22|
|<br>Office of<br>Management<br>|8.70|10.85|2.15|80.65|73.85|-6.80|
|<br>Office of Medical<br>Policy<br>|8.22|5.98|-2.24|116.27|111.79|-4.48|
|<br>Office of New<br>Drugs<br>|64.03|88.30|24.27|1,269.48|1,224.29|-45.19|
|<br>Office of<br>Pharmaceutical<br>Quality|51.72|55.81|4.09|407.85|387.21|-20.64|


_Prescription Drug User Fee Act: FY 2025_ _Page 70_


---

|Center and Office|Number<br>of FTEs<br>Funded<br>by<br>Budget<br>Authority<br>in FY<br>2024|Number<br>of FTEs<br>Funded<br>by<br>Budget<br>Authority<br>in FY<br>2025|Change<br>in the<br>Number<br>of FTEs<br>Funded<br>by<br>Budget<br>Authority|Number<br>of FTEs<br>Funded<br>by Fees<br>in FY<br>2024|Number<br>of FTEs<br>Funded<br>by Fees<br>in FY<br>2025|Change<br>in the<br>Number<br>of FTEs<br>Funded<br>by Fees|
|---|---|---|---|---|---|---|
|Office of<br>Regulatory Policy<br>|<br>3.10|<br>2.37|<br>-0.73|59.15|59.89|0.74|
|<br>Office of<br>Surveillance and<br>Epidemiology<br>|38.59|27.51|-11.08|227.30|240.56|13.26|
|<br>Office of Strategic<br>Programs<br>|9.56|10.58|1.02|81.92|87.97|6.05|
|<br>Office of<br>Information<br>Management and<br>Technology<br>|0.00|0.00|0.00|0.00|0.02|0.02|
|<br>Office of<br>Translational<br>Sciences|69.36|47.65|-21.71|511.80|549.25|37.45|
|<br>Other Offices|0.15|0.00|-0.15|3.88|0.00|-3.88|
|Working Capital<br>Fund (WCF)|59.64|58.90|-0.74|195.20|203.53|8.33|
|**CDRH**<br>|**CDRH**<br>|**CDRH**<br>|**CDRH**<br>|**CDRH**<br>|**CDRH**<br>|**CDRH**<br>|
|Office of Product<br>Evaluation and<br>Quality<br>|0.19|3.66|3.47|12.48|13.48|1.00|
|<br>Office of<br>Management<br>|0.08|0.03|-0.05|0.97|0.63|-0.34|
|<br>Office of Science<br>and Engineering<br>Laboratories<br>|0.04|0.17|0.13|0.06|0.04|-0.02|
|<br>Office of<br>Communication,<br>Information<br>Disclosure,<br>Training and<br>Education†|0.11|0.00|-0.11|0.57|0.40|-0.17|
|<br>Office of Policy|0.02|0.07|0.05|0.21|0.15|-0.06|
|Office of Strategic<br>Partnership and|0.19|0.08|-0.11|0.03|0.00|-0.03|


_Prescription Drug User Fee Act: FY 2025_ _Page 71_


---

|Center and Office|Number<br>of FTEs<br>Funded<br>by<br>Budget<br>Authority<br>in FY<br>2024|Number<br>of FTEs<br>Funded<br>by<br>Budget<br>Authority<br>in FY<br>2025|Change<br>in the<br>Number<br>of FTEs<br>Funded<br>by<br>Budget<br>Authority|Number<br>of FTEs<br>Funded<br>by Fees<br>in FY<br>2024|Number<br>of FTEs<br>Funded<br>by Fees<br>in FY<br>2025|Change<br>in the<br>Number<br>of FTEs<br>Funded<br>by Fees|
|---|---|---|---|---|---|---|
|Technology<br>Innovation<br>|||||||
|Office of the<br>Center Director|0.01|0.02|0.01|0.30|0.21|-0.09|
|<br>Office of Digital<br>Transformation‡|0.04|0.00|-0.04|0.00|0.00|0.00|
|WCF|0.55|0.79|0.24|1.13|1.12|-0.01|
|**CBER**<br>|**CBER**<br>|**CBER**<br>|**CBER**<br>|**CBER**<br>|**CBER**<br>|**CBER**<br>|
|Office of<br>Biostatistics and<br>Pharmacovigilance<br>|17.12|19.33|2.21|82.85|105.04|22.19|
|<br>Office of Blood<br>Research and<br>Review<br>|3.69|5.93|2.24|6.15|4.02|-2.13|
|<br>Office of<br>Compliance and<br>Biologics Quality<br>|15.23|13.29|-1.94|87.74|97.62|9.88|
|<br>Office of<br>Therapeutic<br>Products<br>|50.86|52.32|1.46|216.18|247.94|31.76|
|<br>Office of Vaccines<br>Research and<br>Review<br>|69.39|80.55|11.16|147.29|163.20|15.91|
|<br>Office of<br>Communication<br>Outreach and<br>Development<br>|4.53|1.45|-3.08|39.04|37.39|-1.65|
|<br>Office of the<br>Center Director<br>|3.86|13.54|9.68|25.61|25.72|0.11|
|<br>Office of<br>Regulatory<br>Operations<br>|6.74|3.72|-3.02|44.55|47.57|3.02|
|<br>Office of<br>Management|11.36|11.68|0.32|63.05|56.38|-6.67|
|<br>Office of<br>Information|0.92|0.06|-0.86|3.12|0.16|-2.96|


_Prescription Drug User Fee Act: FY 2025_ _Page 72_


---

|Center and Office|Number<br>of FTEs<br>Funded<br>by<br>Budget<br>Authority<br>in FY<br>2024|Number<br>of FTEs<br>Funded<br>by<br>Budget<br>Authority<br>in FY<br>2025|Change<br>in the<br>Number<br>of FTEs<br>Funded<br>by<br>Budget<br>Authority|Number<br>of FTEs<br>Funded<br>by Fees<br>in FY<br>2024|Number<br>of FTEs<br>Funded<br>by Fees<br>in FY<br>2025|Change<br>in the<br>Number<br>of FTEs<br>Funded<br>by Fees|
|---|---|---|---|---|---|---|
|Management and<br>Technology|||||||
|WCF|34.77|37.57|2.80|64.63|70.14|5.51|
|**OC**<br>|**OC**<br>|**OC**<br>|**OC**<br>|**OC**<br>|**OC**<br>|**OC**<br>|
|OC Immediate<br>Office<br>|9.12|18.64|9.52|16.05|11.70|-4.35|
|<br>Office of the Chief<br>Counsel<br>|18.09|50.28|32.19|31.83|31.56|-0.27|
|<br>Office of the Chief<br>Medical Officer<br>|0.00|57.76|57.76|31.83|36.19|4.36|
|<br>Office of the Chief<br>Scientist<br>|11.97|28.34|16.37|21.06|17.79|-3.28|
|<br>Office of Clinical<br>Policy and<br>Programs<br>|25.53|0.00|-25.53|44.91|0.00|-44.91|
|<br>Office of Digital<br>Transformation<br>|1.58|0.00|-1.58|2.78|0.00|-2.78|
|<br>Office of<br>Enterprise<br>Management<br>Services<br>|0.00|0.00|0.00|0.00|0.00|0.00|
|<br>Office of External<br>Affairs<br>|9.77|26.14|16.37|17.19|16.41|-0.78|
|<br>Office of Global<br>Policy and<br>Strategy<br>|0.56|2.94|2.38|0.99|1.84|0.85|
|<br>Office of<br>International<br>Programs<br>|0.00|0.00|0.00|0.00|0.00|0.00|
|<br>Office of<br>Operations<br>|3.99|5.58|1.59|7.03|3.50|-3.53|
|<br>Office of Policy,<br>Legislation, and<br>International<br>Affairs|12.80|32.37|19.57|22.52|20.31|-2.21|
|<br>WCF|18.29|23.63|5.34|23.53|25.92|2.39|


_Prescription Drug User Fee Act: FY 2025_ _Page 73_


---

|Center and Office|Number<br>of FTEs<br>Funded<br>by<br>Budget<br>Authority<br>in FY<br>2024|Number<br>of FTEs<br>Funded<br>by<br>Budget<br>Authority<br>in FY<br>2025|Change<br>in the<br>Number<br>of FTEs<br>Funded<br>by<br>Budget<br>Authority|Number<br>of FTEs<br>Funded<br>by Fees<br>in FY<br>2024|Number<br>of FTEs<br>Funded<br>by Fees<br>in FY<br>2025|Change<br>in the<br>Number<br>of FTEs<br>Funded<br>by Fees|
|---|---|---|---|---|---|---|
|<br> <br> <br>**OII**<br>|<br> <br> <br>**OII**<br>|<br> <br> <br>**OII**<br>|<br> <br> <br>**OII**<br>|<br> <br> <br>**OII**<br>|<br> <br> <br>**OII**<br>|<br> <br> <br>**OII**<br>|
|Office of<br>Pharmaceutical<br>Quality Operations|107.90|88.70|-19.20|46.72|38.80|-7.92|
|<br>WCF<br>|10.38<br>|9.12<br>|-1.26<br>|4.37<br>|2.62<br>|-1.75<br>|


administered services provided to CDER, CDRH, CBER, OII, and OC. Because many employees under OC and
WCF do not report time, an average cost per OC and WCF FTE was applied to derive the number of PDUFA
program FTEs funded by budget authority.

- CDRH’s Office of Communication and Education was reorganized to the Office of Communication, Information
Disclosure, Training and Education in FY 2024.

- CDRH’s Office of Information Management and Technology was reorganized to the Office of Digital
Transformation in FY 2024.

##### **B. Changes in the Average Total Cost Per FTE in the** **Prescription Drug Review Program**


Section 736B(a)(4) of the FD&C Act requires FDA to provide data, analysis, and
discussion of the changes in the fee revenue amounts and costs for the process for
the review of prescription drugs, including identifying drivers of such changes and
changes in the average total cost per FTE in the prescription drug review program.
Accordingly, the table below provides data for the PDUFA fee revenue amounts and
process costs for FY 2024 and FY 2025, as well as the changes in these amounts
from FY 2024 to FY 2025. As amended by FDORA section 3626, FDA is also required
to report on changes in the total average cost per FTE in the PDUFA program.
Relevant information about the data provided is as follows:


  - _Fee Revenue Amounts_ represent FDA’s net collection of human drug user fees.

  - _Review Process Costs_ represent FDA’s total expenditure on the PDUFA
program.

  - Numbers are provided for both the most recent fiscal year (FY 2025) and the
prior fiscal year (FY 2024). Although section 736B(a)(4) of the FD&C Act as


_Prescription Drug User Fee Act: FY 2025_ _Page 74_


---

amended by FDARA does not explicitly require this data, they do provide
relevant context necessary to interpret the required information.

In FY 2025, FDA had net collections of $1,457,945,602 in prescription drug user fees,
spent $1,359,676,908.in user fees for the human drug review process, and carried a
cumulative balance of $413,940,928 forward for future fiscal years. Detailed financial
information for the PDUFA user fee program can be found in the FY 2025 PDUFA
financial report. [74]

The process for setting the annual target revenue is set forth in the statute. For FY
2025, the base revenue amount was $1,358,764,346. The FY 2025 base revenue
amount is adjusted for inflation to maintain the purchasing power of fee funds. The
inflation-adjusted base is increased by the strategic hiring and retention adjustment to
cover the costs of hiring and retaining highly qualified scientific and technical staff.
The revenue amount is further adjusted using the capacity planning adjustment for the
resource capacity needs for the process for the review of human drug applications.
An additional dollar amount specified in the statute is then added to provide for
additional FTE positions to support PDUFA VII initiatives. The FY 2025 revenue
amount may be adjusted further, if necessary, to provide for sufficient operating
reserves of carryover user fees. Finally, the amount is adjusted to provide for
additional direct costs yielding a total adjusted fee revenue amount of $1,478,740,000
(rounded to the nearest thousand dollars).

In FY 2025, PDUFA review process costs decreased from FY 2024.


74 See [https://www.fda.gov/about-fda/user-fee-financial-reports/pdufa-financial-reports.](https://www.fda.gov/about-fda/user-fee-financial-reports/pdufa-financial-reports)


_Prescription Drug User Fee Act: FY 2025_ _Page 75_


---

**Table 51. Changes in the Average Total Cost Per FTE in the Prescription Drug**
**Review Program.**

|Revenue/Cost|FY 2024|FY 2025|Change from FY<br>2024 to FY 2025|
|---|---|---|---|
|Fee Revenue Amounts<br>(Net Collections)|$1,381,243,203|$ 1,457,945,602|6%|
|Process Cost<br>(Cost of Activities)<br>|$1,772,198,497|$ 1,758,633,360|-1%|
|Average Total Cost Per<br>FTE|**$227,401**|**$ 236,465**|4%|


##### **C. Number of Employees for Whom Time Reporting Is** **Required**


Section 736B(a)(4) of the FD&C Act requires FDA to provide—for CDER, CBER, OII,
and OC—the number of employees for whom time reporting is required and the
number of employees for whom time reporting is not required. Accordingly, the table
below provides the number of employees within CDER, CBER, OII, and OC who are
required to report their time and those who are not required to report their time as of
September 30, 2025.


These data reflect time reporting across all employees in each entity, rather than only
those engaged in PDUFA program activities.


**Table 52. Time Reporting Requirement for FY 2025.**


|Center|FTEs for Whom Time<br>Reporting is Required|FTEs for Whom Time<br>Reporting is Not<br>Required|
|---|---|---|
|CDER|4,951|0|
|CBER|1,149|0|
|CDRH|1,782|0|
|OC|61|2,343|
|OII|2,901|0|
|**Total**|**10,844**|**2,343**|


_Prescription Drug User Fee Act: FY 2025_ _Page 76_


---

##### **D. Changes in the Average FTE Hours Required to Complete** **the Review of Each Type of Human Drug Application**

Section 736B(a)(4) of the FD&C Act, as amended by FDORA section 3626, requires
that FDA provide data, analysis, and discussion of the changes in the average full-time
equivalent hours required to complete review of each type of human drug application.


**Table 53. Changes in the Average FTE Hours Required to Complete the Review**
**of Each Type of Human Drug Applications.**


|Application Type|Average FTE<br>Hours Required<br>to Complete<br>Human Drug<br>Application<br>Reviews in FY<br>2024|Average FTE<br>Hours Required<br>to Complete<br>Human Drug<br>Application<br>Reviews in FY<br>2025|Change from<br>FY 2024 to FY<br>2025|
|---|---|---|---|
|PDUFA NME and BLA Applications|<br>7,718|<br>7,849|131|
|PDUFA Non-NME Applications|2,869|2,922|53|
|**Total**<br>|**10,587**|10,771|184|


To calculate the average hours required to complete review of PDUFA applications,
FDA compared the 3-year average (sum of hours reported divided by the sum of
applications submitted) ending in FY 2024 to the 3-year average ending in FY 2025.
As application review activities span multiple fiscal years, this method provides an
interpretable benchmark for any shifts in average hours required to complete
application reviews over time.


_Prescription Drug User Fee Act: FY 2025_ _Page 77_


---

#### **Appendix A: List of Approved Applications**

This appendix includes detailed review histories of the NDA and BLA submissions
approved under PDUFA VII in FY 2025. Approvals are grouped by priority designation
and submission year and listed in order of total approval time. _Approval time_ is
presented in months and includes each review cycle’s time with FDA, time with the
sponsor, and the total time on that application.

Review histories of the NDA and BLA submissions approved prior to FY 2025 can be
found in the appendices of the earlier PDUFA performance reports. [1]

When determining total time, FDA calculates the number of months and rounds to the
nearest tenth. Therefore, when cycle times are added, rounding discrepancies may
occur.


Because months consist of varying numbers of days, FDA uses the average number of
days in a month for the average year length, which considers leap years, to calculate
review time in months. Prior to FY 2022, FDA did not consider leap years in our
calculations, which may have caused a submission to appear overdue even though it
was approved on the goal date.


1 [http://www.fda.gov/about-fda/user-fee-performance-reports/pdufa-performance-reports](http://www.fda.gov/about-fda/user-fee-performance-reports/pdufa-performance-reports)


_Appendix A_ _Page A-1_


---

**Terms and Coding Used in Tables in This Appendix**

Action Codes:
AE = Approvable
AP = Approved
CR = Complete Response
NA = Not Approvable
TA = Tentative Approval
WD = Withdrawn

- Denotes Class 1 Resubmission (2-month review-time goal)

Denotes Class 2 Resubmission (6-month review-time goal)

- Expedited review and TA of an NDA by FDA for fixed dose combinations and copackaged antiretroviral medications as part of the President’s Emergency Plan for
AIDS Relief
♦ Application reviewed under the program with review goals starting from the 60-day
filing date, rather than the submission date
♯ Major amendment was received, which extended the action goal date by 3 months [2]


**Table A-1. FY 2025 Priority NDA and BLA Approvals (by Fiscal Year of Receipt).**


|Proprietary Name<br>(Established<br>Name)|Applicant|NME<br>(Y/N)|Review<br>Cycle|Cycle<br>Time<br>(Mos.)|Cycle<br>Result|Total<br>Time<br>(Mos.)|Goal<br>Met|
|---|---|---|---|---|---|---|---|
|<br> <br> <br>**Submitted in FY 2025** <br>|<br> <br> <br>**Submitted in FY 2025** <br>|<br> <br> <br>**Submitted in FY 2025** <br>|<br> <br> <br>**Submitted in FY 2025** <br>|<br> <br> <br>**Submitted in FY 2025** <br>|<br> <br> <br>**Submitted in FY 2025** <br>|<br> <br> <br>**Submitted in FY 2025** <br>|<br> <br> <br>**Submitted in FY 2025** <br>|
|INLEXZO<br>(gemcitabine)<br>|JANSSEN BIOTECH INC|N|First|5.9|AP|5.9|Y|
|<br>YEZTUGO<br>(lenacapavir)<br>|GILEAD SCIENCES INC|N|First|5.9|AP|5.9|Y|
|<br>YEZTUGO<br>(lenacapavir)3 <br>|GILEAD SCIENCES INC<br>|N|First|5.9|AP|5.9|Y|
|<br>ELIQUIS SPRINKLE<br>(apixaban)<br>|BRISTOL MYERS SQUIBB<br>CO|N|First|6.0|AP|6.0|Y|
|<br>AVMAPKI FAKZYNJA<br>CO-PACK<br>(avutometinib and<br>defactinib)<br>|<br>VERASTEM INC|Y|First|6.2|AP|6.2|Y♦|
|<br>DATROWAY<br>(datopotamab<br>deruxtecan-dlnk)|DAIICHI SANKYO, INC.|Y|First|7.3|AP|7.3|Y♦|
|<br>IBTROZI (taletrectinib)|NUVATION BIO INC|Y|First|7.6|AP|7.6|Y♦|


2 Beginning with PDUFA V, a major amendment can be received any time during the review cycle and extend the
goal date by 3 months. If the review cycle occurred prior to FY 2013, the major amendment must have been received
within 3 months of the action due date to extend the action goal date by 3 months.
3 These two NDAs are for the same active moiety but different dosage forms (i.e., Injection versus Tablet).


_Appendix A_ _Page A-2_


---

|Proprietary Name<br>(Established<br>Name)|Applicant|NME<br>(Y/N)|Review<br>Cycle|Cycle<br>Time<br>(Mos.)|Cycle<br>Result|Total<br>Time<br>(Mos.)|Goal<br>Met|
|---|---|---|---|---|---|---|---|
|<br>MODEYSO<br>(dordaviprone)<br>|CHIMERIX INC|Y|First|<br>7.6|AP|<br>7.6|Y♦|
|<br>PAPZIMEOS<br>(zopapogene<br>imadenovec-drba)<br>|PRECIGEN, INC.<br>|Y|First|7.6|AP|7.6|Y♦|
|<br>HERNEXEOS<br>(zongertinib)|BOEHRINGER INGELHEIM<br>PHARMACEUTICALS INC<br>|Y|First|7.7|AP|7.7|Y♦|
|<br>ZEGFROVY<br>(sunvozertinib)<br>|<br>DIZAL (JIANGSU)<br>PHARMACEUTICAL CO<br>LTD|Y|First|7.8|AP|7.8|Y♦|
|KEYTRUDA QLEX<br>(pembrolizumab and<br>berahyaluronidase<br>alfa-pmph)<br>|<br>MERCK SHARP & DOHME<br>LLC<br>|Y|First|7.9|AP|7.9|Y♦|
|<br>ENFLONSIA<br>(clesrovimab-cfor)<br>|MERCK SHARP & DOHME<br>LLC|Y|First|8.0|AP|8.0|Y♦|
|<br>BRINSUPRI<br>(brensocatib)|<br>INSMED INC<br>|Y|First|8.0|AP|8.0|Y♦|
|<br>RHAPSIDO<br>(remibrutinib)<br>|NOVARTIS<br>PHARMACEUTICALS<br>CORP<br>|Y|First|8.0|AP|8.0|Y♦|
|KOSELUGO<br>(selumetinib)|<br>ASTRAZENECA<br>PHARMACEUTICALS LP|N|First|8.8|AP|8.8|Y#|
|<br> <br>**Submitted in FY 2024** <br>|<br> <br>**Submitted in FY 2024** <br>|<br> <br>**Submitted in FY 2024** <br>|<br> <br>**Submitted in FY 2024** <br>|<br> <br>**Submitted in FY 2024** <br>|<br> <br>**Submitted in FY 2024** <br>|<br> <br>**Submitted in FY 2024** <br>|<br> <br>**Submitted in FY 2024** <br>|
|EMBLAVEO<br>(aztreonam and<br>avibactam)|ABBVIE INC|N|First|6.0|AP|6.0|Y|
|<br>ITOVEBI (inavolisib)<br>|GENENTECH INC|Y|First|6.5|AP|6.5|Y♦|
|EMRELIS<br>(telisotuzumab<br>vedotin-tllv)<br>|ABBVIE INC.<br>|Y|First|7.5|AP|7.5|Y♦|
|<br>CRENESSITY<br>(crinecerfont)<br>|NEUROCRINE<br>BIOSCIENCES INC<br>|Y|First|7.5|AP|7.5|Y♦|
|<br>CRENESSITY<br>(crinecerfont)4 <br>|<br>NEUROCRINE<br>BIOSCIENCES INC<br>|N|First|7.5|AP|7.5|Y♦|
|<br>GOMEKLI<br>(mirdametinib)<br>|<br>SPRINGWORKS<br>THERAPEUTICS INC<br>|Y|First|7.5|AP|7.5|Y♦|
|<br>GOMEKLI<br>(mirdametinib)5|<br>SPRINGWORKS<br>THERAPEUTICS INC|N|First|7.5|AP|7.5|Y♦|


4 These two NDAs are for the same active moiety but different dosage forms (i.e.Solution versus
Capsule), and only one retains the NME designation upon approval; in this case, the NDA for the
Capsule dosage form retained the NME designation.
5 These two NDAs are for the same active moiety but different dosage forms (i.e.Tablet versus Capsule),
and only one retains the NME designation upon approval; in this case, the NDA for the Tablet dosage
form retained the NME designation.


_Appendix A_ _Page A-3_


---

|Proprietary Name<br>(Established<br>Name)|Applicant|NME<br>(Y/N)|Review<br>Cycle|Cycle<br>Time<br>(Mos.)|Cycle<br>Result|Total<br>Time<br>(Mos.)|Goal<br>Met|
|---|---|---|---|---|---|---|---|
|<br>ALYFTREK<br>(vanzacaftor,<br>tezacaftor, and<br>deutivacaftor)<br>|VERTEX<br>PHARMACEUTICALS INC<br>|Y|First|<br>7.6|AP|<br>7.6|Y♦|
|<br>ZIIHERA<br>(zanidatamab)|JAZZ PHARMACEUTICALS<br>IRELAND LIMITED<br>|Y|First|7.8|AP|7.8|Y♦|
|<br>CTEXLI (chenodiol)<br>|<br>MIRUM<br>PHARMACEUTICALS INC|N|First|7.8|AP|7.8|Y#|
|IMAAVY (nipocalimab-<br>aahu)<br>|<br>JANSSEN BIOTECH, INC.|Y|First|8.0|AP|8.0|Y♦|
|<br>BLUJEPA<br>(gepotidacin)<br>|GLAXOSMITHKLINE LLC<br>|Y|First|8.0|AP|8.0|Y♦|
|<br>TRYNGOLZA<br>(olezarsen)<br>|IONIS<br>PHARMACEUTICALS INC<br>|Y|First|8.0|AP|8.0|Y♦|
|<br>JOURNAVX<br>(suzetrigine)<br>|<br>VERTEX<br>PHARMACEUTICALS INC<br>|Y|First|8.0|AP|8.0|Y♦|
|<br>ROMVIMZA<br>(vimsetinib)<br>|<br>DECIPHERA<br>PHARMACEUTICALS LLC|Y|First|8.0|AP|8.0|Y♦|
|<br>KEBILIDI<br>(eladocagene<br>exuparvovec-tneq)<br>|<br>PTC THERAPEUTICS|Y|First|8.0|AP|8.0|Y♦|
|<br>VIMKUNYA<br>(chikungunya vaccine,<br>recombinant)<br>|BAVARIAN NORDIC A/S|Y|First|8.0|AP|8.0|Y♦|
|<br>MNEXSPIKE (covid-<br>19 vaccine, mrna)<br>|MODERNATX, INC.<br>|Y|First|8.0|AP|8.0|Y♦|
|<br>VYKAT XR (diazoxide<br>choline)<br>|SOLENO THERAPEUTICS<br>INC|N|First|8.9|AP|8.9|Y#|
|<br>BIZENGRI<br>(ZENOCUTUZUMAB-<br>ZBCO)<br>(zenocutuzumab-<br>zbco)<br>|<br>PARTNER<br>THERAPEUTICS INC.<br>|Y|First|9.0|AP|9.0|Y♦#|
|<br>REVUFORJ<br>(revumenib)<br>|SYNDAX<br>PHARMACEUTICALS INC|Y|First|9.7|AP|9.7|Y♦#|
|<br>ENCELTO<br>(revakinagene<br>taroretcel-lwey)<br>|<br>NEUROTECH<br>PHARMACEUTICALS INC.|Y|First|10.5|AP|10.5|Y♦#|
|<br>SYMVESS (acellular<br>tissue engineered<br>vessel-tyod)|HUMACYTE GLOBAL INC.|Y|First|12.3|AP|12.3|N♦|
|<br>LYNOZYFIC<br>(linvoseltamab-gcpt)|REGENERON<br>PHARMACEUTICALS, INC.|Y|First|8.0|CR|8.0|Y♦|
|<br>LYNOZYFIC<br>(linvoseltamab-gcpt)|REGENERON<br>PHARMACEUTICALS, INC.|Y|Sponsor|4.7||12.7||
|<br>LYNOZYFIC<br>(linvoseltamab-gcpt)|REGENERON<br>PHARMACEUTICALS, INC.|Y|Second|5.7|AP|18.4|Y∆|


_Appendix A_ _Page A-4_


---

|Proprietary Name<br>(Established<br>Name)|Applicant|NME<br>(Y/N)|Review<br>Cycle|Cycle<br>Time<br>(Mos.)|Cycle<br>Result|Total<br>Time<br>(Mos.)|Goal<br>Met|
|---|---|---|---|---|---|---|---|
|<br>FORZINITY<br>(elamipretide)|STEALTH<br>BIOTHERAPEUTICS INC|Y|First|<br>15.5|CR|<br>15.5|N♦#|
|<br>FORZINITY<br>(elamipretide)|STEALTH<br>BIOTHERAPEUTICS INC|Y|Sponsor|3.0||18.5||
|<br>FORZINITY<br>(elamipretide)|STEALTH<br>BIOTHERAPEUTICS INC|Y|Second|1.1|AP|19.6|Y∆|
|**Submitted in FY 2023**|**Submitted in FY 2023**|**Submitted in FY 2023**|**Submitted in FY 2023**|**Submitted in FY 2023**|**Submitted in FY 2023**|**Submitted in FY 2023**|**Submitted in FY 2023**|
|VYLOY<br>(zolbetuximab-clzb)|ASTELLAS PHARMA US,<br>INC.|Y|First|7.8|CR|7.8|Y♦|
|VYLOY<br>(zolbetuximab-clzb)|ASTELLAS PHARMA US,<br>INC.|Y|Sponsor|4.1||11.9||
|VYLOY<br>(zolbetuximab-clzb)|ASTELLAS PHARMA US,<br>INC.|Y|Second|5.3|AP|17.2|Y∆|
|ZEVASKYN<br>(prademagene<br>zamikeracel)|ABEONA THERAPEUTICS<br>INC.|Y|First|6.7|CR|6.7|Y♦|
|ZEVASKYN<br>(prademagene<br>zamikeracel)|ABEONA THERAPEUTICS<br>INC.|Y|Sponsor|6.4||13.1||
|ZEVASKYN<br>(prademagene<br>zamikeracel)|ABEONA THERAPEUTICS<br>INC.|Y|Second|6.0|AP|19.1|Y∆|
|CLOTIC (clotrimazole)|LABORATORIOS SALVAT<br>SA|N|First|5.9|CR|5.9|Y|
|CLOTIC (clotrimazole)|LABORATORIOS SALVAT<br>SA|N|Sponsor|24.0||29.9||
|CLOTIC (clotrimazole)|LABORATORIOS SALVAT<br>SA|N|Second|5.7|AP|35.6|Y∆|
|**Submitted in FY 2022**|**Submitted in FY 2022**|**Submitted in FY 2022**|**Submitted in FY 2022**|**Submitted in FY 2022**|**Submitted in FY 2022**|**Submitted in FY 2022**|**Submitted in FY 2022**|
|ALHEMO<br>(concizumab-mtci)|NOVO NORDISK INC.|Y|First|8.0|CR|8.0|Y♦|
|ALHEMO<br>(concizumab-mtci)|NOVO NORDISK INC.|Y|Sponsor|13.9||21.9||
|ALHEMO<br>(concizumab-mtci)|NOVO NORDISK INC.|Y|Second|6.0|AP|27.9|Y∆|
|**Submitted in FY 2021**|**Submitted in FY 2021**|**Submitted in FY 2021**|**Submitted in FY 2021**|**Submitted in FY 2021**|**Submitted in FY 2021**|**Submitted in FY 2021**|**Submitted in FY 2021**|
|ORLYNVAH<br>(sulopenem etzadroxil<br>and probenecid)|ITERUM THERAPEUTICS<br>US LTD|Y|First|7.9|CR|7.9|Y♦|
|ORLYNVAH<br>(sulopenem etzadroxil<br>and probenecid)|ITERUM THERAPEUTICS<br>US LTD|Y|Sponsor|33.1||41.0||
|ORLYNVAH<br>(sulopenem etzadroxil<br>and probenecid)|ITERUM THERAPEUTICS<br>US LTD|Y|Second|6.0|AP|47.0|Y∆|
|**Submitted in FY 2020**|**Submitted in FY 2020**|**Submitted in FY 2020**|**Submitted in FY 2020**|**Submitted in FY 2020**|**Submitted in FY 2020**|**Submitted in FY 2020**|**Submitted in FY 2020**|
|RYONCIL<br>(remestemcel-l-rknd)<br>|MESOBLAST, INC.<br>|Y|First|8.0|CR|8.0|Y♦|
|RYONCIL<br>(remestemcel-l-rknd)<br>|MESOBLAST, INC.<br>|Y|Sponsor|28.0||36.0||
|RYONCIL<br>(remestemcel-l-rknd)<br>|MESOBLAST, INC.<br>|Y|Second|6.0|CR|42.0|Y∆|
|RYONCIL<br>(remestemcel-l-rknd)<br>|MESOBLAST, INC.<br>|Y|Sponsor|11.2||53.2||
|RYONCIL<br>(remestemcel-l-rknd)<br>|MESOBLAST, INC.<br>|Y|Third|5.4|AP|58.6|Y∆|


_Appendix A_ _Page A-5_


---

**Table A-2. FY 2025 Standard NDA and BLA Approvals (by Fiscal Year of Receipt).**


|Proprietary Name<br>(Established<br>Name)|Applicant|NME<br>(Y/N)|Review<br>Cycle|Cycle<br>Time<br>(Mos.)|Cycle<br>Result|Total<br>Time<br>(Mos.)|Goal<br>Met|
|---|---|---|---|---|---|---|---|
|**Submitted in FY 2025** <br>|**Submitted in FY 2025** <br>|**Submitted in FY 2025** <br>|**Submitted in FY 2025** <br>|**Submitted in FY 2025** <br>|**Submitted in FY 2025** <br>|**Submitted in FY 2025** <br>|**Submitted in FY 2025** <br>|
|E-Z-DISK (barium<br>sulfate)|BRACCO DIAGNOSTICS INC|N|First|8.3|AP|8.3|Y|
|<br>KYXATA (carboplatin) <br>|AVYXA HOLDINGS LLC|N|First|8.4|AP|8.4|Y|
|LEQEMBI IQLIK<br>(lecanemab-irmb) <br>|EISAI, INCORPORATED|N|First|9.9|AP|9.9|Y|
|<br>ZOLYMBUS<br>(bimatoprost)|THEA PHARMA INC|N|First|9.9|AP|9.9|Y|
|<br>escitalopram <br>|ALMATICA PHARMA LLC <br>|N|First|9.9|AP|9.9|Y|
|ENBUMYST<br>(bumetanide)|CORSTASIS<br>THERAPEUTICS INC <br>|N|First|9.9|AP|9.9|Y|
|<br>CAMCEVI ETM<br>(leuprolide mesylate)|<br>FORESEE<br>PHARMACEUTICALS CO<br>LTD|N|First|9.9|AP|9.9|Y|
|CYKLX (articaine) <br>|<br>AMERICAN GENOMICS LLC|N|First|10.0|AP|10.0|Y|
|TONMYA<br>(cyclobenzaprine<br>hydrochloride ) <br>|TONIX PHARMACEUTICALS<br>INC|N|First|10.0|AP|10.0|Y|
|<br>INLURIYO<br>(imlunestrant)|ELI LILLY AND CO|Y|First|10.8|AP|10.8|Y♦|
|<br>**Submitted in FY 2024** <br>|<br>**Submitted in FY 2024** <br>|<br>**Submitted in FY 2024** <br>|<br>**Submitted in FY 2024** <br>|<br>**Submitted in FY 2024** <br>|<br>**Submitted in FY 2024** <br>|<br>**Submitted in FY 2024** <br>|<br>**Submitted in FY 2024** <br>|
|BRUKINSA<br>(zanubrutinib)|BEONE MEDICINES USA INC <br>|N|First|9.3|AP|9.3|Y|
|<br>DANZITEN (nilotinib) <br>|AZURITY<br>PHARMACEUTICALS INC|N|First|9.3|AP|9.3|Y|
|AVGEMSI<br>(gemcitabine)|<br>AVYXA HOLDINGS LLC <br>|N|First|9.3|AP|9.3|Y|
|<br>famotidine|SAGENT<br>PHARMACEUTICALS|N|First|9.5|AP|9.5|Y|
|IMKELDI (imatinib) <br>|<br>SHORLA ONCOLOGY|N|First|9.7|AP|9.7|Y|
|LOPRESSOR<br>(metoprolol tartrate) <br>|RUBICON RESEARCH LTD|N|First|9.7|AP|9.7|Y|
|<br>OPDIVO QVANTIG<br>(nivolumab and<br>hyaluronidase-nvhy) <br>|BRISTOL-MYERS SQUIBB<br>COMPANY|N|First|9.9|AP|9.9|Y|
|<br>piperacillin-<br>tazobactam and<br>sodium chloride|B BRAUN MEDICAL INC <br>|N|First|9.9|AP|9.9|Y|
|<br>VYSCOXA (celecoxib)|CARWIN PHARMACEUTICAL<br>ASSOCIATES LLC|N|First|9.9|AP|9.9|Y|


_Appendix A_ _Page A-6_


---

|Proprietary Name<br>(Established<br>Name)|Applicant|NME<br>(Y/N)|Review<br>Cycle|Cycle<br>Time<br>(Mos.)|Cycle<br>Result|Total<br>Time<br>(Mos.)|Goal<br>Met|
|---|---|---|---|---|---|---|---|
|RALDESY (trazodone<br>hydrochloride) <br>|KAMAT PHARMATECH LLC|N|First|9.9|AP|9.9|Y|
|<br>EMROSI (minocycline<br>hydrochloride) <br>|JOURNEY MEDICAL CORP|N|First|9.9|AP|9.9|Y|
|<br>GOZELLIX (kit for the<br>preparation of gallium<br>ga 68 gozetotide)|TELIX INNOVATIONS SA|N|First|9.9|AP|9.9|Y|
|<br>ZUSDURI (mitomycin) <br>|UROGEN PHARMA LTD|N|First|10.0|AP|10.0|Y|
|phenylephrine<br>hydrochloride in<br>sodium chloride|DR REDDYS<br>LABORATORIES SA|N|First|10.0|AP|10.0|Y|
|<br>rocuronium bromide <br>|FRESENIUS KABI USA LLC <br>|N|First|10.0|AP|10.0|Y|
|pyridostigmine<br>bromide|AMNEAL<br>PHARMACEUTICALS LLC <br>|N|First|10.0|AP|10.0|Y|
|<br>daptomycin <br>|<br>MAIA PHARMACEUTICALS<br>INC|N|First|10.0|AP|10.0|Y|
|WIDAPLIK<br>(telmisartan,<br>amlodipine, and<br>indapamide) <br>|<br>AZURITY<br>PHARMACEUTICALS INC <br>|N|First|10.0|AP|10.0|Y|
|<br>LIVMARLI<br>(maralixibat )|MIRUM PHARMACEUTICALS<br>INC|N|First|10.0|AP|10.0|Y|
|<br>SDAMLO (amlodipine)|<br>BRILLIAN PHARMA INC|N|First|10.0|AP|10.0|Y|
|trabectedin <br>|EVER VALINJECT GMBH|N|First|10.0|TA|10.0|Y|
|DOPTELET<br>SPRINKLE<br>(avatrombopag)|AKARX INC <br>|N|First|10.0|AP|10.0|Y|
|<br>VOSTALLY (ramipril) <br>|ROSEMONT<br>PHARMACEUTICALS INC <br>|N|First|10.0|AP|10.0|Y|
|ATMEKSI<br>(methocarbamol) <br>|<br>ROSEMONT<br>PHARMACEUTICALS INC|N|First|10.0|AP|10.0|Y|
|<br>ARYNTA<br>(lisdexamphetamine<br>dimesylate) <br>|<br>AZURITY<br>PHARMACEUTICALS INC|N|First|10.0|AP|10.0|Y|
|<br>INZIRQO<br>(hydrochlorothiazide)|NOVITIUM PHARMA LLC|N|First|10.1|AP|10.1|Y|
|<br>EVRYSDI (risdiplam)|GENENTECH INC|N|First|10.1|AP|10.1|Y|
|IOMERVU (iomeprol)6 <br>|BRACCO DIAGNOSTICS INC|Y|First|11.5|AP|11.5|Y♦|
|DATROWAY<br>(datopotamab<br>deruxtecan-dlnk)|DAIICHI SANKYO, INC.|Y|First|11.6|AP|11.6|Y♦|


_Appendix A_ _Page A-7_


---

|Proprietary Name<br>(Established<br>Name)|Applicant|NME<br>(Y/N)|Review<br>Cycle|Cycle<br>Time<br>(Mos.)|Cycle<br>Result|Total<br>Time<br>(Mos.)|Goal<br>Met|
|---|---|---|---|---|---|---|---|
|ENSACOVE<br>(ensartinib)|XCOVERY HOLDINGS INC|Y|First|11.7|AP|11.7|Y|
|<br>VIZZ (aceclidine) <br>|LENZ THERAPEUTICS INC|Y|First|11.7|AP|11.7|Y♦|
|AUCATZYL<br>(obecabtagene<br>autoleucel) <br>|AUTOLUS, INC.|Y|First|11.7|AP|11.7|Y♦|
|<br>ATTRUBY<br>(acoramidis)|BRIDGEBIO PHARMA INC|Y|First|11.8|AP|11.8|Y♦|
|<br>IOMERVU (iomeprol)6 <br>|BRACCO DIAGNOSTICS INC|Y|First|11.9|AP|11.9|Y♦|
|TRYPTYR<br>(acoltremon) <br>|ALCON LABORATORIES INC|Y|First|11.9|AP|11.9|Y♦|
|<br>PENMENVY<br>(meningococcal<br>groups a, b, c, w, and<br>y vaccine) <br>|GLAXOSMITHKLINE<br>BIOLOGICALS|Y|First|12.0|AP|12.0|Y♦|
|<br>QIVIGY (immune<br>globulin intravenous,<br>human-kthm, 10%<br>solution) <br>|KEDRION, S.P.A.|Y|First|12.0|AP|12.0|Y♦|
|<br>HYMPAVZI<br>(marsticimab-hncq) <br>|PFIZER INC. <br>|Y|First|12.0|AP|12.0|Y♦|
|<br>NEMLUVIO<br>(nemolizumab-ilto)|GALDERMA<br>LABORATORIES, L.P.|Y|First|12.0|AP|12.0|Y♦|
|<br>QFITLIA (fitusiran) <br>|<br>GENZYME CORP <br>|Y|First|12.0|AP|12.0|Y♦|
|PALSONIFY<br>(paltusotine) <br>|CRINETICS<br>PHARMACEUTICALS INC|Y|First|12.0|AP|12.0|Y♦|
|<br>ANZUPGO<br>(delgocitinib) <br>|<br>LEO PHARMA AS <br>|Y|First|12.0|AP|12.0|Y♦|
|<br>VANRAFIA<br>(atrasentan) <br>|NOVARTIS<br>PHARMACEUTICALS CORP <br>|Y|First|12.0|AP|12.0|Y♦|
|<br>DAWNZERA<br>(donidalorsen) <br>|<br>IONIS PHARMACEUTICALS<br>INC|Y|First|12.0|AP|12.0|Y♦|
|<br>SEPHIENCE<br>(sepiapterin) <br>|<br>PTC THERAPEUTICS INC|Y|First|12.0|AP|12.0|Y♦|
|<br>WAYRILZ<br>(rilzabrutinib)|GENZYME CORP|Y|First|12.0|AP|12.0|Y♦|
|<br>NILCEYA (nilotinib)|CIPLA LTD|N|First|12.3|AP|12.3|Y#|
||||First|10.0|CR|10.0|Y|


6 NDA reviewed under the PDUFA V program. At time of receipt, the active ingredient Iomeprol had never been
approved in the United States, allowing for NME designation; however, at time of approval, iomeprol had already
been approved for marketing in another application


_Appendix A_ _Page A-8_


---

|Proprietary Name<br>(Established<br>Name)|Applicant|NME<br>(Y/N)|Review<br>Cycle|Cycle<br>Time<br>(Mos.)|Cycle<br>Result|Total<br>Time<br>(Mos.)|Goal<br>Met|
|---|---|---|---|---|---|---|---|
|BRYNOVIN<br>(sitagliptin)<br>|AZURITY<br>PHARMACEUTICALS INC<br>|<br>N|Sponsor|0.5||10.5||
|BRYNOVIN<br>(sitagliptin)<br>|AZURITY<br>PHARMACEUTICALS INC<br>|<br>N|Second|1.9|AP|12.4|Y▲|
|EKTERLY<br>(sebetralstat)|KALVISTA<br>PHARMACEUTICALS LTD <br>|Y|First|12.5|AP|12.5|N♦|
|<br>BEIZRAY (docetaxel) <br>|<br>ZHUHAI BEIHAI BIOTECH<br>CO LTD <br>|N|First|12.6|AP|12.6|Y#|
|KHINDIVI<br>(hydrocortisone)|<br>ETON PHARMACEUTICALS<br>INC|N|First|12.9|AP|12.9|Y|
|<br>MYINFLA (colchicine) <br>|<br>PHARMASCIENCE INC|N|First|13.0|TA|13.0|Y#|
|NUVAXOVID (covid-<br>19 vaccine,<br>adjuvanted)|NOVAVAX, INC.|Y|First|13.5|AP|13.5|N♦|
|<br>ARBLI (losartan<br>potassium)|SCIENTURE LLC|N|First|10.0|CR|10.0|Y|
|<br>ARBLI (losartan<br>potassium)|SCIENTURE LLC|N|Sponsor|1.0||11.0||
|<br>ARBLI (losartan<br>potassium)|SCIENTURE LLC|N|Second|5.8|AP|16.8|Y∆|
|SUBVENITE<br>(lamotrigine)|OWP PHARMACEUTICALS<br>INC|N|First|10.0|CR|10.0|Y|
|SUBVENITE<br>(lamotrigine)|OWP PHARMACEUTICALS<br>INC|N|Sponsor|2.4||12.4||
|SUBVENITE<br>(lamotrigine)|OWP PHARMACEUTICALS<br>INC|N|Second|6.0|AP|18.4|Y∆|
|ANDEMBRY<br>(garadacimab-gxii)|CSL BEHRING LLC|Y|First|11.8|CR|11.8|Y♦|
|ANDEMBRY<br>(garadacimab-gxii)|CSL BEHRING LLC|Y|Sponsor|2.3||14.1||
|ANDEMBRY<br>(garadacimab-gxii)|CSL BEHRING LLC|Y|Second|5.9|AP|20.0|Y∆|
|**Submitted in FY 2023**|**Submitted in FY 2023**|**Submitted in FY 2023**|**Submitted in FY 2023**|**Submitted in FY 2023**|**Submitted in FY 2023**|**Submitted in FY 2023**|**Submitted in FY 2023**|
|epinephrine in sodium<br>chloride|BAXTER HEALTHCARE<br>CORP|N|First|10.0|CR|10.0|Y|
|epinephrine in sodium<br>chloride|BAXTER HEALTHCARE<br>CORP|N|Sponsor|2.4||12.4||
|epinephrine in sodium<br>chloride|BAXTER HEALTHCARE<br>CORP|N|Second|4.6|AP|17.0|Y∆|
|diltiazem<br>hydrochloride in<br>sodium chloride|HQ SPECIALTY PHARMA<br>CORP|N|First|9.9|CR|9.9|Y|
|diltiazem<br>hydrochloride in<br>sodium chloride|HQ SPECIALTY PHARMA<br>CORP|N|Sponsor|1.2||11.1||
|diltiazem<br>hydrochloride in<br>sodium chloride|HQ SPECIALTY PHARMA<br>CORP|N|Second|6.0|AP|17.1|Y∆|
|ONTRALFY<br>(tizanidine)|FIDELITY BIOPHARMA CO<br>USA|N|First|10.0|CR|10.0|Y|
|ONTRALFY<br>(tizanidine)|FIDELITY BIOPHARMA CO<br>USA|N|Sponsor|2.5||12.5||
|ONTRALFY<br>(tizanidine)|FIDELITY BIOPHARMA CO<br>USA|N|Second|6.0|AP|18.5|Y∆|
||||First|12.9|CR|12.9|Y#|


_Appendix A_ _Page A-9_


---

|Proprietary Name<br>(Established<br>Name)|Applicant|NME<br>(Y/N)|Review<br>Cycle|Cycle<br>Time<br>(Mos.)|Cycle<br>Result|Total<br>Time<br>(Mos.)|Goal<br>Met|
|---|---|---|---|---|---|---|---|
|HEMICLOR<br>(chlorthalidone)|PRM PHARMA LLC|N|Sponsor|4.4||17.3||
|HEMICLOR<br>(chlorthalidone)|PRM PHARMA LLC|N|Second|1.9|AP|19.2|Y▲|
|bendamustine<br>hydrochloride|DR REDDYS<br>LABORATORIES LTD|N|First|13.0|CR|13.0|Y#|
|bendamustine<br>hydrochloride|DR REDDYS<br>LABORATORIES LTD|N|Sponsor|2.6||15.6||
|bendamustine<br>hydrochloride|DR REDDYS<br>LABORATORIES LTD|N|Second|5.6|AP|21.2|Y∆|
|MIUDELLA (copper<br>intrauterine system)|SEBELA WOMENS HEALTH<br>INC|<br>N|First|10.0|CR|10.0|Y|
|MIUDELLA (copper<br>intrauterine system)|SEBELA WOMENS HEALTH<br>INC|<br>N|Sponsor|3.8||13.8||
|MIUDELLA (copper<br>intrauterine system)|SEBELA WOMENS HEALTH<br>INC|<br>N|Second|9.1|AP|22.9|Y∆#|
|UNLOXCYT<br>(cosibelimab-ipdl)|CHECKPOINT<br>THERAPEUTICS, INC.|Y|First|11.4|CR|11.4|Y♦|
|UNLOXCYT<br>(cosibelimab-ipdl)|CHECKPOINT<br>THERAPEUTICS, INC.|Y|Sponsor|6.4||17.8||
|UNLOXCYT<br>(cosibelimab-ipdl)|CHECKPOINT<br>THERAPEUTICS, INC.|Y|Second|5.5|AP|23.3|Y∆|
|QAMZOVA<br>(meloxicam)|NANJING DELOVA BIOTECH<br>CO LTD|N|First|10.0|CR|10.0|Y|
|QAMZOVA<br>(meloxicam)|NANJING DELOVA BIOTECH<br>CO LTD|N|Sponsor|8.0||18.0||
|QAMZOVA<br>(meloxicam)|NANJING DELOVA BIOTECH<br>CO LTD|N|Second|6.0|AP|24.0|Y∆|
|LOPRESSOR<br>(metoprolol tartrate)|XTM CONSULTING LLC|N|First|9.9|CR|9.9|Y|
|LOPRESSOR<br>(metoprolol tartrate)|XTM CONSULTING LLC|N|Sponsor|8.6||18.5||
|LOPRESSOR<br>(metoprolol tartrate)|XTM CONSULTING LLC|N|Second|5.9|AP|24.4|Y∆|
|ATZUMI<br>(dihydroergotamine)|SATSUMA<br>PHARMACEUTICALS INC|N|First|10.1|CR|10.1|Y|
|ATZUMI<br>(dihydroergotamine)|SATSUMA<br>PHARMACEUTICALS INC|N|Sponsor|9.4||19.5||
|ATZUMI<br>(dihydroergotamine)|SATSUMA<br>PHARMACEUTICALS INC|N|Second|6.0|AP|25.5|Y∆|
|XIFYRM (meloxicam)|AZURITY<br>PHARMACEUTICALS INC|N|First|10.0|CR|10.0|Y|
|XIFYRM (meloxicam)|AZURITY<br>PHARMACEUTICALS INC|N|Sponsor|10.8||20.8||
|XIFYRM (meloxicam)|AZURITY<br>PHARMACEUTICALS INC|N|Second|6.0|AP|26.8|Y∆|
|AUSUSVAR<br>(rivaroxaban)|AUSON PHARMACEUTICALS<br>INC|N|First|10.0|CR|10.0|Y|
|AUSUSVAR<br>(rivaroxaban)|AUSON PHARMACEUTICALS<br>INC|N|Sponsor|11.7||21.7||
|AUSUSVAR<br>(rivaroxaban)|AUSON PHARMACEUTICALS<br>INC|N|Second|6.0|TA|27.7|N∆|
|LASIX ONYU<br>(furosemide)|SQ INNOVATION INC|N|First|10.0|CR|10.0|Y|
|LASIX ONYU<br>(furosemide)|SQ INNOVATION INC|N|Sponsor|3.2||13.2||
|LASIX ONYU<br>(furosemide)|SQ INNOVATION INC|N|Second|6.0|TA|19.2|Y∆|
|LASIX ONYU<br>(furosemide)|SQ INNOVATION INC|N|Sponsor|9.6||28.8||
|LASIX ONYU<br>(furosemide)|SQ INNOVATION INC|N|Third|2.0|AP|30.8|Y▲|
|**Submitted in FY 2022**|**Submitted in FY 2022**|**Submitted in FY 2022**|**Submitted in FY 2022**|**Submitted in FY 2022**|**Submitted in FY 2022**|**Submitted in FY 2022**|**Submitted in FY 2022**|
|VYALEV<br>(foscarbidopa and<br>foslevodopa)|ABBVIE INC|N|First|9.9|CR|9.9|Y|
|VYALEV<br>(foscarbidopa and<br>foslevodopa)|ABBVIE INC|N|Sponsor|9.1||19.0||
|VYALEV<br>(foscarbidopa and<br>foslevodopa)|ABBVIE INC|N|Second|6.0|CR|25.0|Y∆|


_Appendix A_ _Page A-10_


---

|Proprietary Name<br>(Established<br>Name)|Applicant|NME<br>(Y/N)|Review<br>Cycle|Cycle<br>Time<br>(Mos.)|Cycle<br>Result|Total<br>Time<br>(Mos.)|Goal<br>Met|
|---|---|---|---|---|---|---|---|
||||Sponsor|1.9||26.9||
||||Third|2.0|AP|28.9|Y▲|
|RAPIBLYK (landiolol)|AOP ORPHAN<br>PHARMACEUTICALS GMBH|Y|First|12.0|CR|12.0|Y♦|
|RAPIBLYK (landiolol)|AOP ORPHAN<br>PHARMACEUTICALS GMBH|Y|Sponsor|12.0||24.0||
|RAPIBLYK (landiolol)|AOP ORPHAN<br>PHARMACEUTICALS GMBH|Y|Second|5.8|AP|29.8|Y∆|
|ONAPGO<br>(apomorphine<br>hydrochloride)|MDD US OPERATIONS LLC<br>A SUB OF SUPERNUS<br>PHARMACEUTICALS INC|<br> <br>N|First|10.0|CR|10.0|Y|
|ONAPGO<br>(apomorphine<br>hydrochloride)|MDD US OPERATIONS LLC<br>A SUB OF SUPERNUS<br>PHARMACEUTICALS INC|<br> <br>N|Sponsor|11.9||21.9||
|ONAPGO<br>(apomorphine<br>hydrochloride)|MDD US OPERATIONS LLC<br>A SUB OF SUPERNUS<br>PHARMACEUTICALS INC|<br> <br>N|Second|6.0|CR|27.9|Y∆|
|ONAPGO<br>(apomorphine<br>hydrochloride)|MDD US OPERATIONS LLC<br>A SUB OF SUPERNUS<br>PHARMACEUTICALS INC|<br> <br>N|Sponsor|3.9||31.8||
|ONAPGO<br>(apomorphine<br>hydrochloride)|MDD US OPERATIONS LLC<br>A SUB OF SUPERNUS<br>PHARMACEUTICALS INC|<br> <br>N|Third|6.1|AP|37.9|N∆|
|**Submitted in FY 2021**|**Submitted in FY 2021**|**Submitted in FY 2021**|**Submitted in FY 2021**|**Submitted in FY 2021**|**Submitted in FY 2021**|**Submitted in FY 2021**|**Submitted in FY 2021**|
|SYMBAVO<br>(meloxicam and<br>rizatriptan)|AXSOME THERAPEUTICS<br>INC|N|First|10.0|CR|10.0|Y|
|SYMBAVO<br>(meloxicam and<br>rizatriptan)|AXSOME THERAPEUTICS<br>INC|N|Sponsor|27.1||37.1||
|SYMBAVO<br>(meloxicam and<br>rizatriptan)|AXSOME THERAPEUTICS<br>INC|N|Second|6.0|AP|43.1|Y∆|
|penpulimab-kcqx|AKESO BIOPHARMA CO.,<br>LTD.|Y|First|30.1|CR|30.1|N♦#|
|penpulimab-kcqx|AKESO BIOPHARMA CO.,<br>LTD.|Y|Sponsor|8.4||38.5||
|penpulimab-kcqx|AKESO BIOPHARMA CO.,<br>LTD.|Y|Second|6.7|AP|45.2|N∆|
|BREKIYA<br>(dihydroergotamine<br>mesylate)|AMNEAL<br>PHARMACEUTICALS LLC|N|First|10.0|CR|10.0|Y|
|BREKIYA<br>(dihydroergotamine<br>mesylate)|AMNEAL<br>PHARMACEUTICALS LLC|N|Sponsor|12.0||22.0||
|BREKIYA<br>(dihydroergotamine<br>mesylate)|AMNEAL<br>PHARMACEUTICALS LLC|N|Second|5.9|CR|27.9|Y∆|
|BREKIYA<br>(dihydroergotamine<br>mesylate)|AMNEAL<br>PHARMACEUTICALS LLC|N|Sponsor|16.0||43.9||
|BREKIYA<br>(dihydroergotamine<br>mesylate)|AMNEAL<br>PHARMACEUTICALS LLC|N|Third|5.9|AP|49.8|Y∆|
|epinephrine|FRESENIUS KABI USA LLC|N|First|9.9|CR|9.9|Y|
|epinephrine|FRESENIUS KABI USA LLC|N|Sponsor|8.0||17.9||
|epinephrine|FRESENIUS KABI USA LLC|N|Second|5.7|CR|23.6|Y∆|
|epinephrine|FRESENIUS KABI USA LLC|N|Sponsor|11.9||35.5||
|epinephrine|FRESENIUS KABI USA LLC|N|Third|6.0|CR|41.5|Y∆|
|epinephrine|FRESENIUS KABI USA LLC|N|Sponsor|2.4||43.9||
|epinephrine|FRESENIUS KABI USA LLC|N|Fourth|2.0|TA|45.9|Y▲|
|epinephrine|FRESENIUS KABI USA LLC|N|Sponsor|2.5||48.4||
|epinephrine|FRESENIUS KABI USA LLC|N|Fifth|1.9|AP|50.3|Y▲|
|**Submitted in FY 2020**|**Submitted in FY 2020**|**Submitted in FY 2020**|**Submitted in FY 2020**|**Submitted in FY 2020**|**Submitted in FY 2020**|**Submitted in FY 2020**|**Submitted in FY 2020**|
|GRAFAPEX<br>(treosulfan)|MEDEXUS PHARMA INC|Y|First|11.6|CR|11.6|Y♦|
|GRAFAPEX<br>(treosulfan)|MEDEXUS PHARMA INC|Y|Sponsor|33.0||44.6||
|GRAFAPEX<br>(treosulfan)|MEDEXUS PHARMA INC|Y|Second|8.7|AP|53.3|Y∆#|
||||First|9.8|CR|9.8|Y◊|


_Appendix A_ _Page A-11_


---

|Proprietary Name<br>(Established<br>Name)|Applicant|NME<br>(Y/N)|Review<br>Cycle|Cycle<br>Time<br>(Mos.)|Cycle<br>Result|Total<br>Time<br>(Mos.)|Goal<br>Met|
|---|---|---|---|---|---|---|---|
|dolutegravir,<br>emtricitabine, and<br>tenofovir alafenamide|<br> <br> <br> <br> <br>CIPLA LTD|<br> <br> <br> <br> <br>N|Sponsor|3.9||13.7||
|dolutegravir,<br>emtricitabine, and<br>tenofovir alafenamide|<br> <br> <br> <br> <br>CIPLA LTD|<br> <br> <br> <br> <br>N|Second|5.5|CR|19.2|Y∆◊|
|dolutegravir,<br>emtricitabine, and<br>tenofovir alafenamide|<br> <br> <br> <br> <br>CIPLA LTD|<br> <br> <br> <br> <br>N|Sponsor|0.6||19.8||
|dolutegravir,<br>emtricitabine, and<br>tenofovir alafenamide|<br> <br> <br> <br> <br>CIPLA LTD|<br> <br> <br> <br> <br>N|Third|6.0|CR|25.8|Y∆◊|
|dolutegravir,<br>emtricitabine, and<br>tenofovir alafenamide|<br> <br> <br> <br> <br>CIPLA LTD|<br> <br> <br> <br> <br>N|Sponsor|1.4||27.2||
|dolutegravir,<br>emtricitabine, and<br>tenofovir alafenamide|<br> <br> <br> <br> <br>CIPLA LTD|<br> <br> <br> <br> <br>N|Fourth|5.5|CR|32.7|Y∆◊|
|dolutegravir,<br>emtricitabine, and<br>tenofovir alafenamide|<br> <br> <br> <br> <br>CIPLA LTD|<br> <br> <br> <br> <br>N|Sponsor|4.1||36.8||
|dolutegravir,<br>emtricitabine, and<br>tenofovir alafenamide|<br> <br> <br> <br> <br>CIPLA LTD|<br> <br> <br> <br> <br>N|Fifth|5.8|CR|42.6|Y∆◊|
|dolutegravir,<br>emtricitabine, and<br>tenofovir alafenamide|<br> <br> <br> <br> <br>CIPLA LTD|<br> <br> <br> <br> <br>N|Sponsor|7.6||50.2||
|dolutegravir,<br>emtricitabine, and<br>tenofovir alafenamide|<br> <br> <br> <br> <br>CIPLA LTD|<br> <br> <br> <br> <br>N|Sixth|5.9|TA|56.1|Y∆◊|
|BONDLIDO (lidocaine)|MEDRX USA INC|N|First|10.1|CR|10.1|N|
|BONDLIDO (lidocaine)|MEDRX USA INC|N|Sponsor|20.9||31.0||
|BONDLIDO (lidocaine)|MEDRX USA INC|N|Second|6.0|CR|37.0|Y∆|
|BONDLIDO (lidocaine)|MEDRX USA INC|N|Sponsor|3.4||40.4||
|BONDLIDO (lidocaine)|MEDRX USA INC|N|Third|6.0|CR|46.4|Y∆|
|BONDLIDO (lidocaine)|MEDRX USA INC|N|Sponsor|8.4||54.8||
|BONDLIDO (lidocaine)|MEDRX USA INC|N|Fourth|6.0|AP|60.8|Y∆|
|YUTREPIA<br>(treprostinil)|LIQUIDIA TECHNOLOGIES<br>INC|N|First|10.0|CR|10.0|Y|
|YUTREPIA<br>(treprostinil)|LIQUIDIA TECHNOLOGIES<br>INC|N|Sponsor|5.4||15.4||
|YUTREPIA<br>(treprostinil)|LIQUIDIA TECHNOLOGIES<br>INC|N|Second|5.9|TA|21.3|Y∆|
|YUTREPIA<br>(treprostinil)|LIQUIDIA TECHNOLOGIES<br>INC|N|Sponsor|20.6||41.9||
|YUTREPIA<br>(treprostinil)|LIQUIDIA TECHNOLOGIES<br>INC|N|Third|12.8|TA|54.7|N∆|
|YUTREPIA<br>(treprostinil)|LIQUIDIA TECHNOLOGIES<br>INC|N|Sponsor|7.2||61.9||
|YUTREPIA<br>(treprostinil)|LIQUIDIA TECHNOLOGIES<br>INC|N|Fourth|2.0|AP|63.9|Y▲|
|MEZOFY<br>(aripiprazole)|CMG PHARMACEUTICAL CO<br>LTD|N|First|10.0|CR|10.0|Y|
|MEZOFY<br>(aripiprazole)|CMG PHARMACEUTICAL CO<br>LTD|N|Sponsor|49.9||59.9||
|MEZOFY<br>(aripiprazole)|CMG PHARMACEUTICAL CO<br>LTD|N|Second|6.0|AP|65.9|Y∆|
|**Submitted in FY 2018**|**Submitted in FY 2018**|**Submitted in FY 2018**|**Submitted in FY 2018**|**Submitted in FY 2018**|**Submitted in FY 2018**|**Submitted in FY 2018**|**Submitted in FY 2018**|
|dolutegravir,<br>lamivudine, and<br>tenofovir disoproxil<br>fumarate|CIPLA LTD|N|First|9.7|CR|9.7|Y◊|
|dolutegravir,<br>lamivudine, and<br>tenofovir disoproxil<br>fumarate|CIPLA LTD|N|Sponsor|2.0||11.7||
|dolutegravir,<br>lamivudine, and<br>tenofovir disoproxil<br>fumarate|CIPLA LTD|N|Second|5.3|CR|17.0|Y∆◊|
|dolutegravir,<br>lamivudine, and<br>tenofovir disoproxil<br>fumarate|CIPLA LTD|N|Sponsor|6.2||23.2||
|dolutegravir,<br>lamivudine, and<br>tenofovir disoproxil<br>fumarate|CIPLA LTD|N|Third|5.7|CR|28.9|Y∆◊|
|dolutegravir,<br>lamivudine, and<br>tenofovir disoproxil<br>fumarate|CIPLA LTD|N|Sponsor|2.8||31.7||
|dolutegravir,<br>lamivudine, and<br>tenofovir disoproxil<br>fumarate|CIPLA LTD|N|Fourth|5.9|CR|37.6|Y∆◊|
|dolutegravir,<br>lamivudine, and<br>tenofovir disoproxil<br>fumarate|CIPLA LTD|N|Sponsor|1.7||39.3||


_Appendix A_ _Page A-12_


---

|Proprietary Name<br>(Established<br>Name)|Applicant|NME<br>(Y/N)|Review<br>Cycle|Cycle<br>Time<br>(Mos.)|Cycle<br>Result|Total<br>Time<br>(Mos.)|Goal<br>Met|
|---|---|---|---|---|---|---|---|
||||Fifth|5.7|CR|45.0|Y∆◊|
||||Sponsor|0.3||45.3||
||||Sixth|5.7|CR|51.0|Y∆◊|
||||Sponsor|6.5||57.5||
||||Seventh|5.9|CR|63.4|Y∆◊|
||||Sponsor|2.4||65.8||
||||Eighth|5.9|CR|71.7|Y∆◊|
||||Sponsor|4.4||76.1||
||||Nineth|1.9|TA|78.0|Y▲◊|
|OTEZLA (apremilast)|AMGEN INC|N|First|8.1|WD|8.1|Y|
|OTEZLA (apremilast)|AMGEN INC|N|Sponsor|74.4||82.5||
|OTEZLA (apremilast)|AMGEN INC|N|Second|10.0|AP|92.5|Y|


_Appendix A_ _Page A-13_


---

#### **Appendix B: Filed Application Numbers by Review Division**

The tables below and on the pages that follow show the number of applications filed in
FY 2025 for various application types and review designations broken out by review
division. This reporting for PDUFA VII is required under section 736B(a) of the FD&C
Act.


**Table B-1. Original Applications Filed in FY 2025 by Review Division/Office.**


|Review<br>Division/Office|Priority<br>NDAs|Standard<br>NDAs|Priority<br>BLAs|Standard<br>BLAs|Undesignated<br>Original<br>Applications|
|---|---|---|---|---|---|
|<br>**CDER Review Divisions** <br>|<br>**CDER Review Divisions** <br>|<br>**CDER Review Divisions** <br>|<br>**CDER Review Divisions** <br>|<br>**CDER Review Divisions** <br>|<br>**CDER Review Divisions** <br>|
|Division of<br>Anesthesiology,<br>Addiction Medicine,<br>and Pain Medicine<br>|0|6|0|0|0|
|<br>Division of Anti-<br>Infectives|1|1|0|0|1|
|<br>Division of Antivirals<br>|2|6|2|0|1|
|Division of<br>Cardiology and<br>Nephrology<br>|1|7|1|0|3|
|<br>Division of<br>Dermatology and<br>Dentistry<br>|1|1|0|1|1|
|<br>Division of Diabetes,<br>Lipid Disorders, and<br>Obesity<br>|0|2|0|1|1|
|<br>Division of<br>Gastroenterology<br>|0|2|0|0|1|
|<br>Division of General<br>Endocrinology<br>|1|3|0|0|0|
|<br>Division of<br>Hematologic<br>Malignancies I<br>|1|1|0|0|1|
|<br>Division of<br>Hematologic<br>Malignancies II<br>|1|2|0|1|0|
|<br>Division of<br>Hepatology and<br>Nutrition|0|3|0|0|0|


_Appendix B_ _Page B-1_


---

|Review<br>Division/Office|Priority<br>NDAs|Standard<br>NDAs|Priority<br>BLAs|Standard<br>BLAs|Undesignated<br>Original<br>Applications|
|---|---|---|---|---|---|
|Division of Imaging<br>and Radiation<br>Medicine<br>|0|7|1|0|<br>0|
|<br>Division of<br>Neurology I<br>|2|2|1|1|3|
|<br>Division of<br>Neurology II<br>|1|2|0|0|0|
|<br>Division of Non-<br>Malignant<br>Hematology<br>|1|2|0|0|1|
|<br>Division of Non-<br>Prescription Drugs I<br>|0|1|0|0|1|
|<br>Division of Non-<br>Prescription Drugs II<br>|0|0|0|0|0|
|<br>Division of Oncology<br>I <br>|2|8|0|1|3|
|<br>Division of Oncology<br>II<br>|7|2|2|2|0|
|<br>Division of Oncology<br>III<br>|0|3|0|0|0|
|<br>Division of<br>Ophthalmology<br>|1|5|0|0|0|
|<br>Division of<br>Psychiatry<br>|0|7|0|0|0|
|<br>Division of<br>Pulmonology,<br>Allergy, and Critical<br>Care<br>|5|2|0|1|0|
|<br>Division of Rare<br>Diseases and<br>Medical Genetics<br>|3|0|1|0|0|
|<br>Division of<br>Rheumatology and<br>Transplant Medicine<br>|0|2|0|2|0|
|<br>Division of Urology,<br>Obstetrics, and<br>Gynecology|1|1|0|0|2|
|<br>_CDER Totals_|_31_|_78_|_8 _|_10_|_19_|
|**CBER Review Offices** <br>|**CBER Review Offices** <br>|**CBER Review Offices** <br>|**CBER Review Offices** <br>|**CBER Review Offices** <br>|**CBER Review Offices** <br>|
|Office of Tissues and<br>Advanced Therapies|0|0|8|2|0|


_Appendix B_ _Page B-2_


---

|Review<br>Division/Office|Priority<br>NDAs|Standard<br>NDAs|Priority<br>BLAs|Standard<br>BLAs|Undesignated<br>Original<br>Applications|
|---|---|---|---|---|---|
|Office of Vaccines<br>Research and<br>Review|0|0|0|1|<br>0|
|<br>_CBER Totals_|_0 _|_0 _|_8 _|_3 _|_0 _|
|**FDA Totals**|31|78|16|13|19|


_Appendix B_ _Page B-3_


---

**Table B-2. Efficacy Supplements Filed in FY 2025 by Review Division/Office.**


|Review Division/Office|Priority<br>Efficacy<br>Supplements|Standard<br>Efficacy<br>Supplements|Undesignated<br>Efficacy Supplements|
|---|---|---|---|
|**CDER Review Divisions**|**CDER Review Divisions**|**CDER Review Divisions**|**CDER Review Divisions**|
|Division of<br>Anesthesiology,<br>Addiction Medicine, and<br>Pain Medicine|0|3|0|
|Division of Anti-Infectives|2|8|1|
|Division of Antivirals|2|7|0|
|Division of Cardiology<br>and Nephrology|5|11|0|
|Division of Dermatology<br>and Dentistry|1|11|2|
|Division of Diabetes,<br>Lipid Disorders, and<br>Obesity|7|7|0|
|Division of<br>Gastroenterology|1|10|0|
|Division of General<br>Endocrinology|0|4|0|
|Division of Hematologic<br>Malignancies I|3|7|0|
|Division of Hematologic<br>Malignancies II|2|11|0|
|Division of Hepatology<br>and Nutrition|1|1|0|
|Division of Imaging and<br>Radiation Medicine|0|3|0|
|Division of Neurology I|1|7|0|
|Division of Neurology II|1|5|0|
|Division of Non-Malignant<br>Hematology|4|2|0|
|Division of Non-<br>Prescription Drugs I|0|1|0|


_Appendix B_ _Page B-4_


---

|Review Division/Office|Priority<br>Efficacy<br>Supplements|Standard<br>Efficacy<br>Supplements|Undesignated<br>Efficacy Supplements|
|---|---|---|---|
|Division of Non-<br>Prescription Drugs II|0|0|0|
|Division of Oncology I|9|11|2|
|Division of Oncology II|11|8|2|
|Division of Oncology III|11|16|0|
|Division of<br>Ophthalmology|1|2|0|
|Division of Psychiatry|3|5|0|
|Division of Pulmonology,<br>Allergy, and Critical Care|6|7|2|
|Division of Rare<br>Diseases and Medical<br>Genetics|2|2|0|
|Division of Rheumatology<br>and Transplant Medicine|1|10|0|
|Division of Urology,<br>Obstetrics, and<br>Gynecology|1|3|0|
|_CDER Totals_|_75_|_162_|_9 _|
|**CBER Review Divisions **|**CBER Review Divisions **|**CBER Review Divisions **|**CBER Review Divisions **|
|Office of Tissues and<br>Advanced Therapies|8|6|0|
|Office of Vaccines<br>Research and Review|3|17|0|
|_CBER Totals_|_11_|_23_|_0 _|
|**FDA Totals**|86|185|9|


_Appendix B_ _Page B-5_


---

**Table B-3. Submissions with Special Designations Filed in FY 2025 by Review**
**Division/Office.**


|Review<br>Division/Office|Accelerated<br>Approval|Fast<br>Track<br>Products|Orphan<br>Designations|Breakthrough<br>Designations*|IND<br>Applications<br>Submitted|
|---|---|---|---|---|---|
|**CDER Review Divisions**|**CDER Review Divisions**|**CDER Review Divisions**|**CDER Review Divisions**|**CDER Review Divisions**||
|Division of<br>Anesthesiology,<br>Addiction<br>Medicine, and<br>Pain Medicine|0|1|0|1|97|
|Division of Anti-<br>Infectives|0|2|0|0|27|
|Division of<br>Antivirals|1|6|1|6|42|
|Division of<br>Cardiology and<br>Nephrology|0|0|0|1|109|
|Division of<br>Dermatology and<br>Dentistry|0|0|1|0|71|
|Division of<br>Diabetes, Lipid<br>Disorders, and<br>Obesity|0|1|1|2|81|
|Division of<br>Gastroenterology|0|0|0|0|54|
|Division of<br>General<br>Endocrinology|0|0|2|1|17|
|Division of<br>Hematologic<br>Malignancies I|0|1|3|1|78|
|Division of<br>Hematologic<br>Malignancies II|1|1|2|2|101|
|Division of<br>Hepatology and<br>Nutrition|0|0|1|1|27|


_Appendix B_ _Page B-6_


---

|Review<br>Division/Office|Accelerated<br>Approval|Fast<br>Track<br>Products|Orphan<br>Designations|Breakthrough<br>Designations*|IND<br>Applications<br>Submitted|
|---|---|---|---|---|---|
|Division of<br>Imaging and<br>Radiation<br>Medicine<br>|0|1|3|0|90|
|<br>Division of<br>Neurology I<br>|0|3|5|5|102|
|<br>Division of<br>Neurology II<br>|0|0|2|5|65|
|<br>Division of Non-<br>Malignant<br>Hematology<br>|0|0|1|5|42|
|<br>Division of Non-<br>Prescription<br>Drugs I<br>|0|0|0|0|1|
|<br>Division of Non-<br>Prescription<br>Drugs II<br>|0|0|0|0|1|
|<br>Division of<br>Oncology I<br>|1|2|1|5|258|
|<br>Division of<br>Oncology II<br>|5|4|7|12|244|
|<br>Division of<br>Oncology III<br>|0|0|0|7|188|
|<br>Division of<br>Ophthalmology<br>|0|0|2|3|38|
|<br>Division of<br>Psychiatry<br>|0|0|0|1|88|
|<br>Division of<br>Pulmonology,<br>Allergy, and<br>Critical Care<br>|0|1|2|2|58|
|<br>Division of Rare<br>Diseases and<br>Medical Genetics<br>|2|3|4|2|7|
|<br>Division of<br>Rheumatology<br>and Transplant<br>Medicine<br>|0|1|0|3|61|
|<br>Division of<br>Urology,<br>Obstetrics, and<br>Gynecology|0|0|0|1|31|


_Appendix B_ _Page B-7_


---

|Review<br>Division/Office|Accelerated<br>Approval|Fast<br>Track<br>Products|Orphan<br>Designations|Breakthrough<br>Designations*|IND<br>Applications<br>Submitted|
|---|---|---|---|---|---|
|_CDER Totals_<br>|_10_<br>|_27_|_38_|_66_|_1,978_<br>|
|**CBER Review Divisions**<br>|**CBER Review Divisions**<br>|**CBER Review Divisions**<br>|**CBER Review Divisions**<br>|**CBER Review Divisions**<br>||
|<br>Office of Tissues<br>and Advanced<br>Therapies<br>|<br>0|2|6|1|<br>12|
|<br>Office of Vaccines<br>Research and<br>Review|0|0|0|0|0|
|<br>_CBER Totals_|_0 _|_2 _|_6 _|_1 _|_12_|
|**FDA Totals**|10|29|44|67|1,990|


- This column does not represent filed figures; rather it shows the number of BT designations granted on INDs,
NDAs, and BLAs during FY 2025. BT designation is granted based on indication, and therefore, one submission may
have more than one BT designation granted.


_Appendix B_ _Page B-8_


---

#### **Appendix C: Analysis of Use of Funds**

On September 30, 2022, FUFRA was signed into law. FUFRA reauthorized the user
fee programs for prescription drugs, generic drugs, medical devices, and biosimilar
biological products.

##### **A. Original Application Approval Cycle Summary**


The following table addresses section 904(a)(1) of FDARA (section 736B(a)(5)(A) of the
FD&C Act), pertaining to PDUFA, which requires FDA to include data showing the
aggregate number of approvals that occurred during FY 2025. Data represent all the
original NDA and BLA approvals that occurred during FY 2025, regardless of when the
application was received. Data are presented by the type of application and
performance goal, as well as whether the approval occurred on time or was overdue on
the performance goal.

This table captures not only first cycle approvals, but also multiple cycle approvals. For
applications that were approved after multiple cycles, the performance metric is counted
for the cycle when the approval was given. Approval counts also include applications
that were given a tentative approval.

Figures provided in the table below are indicated in detail in Appendix A of this report,
which provides a detailed review history of the NDAs and BLAs approved under PDUFA
during FY 2025. [1]


1 Performance is calculated only on the first cycle in which the application received an approval or tentative approval.
Any subsequent tentative or full approvals, after the first tentative approval action, will not affect the performance
metric regardless of the fiscal year of the first tentative approval.


_Appendix C_ _Page C-1_


---

**Table C-1. FY 2025 Original Application Approval Cycle Summary.**


|Approval Cycle<br>Type|Performance<br>Goal: Act on<br>90 Percent<br>Within|Filed in FY<br>2025*|Approval<br>in FY<br>2025†|On<br>Time‡|Overdue‡|Percent<br>On Time|
|---|---|---|---|---|---|---|
|First Cycle Priority<br>NMEs & BLAs<br>|6 months of<br>filing date|39|33|32|1|**97%**|
|First Cycle<br>Standard NMEs &<br>BLAs|10 months of<br>filing date|30|22|20|2|**91%**|
|<br>First Cycle Priority<br>Non-NME NDAs<br>|6 months|8|8|8|0|**100%**|
|First Cycle<br>Standard Non-NME<br>NDAs|10 months|61|41|41|0|**100%**|
|<br>First Cycle Priority<br>Undesignated~|N/A|19|--|--|--|--|
|Class 1<br>Resubmissions|2 months|6|7|7|0|**100%**|
|Class 2<br>Resubmissions|6 months|50|29|26|3|**90%**|
|**Total**<br>|**--**<br>|**213**<br>|**140**<br>|**134**<br>|**6 **<br>|--*<br>|


been accepted as a resubmission. Data do not reflect applications that are unacceptable for filing because of
nonpayment of user fees, have been withdrawn within 60 days of receipt, or have been refused to file.

 -  This column represents applications approved in FY 2025, regardless of when the application or resubmission was
received.

  - The on time and overdue metrics are based on the cycle that received the approval action.
§ Performance is not calculated on combined goals.
~ These applications have not yet received a review priority designation.

##### **B. Performance Enhancement Goals**


Section 736B(a)(5)(B) of the FD&C Act, which requires FDA to include relevant data to
determine whether CDER and CBER have met performance enhancement goals
identified in the Commitment Letters described in section 101(b) of the Prescription
Drug User Fee Amendments of 2022 for the applicable fiscal year. A link to each


_Appendix C_ _Page C-2_


---

performance enhancement goal completed under PDUFA VII can be found on FDA’s
website. [2]

For purposes of this report, _performance enhancement goals_ are defined as any nonreview performance goal described in PDUFA with a specified goal date that falls within
the applicable fiscal year.


The table below represents FDA’s FY 2024 updated performance enhancement goals.


**Table C-2. FY 2024 Performance Enhancement Goals (Updated).**


|Performance<br>Enhancement Goal|Target<br>Goal Date|On<br>Time<br>(Y/N)|Actual<br>Completion<br>Date|Comments|
|---|---|---|---|---|
|Hiring PDUFA Human Drug<br>Review Program Staff<br>FY24<br>|9/30/2024|N|--|https://www.fda.gov/industr<br>y/prescription-drug-user-<br>fee-amendments/pdufa-<br>and-bsufa-quarterly-hiring-<br>updates|


The table below represents FDA’s FY 2025 performance enhancement goals.


**Table C-3. FY 2025 Performance Enhancement Goals.**


|Performance<br>Enhancement Goal|Target<br>Goal Date|On<br>Time<br>(Y/N)|Actual<br>Completion<br>Date|Comments|
|---|---|---|---|---|
|ESG Website Update FY24|10/21/2024|Y|10/8/2024|https://www.fda.gov/indust<br>ry/resources/submission-<br>statistics|
|Quarterly Hiring Reporting<br>Q4 FY24|10/21/2024|Y|10/8/2024|https://www.fda.gov/indust<br>ry/prescription-drug-user-<br>fee-amendments/pdufa-<br>and-bsufa-quarterly-hiring-<br>updates|
|Publish Data Standards<br>Action Plan Q4 FY24|12/31/2024|Y|11/22/2024|https://www.fda.gov/drugs/<br>electronic-regulatory-<br>submission-and-<br>review/data-standards-|


2 [https://www.fda.gov/industry/prescription-drug-user-fee-amendments/completed-pdufa-vi-deliverables](https://www.fda.gov/industry/prescription-drug-user-fee-amendments/completed-pdufa-vi-deliverables)


_Appendix C_ _Page C-3_


---

|Col1|Col2|Col3|Col4|program-strategic-plan-<br>and-board|
|---|---|---|---|---|
|Quarterly Hiring Reporting<br>Q1 FY25|1/21/2025|Y|1/14/2025|https://www.fda.gov/indust<br>ry/prescription-drug-user-<br>fee-amendments/pdufa-<br>and-bsufa-quarterly-hiring-<br>updates|
|Contribute Information on<br>Sentinel to PDUFA<br>Financial Report FY24|1/30/2025|Y|10/18/2024|https://www.fda.gov/about-<br>fda/user-fee-financial-<br>reports/pdufa-financial-<br>reports|
|Provide Rare Diseases<br>Information to PDUFA<br>Annual Report FY24|1/30/2025|Y|9/27/2024|https://www.fda.gov/about-<br>fda/fda-track-agency-wide-<br>program-performance/fda-<br>track-prescription-drug-<br>user-fee-act-pdufa-<br>performance-reports|
|Provide Information on<br>Appropriated User Fee<br>Funds Financial Report<br>FY24|3/31/2025|Y|11/4/2024|https://www.fda.gov/about-<br>fda/user-fee-financial-<br>reports/pdufa-financial-<br>reports|
|Provide Information on CPA<br>Fee Revenues to PDUFA<br>Annual Financial Report<br>FY24|3/31/2025|Y|10/31/2024|https://www.fda.gov/about-<br>fda/user-fee-financial-<br>reports/pdufa-financial-<br>reports|
|Publish Data Standards<br>Action Plan Q1 FY25|3/31/2025|Y|3/27/2025|https://www.fda.gov/drugs/<br>electronic-regulatory-<br>submission-and-<br>review/data-standards-<br>program-strategic-plan-<br>and-board|
|Publish Financial Plan<br>Updates FY25|3/31/2025|N|7/30/2025|https://www.fda.gov/about-<br>fda/user-fee-reports/user-<br>fee-five-year-financial-<br>plans <br> <br>See corrective actions for<br>additional information.|
|Publish Capacity Planning<br>Implementation Plan<br>Updates FY25|3/31/2025|Y|3/31/2025|https://www.fda.gov/indust<br>ry/fda-user-fee-<br>programs/resource-<br>capacity-planning-and-<br>modernized-time-reporting|


_Appendix C_ _Page C-4_


---

|Include Rare Diseases<br>Information in Novel Drug<br>Approvals Report CY24|3/31/2025|Y|1/1/2025|https://www.fda.gov/media<br>/184967/download?attach<br>ment|
|---|---|---|---|---|
|Quarterly Hiring Reporting<br>Q2 FY25|4/21/2025|N|6/26/2025|https://www.fda.gov/indust<br>ry/prescription-drug-user-<br>fee-amendments/pdufa-<br>and-bsufa-quarterly-hiring-<br>updates <br> <br>FDA sets the target goal<br>date for these postings<br>because the Commitment<br>Letter does not specify a<br>date. FDA achieved timely<br>postings, so no corrective<br>actions are needed.|
|Publish Final Guidance on<br>Alternative Tools to Assess<br>Manufacturing Facilities|5/21/2025|N|9/12/2025|https://www.fda.gov/regula<br>tory-information/search-<br>fda-guidance-<br>documents/alternative-<br>tools-assessing-drug-<br>manufacturing-facilities-<br>identified-pending-<br>applications <br> <br>The Commitment Letter<br>states that FDA should<br>“work toward” the target<br>date. Given that FDA did<br>work toward the target<br>date for publishing the<br>final guidance, no<br>corrective actions are<br>needed.|
|Conduct Public Meeting<br>Financial Plan FY25|6/30/2025|N|9/30/2025|https://www.fda.gov/drugs/<br>news-events-human-<br>drugs/financial-<br>transparency-and-<br>efficiency-prescription-<br>drug-user-fee-act-<br>biosimilar-user-fee-act-<br>and <br> <br>See corrective actions for<br>additional information.|


_Appendix C_ _Page C-5_


---

|Publish CMC IR<br>Assessment Report|6/30/2025|Y|6/2/2025|https://www.fda.gov/media<br>/186729/download|
|---|---|---|---|---|
|Publish Data Standards<br>Action Plan Q2 FY25|6/30/2025|N|8/5/2025|https://www.fda.gov/drugs/<br>electronic-regulatory-<br>submission-and-<br>review/data-standards-<br>program-strategic-plan-<br>and-board <br> <br>FDA sets the target goal<br>date for these action plans<br>because the Commitment<br>Letter does not specify a<br>date. FDA achieved timely<br>publications, so no<br>corrective actions are<br>needed.|
|Publish Independent<br>Assessment of Hiring<br>Report|6/30/2025|N|8/25/2025|https://www.fda.gov/media<br>/188083/download?attach<br>ment <br> <br>See corrective actions for<br>additional information.|
|Report Real-World<br>Evidence Submissions to<br>CDER and CBER - FY24|6/30/2025|Y|6/10/2025|https://www.fda.gov/scienc<br>e-research/real-world-<br>evidence/real-world-<br>evidence-submissions-<br>center-biologics-<br>evaluation-and-research-<br>center-drug-evaluation-<br>and|
|Quarterly Hiring Reporting<br>Q3 FY25|7/21/2025|Y|7/15/2025|https://www.fda.gov/indust<br>ry/prescription-drug-user-<br>fee-amendments/pdufa-<br>and-bsufa-quarterly-hiring-<br>updates|
|Conduct Public Workshop<br>on CMC Development and<br>Readiness Pilot|7/31/2025|N|9/10/2025|https://www.fda.gov/drugs/<br>news-events-human-<br>drugs/lessons-learned-<br>chemistry-manufacturing-<br>and-controls-cmc-<br>development-and-<br>readiness-pilot-cdrp <br> <br>See corrective actions for<br>additional information.|


_Appendix C_ _Page C-6_


---

|Finalize Innovative<br>Manufacturing Strategy<br>Document|8/12/2025|N|--|See corrective actions for<br>additional information.|
|---|---|---|---|---|
|Annual FDA-Industry IT<br>Leadership Meetings 3<br>FY25|9/30/2025|Y|6/3/2025||
|Assess and Share<br>Bioinformatics Capabilities<br>FY25|9/30/2025|Y|9/30/2025||
|CBER Roadmap Updates<br>FY25|9/30/2025|N|--|See corrective actions for<br>additional information.|
|Complete ESG Transition<br>to Cloud|9/30/2025|Y|4/14/2025||
|Conduct PFDD<br>Methodology Workshop 2|9/30/2025|Y|9/19/2025|https://www.fda.gov/drugs/<br>news-events-human-<br>drugs/patient-focused-<br>drug-development-<br>workshop-2-discuss-<br>methodologic-and-other-<br>challenges-related|
|Conduct Public Meeting<br>CGT Manufacturers|9/30/2025|Y|9/18/2025|https://www.fda.gov/news-<br>events/otp-events-<br>meetings-and-<br>workshops/fda-cber-otp-<br>public-listening-meeting-<br>leveraging-knowledge-<br>facilitating-development-<br>and-review-cell|
|Conduct STAR Interim<br>Assessment|9/30/2025|Y|8/1/2025||
|Develop and Update Data<br>and Tech Modernization<br>Strategy FY25|9/30/2025|N|--|See corrective actions for<br>additional information.|
|Hiring PDUFA Human Drug<br>Review Program Staff FY25|9/30/2025|N|--|https://www.fda.gov/indust<br>ry/prescription-drug-user-<br>fee-amendments/pdufa-<br>and-bsufa-quarterly-hiring-<br>updates <br> <br>See corrective actions for<br>additional information.|
|Hold Public Meeting for<br>Independent Assessment of<br>Hiring|9/30/2025|Y|9/24/2025|https://www.fda.gov/drugs/<br>news-events-human-<br>drugs/prescription-drug-|


_Appendix C_ _Page C-7_


---

|Col1|Col2|Col3|Col4|user-fee-act-and-<br>biosimilar-user-fee-<br>amendments-hiring-and-<br>retention-assessment|
|---|---|---|---|---|
|Publish Data Standards<br>Action Plan Q3 FY25|9/30/2025|Y|9/26/2025|https://www.fda.gov/drugs/<br>electronic-regulatory-<br>submission-and-<br>review/data-standards-<br>program-strategic-plan-<br>and-board|
|Publish Draft Guidance on<br>CID|9/30/2025|N|--|See corrective actions for<br>additional information.|
|Publish Draft Guidance on<br>Evaluation of Efficacy in<br>Small Patient Populations<br>Using Novel Trial Designs|9/30/2025|Y|9/25/2025|https://www.fda.gov/regula<br>tory-information/search-<br>fda-guidance-<br>documents/innovative-<br>designs-clinical-trials-<br>cellular-and-gene-therapy-<br>products-small-<br>populations|
|Publish Draft Guidance on<br>Post Approval CGT|9/30/2025|Y|9/25/2025|https://www.fda.gov/regula<br>tory-information/search-<br>fda-guidance-<br>documents/postapproval-<br>methods-capture-safety-<br>and-efficacy-data-cell-and-<br>gene-therapy-products|
|Publish Draft Guidance on<br>Regenerative Medicine<br>Therapies|9/30/2025|Y|9/25/2025|https://www.fda.gov/regula<br>tory-information/search-<br>fda-guidance-<br>documents/expedited-<br>programs-regenerative-<br>medicine-therapies-<br>serious-conditions-0|
|Publish Report on Use of<br>Sentinel|9/30/2025|Y|9/30/2025|https://www.fda.gov/indust<br>ry/prescription-drug-user-<br>fee-amendments/pdufa-<br>vii-commitment-<br>assessment-sentinel-<br>system-2022-2024|
|Publish Resource Capacity<br>Planning Assessment<br>Report|9/30/2025|Y|9/26/2025|https://www.fda.gov/media<br>/188791/download?attach<br>ment|


_Appendix C_ _Page C-8_


---

|Publish Update on Public<br>and Sponsor Access on<br>Sentinel Website|9/30/2025|Y|9/24/2025|https://www.fda.gov/media<br>/188920/download?attach<br>ment|
|---|---|---|---|---|
|Quarterly PDUFA Standing<br>Meetings with Industry<br>FY25|9/30/2025|Y|9/30/2025||
|RDEA Selection Committee<br>Meetings FY25<br>|9/30/2025|Y|8/21/2025||

##### **C. Common Causes and Trends Impacting Ability to Meet** **Goals**

The following table addresses section 904(a)(1) of FDARA (section 736B(a)(5)(C) of the
FD&C Act), pertaining to PDUFA, which requires FDA to identify the most common
causes and trends of external or other circumstances affecting the ability of FDA,
including CDER, CBER, and OII, to meet the review time and performance
enhancement goals identified in the Commitment Letters described in section 101(b) of
the Prescription Drug User Fee Amendments of 2022.


**Table C-4. FY 2025 Performance Results.**


|Cause or Trend|Impact on FDA’s Commitments|
|---|---|
|Loss of staff during the fiscal<br>year.|The loss of staff during the fiscal year impacted FDA’s ability<br>to achieve some performance goals.|


_Appendix C_ _Page C-9_


---

#### **Appendix D: FY 2025 Corrective Action Report**

Section 736B(c) of the FD&C Act requires FDA to publicly issue a corrective action
report that details its progress in meeting the review and performance enhancement
goals identified in the PDUFA VII Commitment Letter for the applicable fiscal year.

If each of the review and performance enhancement goals for the applicable fiscal year
have been met, the corrective action report shall include recommendations on ways in
which the Secretary can improve and streamline the human drug application process.

For any of the review and performance enhancement goals during the applicable fiscal
year that were not met, the corrective action report shall include a justification, as
applicable, for the types of circumstances and trends that contributed to missed review
goal times; and with respect to performance enhancement goals that were not met, a
description of the efforts that FDA has put in place to improve the ability of the Agency
to meet each goal in the coming fiscal year. Such a description of corrective efforts is
not required by statute for review time goals, but FDA is providing this information
regardless in an effort to be complete.

This report satisfies this reporting requirement.

##### **A. Executive Summary**


Table D-1 below represents FDA’s FY 2024 updated performance results for goal types
that the Agency was not able to fully report in last year’s report. If a goal type is not
listed in this table for FY 2024, then the Agency fully reported on it in last year’s report. [1]


**Table D-1. FY 2024 Review and Procedural and Processing Goal Performance**
**Results (Updated).**


|Goal Type|Circumstances and Trends Impacting<br>the Ability to Meet the Goal Date|Corrective Action Plan|
|---|---|---|
|Review Goals|While FDA reported missing the Class 1<br>and 2 resubmissions goal in the FY 2024<br>PDUFA Performance Report, once all<br>reviews were ultimately completed, FDA<br>achieved the performance standard for all<br>review goal categories.|N/A|


1 [https://www.fda.gov/about-fda/user-fee-performance-reports/pdufa-performance-reports](https://www.fda.gov/about-fda/user-fee-performance-reports/pdufa-performance-reports)


_Appendix D_ _Page D-1_


---

**Table D-2. FY 2025 Review and Procedural and Processing Goal Performance**
**Results.**


|Goal Type|Circumstances and Trends Impacting<br>Ability to Meet Goal Date|Corrective Action Plan|
|---|---|---|
|Review Goals|FDA experienced higher than normal<br>attrition in FY 2025, resulting in above<br>average staff departure rate and loss of<br>some review capacity.  While remaining<br>staff tried to absorb the workload, not all<br>reviews could be done on-time, and some<br>review goals were missed.|FDA will continue to strive to<br>meet our performance<br>standards for review goals, and<br>work toward addressing<br>resource constraints caused by<br>the high attrition in FY 2025.|
|Procedural and<br>Processing Goals|While FDA missed several meetings goals,<br>despite loss in staffing, FDA was still able to<br>improve meetings related performance in<br>FY 2025 compared to previous years.<br> <br>Similar to the trend affecting review goals,<br>the loss of review staff had an impact on<br>FDA’s ability to meet the goal for reviewing<br>some responses to clinical holds on time.<br>As a result, FDA is currently missing that<br>performance metric by only one percentage<br>point but may meet the standard once all<br>reviews are complete.<br> <br>For the missed goal Human Factors<br>Validation Protocol Submissions to INDs,<br>FDA experienced higher than normal<br>attrition in FY 2025, resulting in above|For meetings FDA will continue<br>to explore ways to build on the<br>performance improvement<br>trend.<br> <br>FDA will continue to strive to<br>meet our performance standard<br>for reviewing clinical hold<br>responses and work toward<br>addressing resource constraints<br>caused by the high attrition in<br>FY 2025.<br> <br>For the Human Factors<br>Validation goal, FDA will<br>continue to strive to iteratively<br>improve performance similar to<br>FY 2024.|


_Appendix D_ _Page D-2_


---

**Table D-3.** **FY 2025 Performance Enhancement Goal Performance Results.**


|Goal Type|Circumstances and Trends Impacting<br>Ability to Meet Goal Date|Corrective Action Plan|
|---|---|---|
|Financial<br>Transparency<br>|FDA missed the goal to publish a PDUFA<br>5-year financial plan and the subsequent<br>goal to hold a public meeting to present the<br>financial plan.  The financial plan, due by<br>March 31, 2025, was published July 30,<br>2025.  The public meeting, due by June 30,<br>2025, was held September 30, 2025.  The<br>delay in publishing the Five-Year Financial<br>Plans reflects the Agency’s commitment to<br>providing accurate and meaningful financial<br>projections.<br>|FDA plans on meeting these<br>commitments in FY 2026.<br>|
|Hiring Assessment,<br>Hiring, CMC<br>Development and<br>Readiness Pilot,<br>Innovative<br>Manufacturing|Due to the hiring pause implemented by<br>E.O 14210 and extended in July 2025, the<br>Agency has been unable to post<br>announcements for positions to be filled by<br>outside candidates.|FDA does not anticipate the<br>replication of these unforeseen<br>circumstances.|


_Appendix D_ _Page D-3_


---

|Goal Type|Circumstances and Trends Impacting<br>Ability to Meet Goal Date|Corrective Action Plan|
|---|---|---|
|IT Modernization &<br>Bioinformatics IT<br>Support<br>|Driven by the Commissioner’s mandate to<br>eliminate siloes and implement enterprise<br>approaches to technology solutions and AI,<br>FDA is currently consolidating agency<br>systems across centers and bringing each<br>center to a shared, modernized platform<br>which supersedes previous data and<br>technology strategy and CBER IT<br>modernization plans.  Given the magnitude<br>of the change and the pace of the<br>consolidations, CDER and CBER are<br>focused on achieving the results. Updates<br>were provided quarterly to industry partners<br>for the last two quarters of the fiscal year.<br>|FDA will investigate how to<br>continue meeting the spirit of<br>these commitments through<br>regular stakeholder meetings<br>and other approaches. <br>|
|Complex Innovative<br>Trial Designs|The guidance required review coordination<br>across multiple FDA offices and high-level<br>clearance from the Department of Health<br>and Human Services. This review process<br>occurred while the Agency balanced many<br>policy priorities that became particularly<br>acute in the first half of 2025. This led to a<br>delay in publication.<br>|This was a one-time<br>commitment; this delay will have<br>no downstream impact on other<br>commitments. At this point, no<br>further corrective actions are<br>planned.|


##### **B. PDUFA Performance Goals**

The following section addresses section 904(a)(2)(B) of FDARA (section 736B(c)(2)(A)
of the FD&C Act), which requires FDA to provide a justification for the determination of
review goals missed during FY 2025, and a description of the circumstances and any
trends related to missed review goals.

This section presents PDUFA performance and workload information for two different
types of goals: (1) review of applications and other submissions pertaining to human
drugs and biologics and (2) meeting management and other procedural goals related to
responses and notifications in the human drug review process.

This section includes all PDUFA VII goals as they pertain to receipts/filed submissions
in FY 2025.


_Appendix D_ _Page D-4_


---

If a goal type is not listed for FY 2024, then the Agency fully reported on it in last year’s
report.

##### _1. FY 2024 Updated Review and Procedural and Processing_ _Goal Performance Results_


**Summary of Performance:**

_Review Goals_
FDA achieved the performance standard for all review goal categories in FY 2024.


_Procedural and Processing Goals_
FDA missed an additional formal meetings goal for issuing Type B Written Response
Only (WRO) in FY 2024, in addition to previous goals reported in the FY 2024 PDUFA
Performance Report.

**Justification:**

Similar to other meeting goals missed in FY 2024 already reported on, there are several
factors that may have contributed to the missed goal including other competing PDUFA
goals, increased meeting volume, and complexity of questions requiring more
disciplines and time to resolve.


**Corrective Actions:**

FDA is continuing to explore ways to improve meeting performance and improve upon
the upward performance trend.

##### _2. FY 2025 Review and Procedural and Processing_ _Performance Results_


**Summary of Performance:**

_Review Goals_
FDA is currently missing the review performance goal for Priority Non-NME NDAs &
Class 1&2 Efficacy Supplement Resubmissions in FY 2025.


_Procedural and Processing Goals_


_Appendix D_ _Page D-5_


---

FDA is currently missing the performance standard for the following formal meetings
related goals:

  - Meeting scheduling for Type A, B, and C

  - Final written response for Type B and C Meetings

FDA also is currently missing the performance standard for review of responses to
Clinical Holds.

Lastly, FDA missed the performance standard for reviewing Human Factors Validation
Protocol Submissions to INDs.


**Justification:**

_Review Goals_
While FDA experienced higher than normal attrition in FY 2025, resulting in above
average staff departure rate and loss of some review capacity, FDA also received a
small number of submissions in both review categories that FDA is currently under
performing on. The result is that missing only a single review goal brings the
performance below the 90% goal. FDA still strives to meet all review goals; however,
because of the small cohort size, unless the FDA meets 100% of the reviews, the 90%
goal will be missed, leaving no room for unexpected challenges. Nonetheless, there are
still several pending submissions that could potentially be classified as a priority nonNME category once filed and if those are reviewed on time, FDA’s performance may
shift upwards for the final assessment in next year’s report.

_Procedural and Processing Goals_
Similar to the trend effecting review goals, the loss of review staff had an impact on
FDA’s ability to meet the goal for reviewing some responses to clinical holds on time.
As a result, FDA is currently missing that performance metric by only one percentage
point, but may meet the standard once all reviews are complete.

While FDA missed several meetings goals, FDA was still able to improve meeting
related performance in FY 2025 compared to previous years.

Loss of review staff/resourcing constraints had an impact on FDA’s ability to meet the
goal for evaluation of human factors validation study protocols. As a result, FDA is
currently missing that performance metric.


**Corrective Actions:**


_Appendix D_ _Page D-6_


---

_Review Goals_
FDA will continue to strive to meet our performance standards for review goals, and
work toward addressing resource constraints caused by the high attrition in FY 2025.

_Procedural and Processing Goals_
For meetings, FDA will continue to explore ways to build upon the performance
improvement trend.

FDA will continue to strive to meet our performance standard for reviewing clinical hold
responses and work toward addressing resource constraints caused by the high attrition
in FY 2025.

FDA continues to assess ways to handle the large volume and increasing complexity of
Human Factors Validation Protocol Submissions to INDs more effectively and work
toward addressing resource constraints through increased hiring and training.

##### **C. PDUFA Performance Enhancement Goals**


The following section addresses section 904(a)(2) of FDARA (section 736B(c)(2) of the
FD&C Act), which requires FDA to provide a justification for missed performance
enhancement goals and a description of the efforts FDA has put in place to improve the
ability of the Agency to meet each goal in the coming fiscal year (included here under
the heading “Corrective Actions”).

This section presents non-review performance goals cited in the PDUFA VII
Commitment Letter with required completion dates in FY 2025. For the purposes of this
report, _performance enhancement goals_ are defined as any non-review performance
goal with a specified deadline as named in the PDUFA Commitment Letter.
Performance enhancement goals with specified completion dates in FY 2026 will be
covered in subsequent corrective action reports.


**I.** **Financial Transparency**
_A._ _Summary of Performance:_


_Appendix D_ _Page D-7_


---

FDA missed the goal to publish a PDUFA 5-year financial plan and the
subsequent goal to hold a public meeting to present the financial plan.
The financial plan, due by March 31, 2025, was published July 30, 2025.
The public meeting, due by June 30, 2025, was held September 30, 2025.


_B._ _Justification:_

The delay in publishing the Five-Year Financial Plans reflects the
Agency’s commitment to providing accurate and meaningful financial
projections.

_C._ _Corrective Actions:_


FDA plans on meeting these commitments in FY 2026.


**II.** **Hiring Assessment**
_A._ _Summary of Performance:_


FDA missed the PDUFA goal to publish a third-party assessment report
on the hiring and retention of program staff. The commitment letter states
the report should be published by June 30, 2025. FDA published the
report on August 25, 2025.


_B._ _Justification:_


Delays occurred due to unanticipated staff departures.


_C._ _Corrective Actions:_


FDA does not anticipate the reoccurrence of these unforeseen
circumstances.


**III.** **Hiring**
_A._ _Summary of Performance:_


FDA missed the PDUFA goal for hiring in FY 2025. As of September 30,
2025, 17 of 44 FTEs were hired.


_Appendix D_ _Page D-8_


---

_B._ _Justification:_


Due to the hiring pause implemented by E.O 14210 and extended in July
2025, the Agency has been unable to post announcements for positions to
be filled by outside candidates.

_C._ _Corrective Actions:_

FDA will strive to meet hiring goals in future years.


**IV.** **CMC Development and Readiness Pilot**

_A._ _Summary of Performance:_


FDA missed the PDUFA goal to conduct a public workshop on the CMC
Development and Readiness Pilot (CDRP) by July 31, 2025. FDA held the
workshop on September 10, 2025.

_B._ _Justification:_


In April 2025, the CDRP workgroup postponed the meeting originally
scheduled for May 20, 2025, due to resource constraints.
The original CBER/CDER speakers and policy staff were part of the
Reduction in Force or left the agency.

_C._ _Corrective Actions:_


FDA will continue to strive to iteratively improve implementation of PDUFA
Performance Enhancement Goals. FDA will also continue to evaluate and
modernize its strategy for implementation of deliverables through resource
constraints.

This delay is not expected to have any downstream impact on other
commitments. FDA will continue work on the Strategy Document and
expects no delays for the April 30, 2026 deliverable.

**V.** **Innovative Manufacturing**

_A._ _Summary of Performance:_


_Appendix D_ _Page D-9_


---

FDA missed the PDUFA goal to finalize the draft strategy document related
to facilitating the utilization of innovative manufacturing technologies. The
commitment letter states the strategy document should be finalized within 9
months after the close of the public comment period on the draft strategy
document. The public comment period closed on November 12, 2024, and
the final strategy document was due by August 12, 2025. As of September
30, 2025, the final strategy document had not been published.

_B._ _Justification:_


Due to resource constraints in Q2 through Q4 of FY 2025, the clearance
and publication of the final Strategy Document was delayed.

Drafting of the final Strategy Document was completed June 2025.

_C._ _Corrective Actions:_


FDA will continue to strive to iteratively improve implementation of PDUFA
Performance Enhancement Goals. FDA will also continue to evaluate and
modernize its strategy document development processes to streamline the
review and clearance process.

This delay is not expected to have any downstream impact on other
commitments. At this point, no further corrective actions are planned.
.
**VI.** **IT Modernization & Bioinformatics IT Support**

_A._ _Summary of Performance:_


FDA missed the PDUFA goal to develop and update FDA’s data and
technology modernization strategy for fiscal year 2025. FDA also did not
provide updates on CBER’s IT modernization roadmap.

_B._ _Justification:_


Driven by the Commissioner’s mandate to eliminate siloes and implement
enterprise approaches to technology solutions and AI, FDA is currently
consolidating agency systems across centers and bringing each center to a
shared, modernized platform which supersedes previous data and
technology strategy and CBER IT modernization plans. Given the


_Appendix D_ _Page D-10_


---

magnitude of the change and the pace of the consolidations, CDER and
CBER are focused on achieving the results. FDA provided quarterly
updates to industry partners for the last two quarters of the fiscal year.


_C._ _Corrective Actions:_

FDA will investigate how to continue meeting the spirit of these
commitments through regular stakeholder meetings and other approaches.


**VII.** **Complex Innovative Trial Designs**

_A._ _Summary of Performance:_


FDA missed the PDUFA goal to publish guidance on the Use of Bayesian
Methodology in Clinical Trials of Drugs and Biologics by the end of FY2025.

_B._ _Justification:_


The guidance required review coordination across multiple FDA offices and
high-level clearance from the Department of Health and Human Services.
This review process occurred while the Agency balanced many policy
priorities that became particularly acute in the first half of 2025.
Unfortunately, this led to a delay in publication.

_C._ _Corrective Actions:_

This was a one-time commitment; this delay will have no downstream
impact on other commitments. At this point, no further corrective actions
are planned since the guidance is being worked on and will be published
as soon as possible


_Appendix D_ _Page D-11_


---

#### **Appendix E: Definitions of Key Terms**

A. The phrase _review and act on_ means the issuance of a complete action letter after
the complete review of a filed complete application. The action letter, if it is not an
approval, will set forth in detail the specific deficiencies and, where appropriate, the
actions necessary to place the application in condition for approval.

B. Review Performance Goal Extensions

1. Major Amendments

a. A major amendment to an original application, efficacy supplement, or Class
2 resubmission of any of these applications, submitted at any time during the
review cycle, may extend the goal date by 3 months. [Note: If the review
cycle occurred prior to FY 2013, the major amendment must have been
received within 3 months of the action due date to extend the action goal date
by 3 months.]

b. A major amendment may include, for example, a major new clinical
safety/efficacy study report; major re-analysis of previously submitted study
(studies); submission of a Risk Evaluation and Mitigation Strategy (REMS)
with Elements to Assure Safe Use (ETASU) not included in the original
application; or significant amendment to a previously submitted REMS with
ETASU. Generally, changes to REMS that do not include ETASU and minor
changes to REMS with ETASU will not be considered major amendments.

c. A major amendment to a manufacturing supplement submitted at any time
during the review cycle may extend the goal date by 2 months. [Note: If the
review cycle occurred prior to FY 2013, the major amendment must have
been received within 2 months of the action due date to extend the action
goal date by 2 months.]

d. Only one extension can be given per review cycle.

e. Consistent with the underlying principles articulated in the _Good Review_
_Management Principles and Practices for PDUFA Products_ guidance, [1] FDA’s
decision to extend the review clock should, except in rare circumstances, be
limited to occasions when the review of new information could address
outstanding deficiencies in the application and lead to approval in the current
review cycle.


1 [https://www.fda.gov/media/151712/download.](https://www.fda.gov/media/151712/download)


_Appendix E_ _Page E-1_


---

2. Inspection of Facilities Not Adequately Identified in an Original Application or
Supplement

a. All original applications, including those in the “Program,” and supplements
are expected to include a comprehensive and readily located list of all
manufacturing facilities included or referenced in the application or
supplement. This list provides FDA with information needed to schedule
inspections of manufacturing facilities that may be necessary before approval
of the original application or supplement.

b. If, during FDA’s review of an original application or supplement, the Agency
identifies a manufacturing facility that was not included in the comprehensive
and readily located list, the goal date may be extended.

i. If FDA identifies the need to inspect a manufacturing facility that is not
included as part of the comprehensive and readily located list in an
original application or efficacy supplement, the goal date may be
extended by 3 months.
ii. If FDA identifies the need to inspect a manufacturing facility that is not
included as part of the comprehensive and readily located list in a
manufacturing supplement, the goal date may be extended by 2 months.

C. A _resubmitted original application_ is an applicant’s complete response to an action
letter addressing all identified deficiencies.

D. _Class 1 resubmitted applications_ are applications resubmitted after a complete
response letter (or a not approvable or approvable letter) that include the following
items only (or combinations of these items):

1. Final printed labeling

2. Draft labeling

3. Safety updates submitted in the same format, including tabulations, as the
original safety submission with new data and changes highlighted (except when
large amounts of new information, including important new adverse experiences
not previously reported with the product, are presented in the resubmission)

4. Stability updates to support provisional or final dating periods

5. Commitments to perform postmarketing studies, including proposals for such
studies

6. Assay validation data

7. Final release testing on the last 1-2 lots used to support approval


_Appendix E_ _Page E-2_


---

8. A minor reanalysis of data previously submitted to the application (determined by
the Agency as fitting the Class 1 category)

9. Other minor clarifying information (determined by the Agency as fitting the Class
1 category)

10. Other specific items may be added later as the Agency gains experience with the
scheme and will be communicated via guidance documents to industry

E. _Class 2 resubmissions_ are resubmissions that include any other items, including any
item that would require presentation to an advisory committee.

F. Meeting requests commit FDA to notify the requestor of a formal meeting in writing
within 14 days of request for Type A, Type B(EOP), and Type D meetings or within
21 days of request for Type B, Type C, and Type INTERACT meetings.

G. Scheduled meetings should be made within 30 days of receipt of request for Type A
meetings, 60 days for Type B meetings, 70 days for Type B(EOP) meetings, 75 days
for Type C and Type INTERACT meetings, and 50 days for Type D meetings. If the
requested date for any of these types of meetings is greater than 30, 50, 60, 70, or
75 days, as appropriate, from the date the request is received by FDA, the meeting
date should be within 14 days of the requested date.

H. Preliminary responses to sponsor questions contained in the background package
for Type B(EOP), D, and INTERACT meetings should be sent to the sponsor no
later than 5 calendar days prior to the meeting date.

I. Meeting minutes are to be prepared by FDA clearly outlining agreements,
disagreements, issues for further discussion, and action items. They will be
available to the sponsor within 30 days of the meeting.

J. A Type A meeting is a meeting that is necessary for an otherwise stalled drug
development program to proceed (a “critical path” meeting) or to address an
important safety issue.

K. A Type B meeting includes pre-IND meetings and pre-NDA/BLA meetings, while
Type B(EOP) meetings are reserved for certain End-of-Phase 1 meetings (i.e., for
21 CFR part 312 subpart E or 21 CFR part 314 subpart H or similar products) and
End-of-Phase 2/pre-Phase 3 meetings. Meetings regarding REMS or postmarketing
requirements that occur outside the context of the review of a marketing application
will also generally be considered Type B meetings.

L. A Type C meeting is any type of meeting other than Type A, B, B(EOP), D, or
INTERACT.


_Appendix E_ _Page E-3_


---

M. A Type D meeting is focused on a narrow set of issues (e.g., often one, but typically
not more than two issues and associated questions).

N. An Initial Targeted Engagement for Regulatory Advice on CBER/CDER Products
(INTERACT) meeting is intended for novel questions and unique challenges in early
development (i.e., prior to filing of an IND).

O. The performance goals and procedures also apply to original applications and
supplements for human drugs initially marketed on an over-the-counter (OTC) basis
through an NDA or switched from prescription to OTC status through an NDA or
supplement.

P. IT-specific definitions:

1. _Program_ refers to the organizational resources, procedures, and activities
assigned to conduct “the process for the review of human drug applications,” as
defined in PDUFA.

2. _Standards-base_ means compliant with published specifications that address
terminology or information exchange between FDA and regulated parties or
external stakeholders, as adopted by FDA or other agencies of the federal
government, and often based on the publications of national or international
Standards Development Organizations.

3. _FDA Standards_ means technical specifications that have been adopted and
published by FDA through the appropriate governance process. FDA standards
may apply to terminology, information exchange, engineering or technology
specifications, or other technical matters related to information systems. FDA
standards often are based on the publications of other federal agencies or the
publications of national or international Standards Development Organizations.

4. _Product life cycle_ means the sequential stages of human drug development,
regulatory review and approval, postmarket surveillance and risk management,
and, when applicable, withdrawal of an approved drug from the market. In the
context of the process for the review of human drug applications, the product life
cycle begins with the earliest regulatory submissions in the IND phase, continues
through the NDA or BLA review phase, and includes postmarket surveillance and
risk management activities as covered under the process for the review of human
drug applications.

Q. Special Protocol Assessments: Upon specific request by a sponsor, FDA will
evaluate certain protocols and issues to assess whether the design is adequate to
meet scientific and regulatory requirements identified by the sponsor.


_Appendix E_ _Page E-4_


---

R. The Application Integrity Policy focuses on the integrity of data and information in
applications submitted to FDA for review and approval. It describes FDA’s approach
regarding the review of applications that may be affected by wrongful acts that raise
significant questions regarding data reliability. More information on the policy is
available at [http://www.fda.gov/media/71236/download.](http://www.fda.gov/media/71236/download)

S. A Risk Evaluation and Mitigation Strategy (REMS) is a drug safety program that FDA
may require for certain medications with serious safety concerns to help ensure the
benefits of the medication outweigh its risks. [2]

T. A Use-Related Risk Analysis (URRA) is employed by sponsors to identify the need
for risk mitigation strategies and to design a Human Factors validation study. Based
on a URRA, a sponsor may propose that a Human Factors validation study is not
needed to be submitted to support a safe and effective use of a drug-device or
biologic-device combination product. [3]

U. Human Factors validation studies are conducted to evaluate the user interface of a
drug device or biologic-device combination product to eliminate or mitigate userelated hazards that may affect the safe and effective use of the combination
product. [4]

V. Postmarketing Requirements (PMRs) include studies and clinical trials that sponsors
are required to conduct under one or more statutes or regulations. [5]


[2 For more information on REMS, see https://www.fda.gov/drugs/drug-safety-and-availability/risk-](https://www.fda.gov/drugs/drug-safety-and-availability/risk-evaluation-and-mitigation-strategies-rems)
[evaluation-and-mitigation-strategies-rems.](https://www.fda.gov/drugs/drug-safety-and-availability/risk-evaluation-and-mitigation-strategies-rems)
3 [https://www.fda.gov/media/151712/download.](https://www.fda.gov/media/151712/download)
4 Ibid.
[5 For more information on PMRs, see https://www.fda.gov/drugs/guidance-compliance-regulatory-](https://www.fda.gov/drugs/guidance-compliance-regulatory-information/postmarketing-requirements-and-commitments-introduction)
[information/postmarketing-requirements-and-commitments-introduction.](https://www.fda.gov/drugs/guidance-compliance-regulatory-information/postmarketing-requirements-and-commitments-introduction)


_Appendix E_ _Page E-5_


---

This report was prepared by FDA's Performance Management Staff in
collaboration with FDA’s Center for Biologics Evaluation and Research
and Center for Drug Evaluation and Research.  For information on
obtaining additional copies, please contact:
Performance Management Staff
Office of Operations
U.S. Food and Drug Administration
10903 New Hampshire Ave.
Silver Spring, MD  20993-0002

This report is available on FDA’s website at
https://www.fda.gov/fdatrack.

---
*Conversion confidence: 100% (135 pages)*